/* Generated by Cython 0.29.7 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/fast/code/venv/py3d/lib64/python3.6/site-packages/numpy/core/include/numpy/arrayobject.h",
            "/fast/code/venv/py3d/lib64/python3.6/site-packages/numpy/core/include/numpy/ufuncobject.h",
            "libudis/libudis.h",
            "libudis/libudis_flags.h"
        ],
        "extra_compile_args": [
            "-g"
        ],
        "include_dirs": [
            "libdebugger",
            "libudis",
            "/fast/code/venv/py3d/lib64/python3.6/site-packages/numpy/core/include"
        ],
        "name": "omnivore.disassembler.libudis",
        "sources": [
            "libudis/libudis.pyx",
            "libudis/parse_udis_cpu.c",
            "libudis/parse_custom.c",
            "libudis/stringify_udis_cpu.c",
            "libudis/stringify_custom.c",
            "libudis/history.c"
        ]
    },
    "module_name": "omnivore.disassembler.libudis"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_7"
#define CYTHON_HEX_VERSION 0x001D07F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
  #define PyObject_Unicode             PyObject_Str
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : (Py_INCREF(func), func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__omnivore__disassembler__libudis
#define __PYX_HAVE_API__omnivore__disassembler__libudis
/* Early includes */
#include <string.h>
#include <stdio.h>
#include "numpy/arrayobject.h"
#include "numpy/ufuncobject.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "libudis/libudis.pyx",
  "stringsource",
  "__init__.pxd",
  "type.pxd",
};
/* BufferFormatStructs.proto */
#define IS_UNSIGNED(type) (((type) -1) > 0)
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;


/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":776
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":777
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":778
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":779
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":783
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":784
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":785
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":786
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":790
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":791
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":800
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":801
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":802
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":804
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":805
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":806
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":808
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":809
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":811
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":812
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":813
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* Declarations.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);


/*--- Type declarations ---*/
struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage;
struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage;
struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly;
struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly;
struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig;
struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory;
struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage;
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__;
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__;
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__;
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__;
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":815
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":816
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":817
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":819
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_t_7libudis_7libudis_history_entry_t;
struct __pyx_t_7libudis_7libudis_emulator_history_t;
struct __pyx_t_7libudis_7libudis_label_info_t;
struct __pyx_t_7libudis_7libudis_jmp_targets_t;

/* "libudis/libudis.pxd":3
 * cimport numpy as np
 * 
 * cdef struct history_entry_t:             # <<<<<<<<<<<<<<
 *     np.uint16_t pc;
 *     np.uint16_t target_addr;
 */
struct __pyx_t_7libudis_7libudis_history_entry_t {
  __pyx_t_5numpy_uint16_t pc;
  __pyx_t_5numpy_uint16_t target_addr;
  __pyx_t_5numpy_uint8_t num_bytes;
  __pyx_t_5numpy_uint8_t disassembler_type;
  __pyx_t_5numpy_uint8_t flag;
  __pyx_t_5numpy_uint8_t unused;
  __pyx_t_5numpy_uint8_t instruction[16];
};

/* "libudis/libudis.pxd":12
 *     np.uint8_t instruction[16];
 * 
 * cdef struct emulator_history_t:             # <<<<<<<<<<<<<<
 *     np.int32_t num_allocated_entries;
 *     np.int32_t num_entries;
 */
struct __pyx_t_7libudis_7libudis_emulator_history_t {
  __pyx_t_5numpy_int32_t num_allocated_entries;
  __pyx_t_5numpy_int32_t num_entries;
  __pyx_t_5numpy_int32_t first_entry_index;
  __pyx_t_5numpy_int32_t latest_entry_index;
  __pyx_t_5numpy_uint32_t cumulative_count;
  struct __pyx_t_7libudis_7libudis_history_entry_t *entries;
};

/* "libudis/libudis.pxd":20
 *     history_entry_t *entries;
 * 
 * cdef struct label_info_t:             # <<<<<<<<<<<<<<
 *     np.uint32_t text_start_index;
 *     np.int8_t line_length;
 */
struct __pyx_t_7libudis_7libudis_label_info_t {
  __pyx_t_5numpy_uint32_t text_start_index;
  __pyx_t_5numpy_int8_t line_length;
  __pyx_t_5numpy_int8_t num_bytes;
  __pyx_t_5numpy_int8_t item_count;
  __pyx_t_5numpy_int8_t type_code;
};

/* "libudis/libudis.pxd":27
 *     np.int8_t type_code;
 * 
 * ctypedef int (*print_label_bridge_t)(int addr, int rw);             # <<<<<<<<<<<<<<
 * 
 * cdef struct jmp_targets_t:
 */
typedef int (*__pyx_t_7libudis_7libudis_print_label_bridge_t)(int, int);

/* "libudis/libudis.pxd":29
 * ctypedef int (*print_label_bridge_t)(int addr, int rw);
 * 
 * cdef struct jmp_targets_t:             # <<<<<<<<<<<<<<
 *     np.uint8_t discovered[256*256];
 *     char *text_storage;
 */
struct __pyx_t_7libudis_7libudis_jmp_targets_t {
  __pyx_t_5numpy_uint8_t discovered[(0x100 * 0x100)];
  char *text_storage;
  struct __pyx_t_7libudis_7libudis_label_info_t *labels;
};

/* "libudis/libudis.pxd":34
 *     label_info_t *labels;
 * 
 * ctypedef int (*parse_func_t)(history_entry_t *, unsigned char *, unsigned int, unsigned int, jmp_targets_t *)             # <<<<<<<<<<<<<<
 * 
 * ctypedef int (*string_func_t)(history_entry_t *, char *, char *, int, jmp_targets_t *)
 */
typedef int (*__pyx_t_7libudis_7libudis_parse_func_t)(struct __pyx_t_7libudis_7libudis_history_entry_t *, unsigned char *, unsigned int, unsigned int, struct __pyx_t_7libudis_7libudis_jmp_targets_t *);

/* "libudis/libudis.pxd":36
 * ctypedef int (*parse_func_t)(history_entry_t *, unsigned char *, unsigned int, unsigned int, jmp_targets_t *)
 * 
 * ctypedef int (*string_func_t)(history_entry_t *, char *, char *, int, jmp_targets_t *)             # <<<<<<<<<<<<<<
 */
typedef int (*__pyx_t_7libudis_7libudis_string_func_t)(struct __pyx_t_7libudis_7libudis_history_entry_t *, char *, char *, int, struct __pyx_t_7libudis_7libudis_jmp_targets_t *);

/* "libudis/libudis.pyx":22
 * 
 * 
 * cdef class TextStorage:             # <<<<<<<<<<<<<<
 *     cdef int max_lines
 *     cdef public int num_lines
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage {
  PyObject_HEAD
  struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *__pyx_vtab;
  int max_lines;
  int num_lines;
  PyArrayObject *label_info;
  struct __pyx_t_7libudis_7libudis_label_info_t *label_info_data;
  PyArrayObject *text_buffer;
  char *text_buffer_data;
  int text_buffer_size;
  char *text_ptr;
  __pyx_t_5numpy_uint32_t text_index;
};


/* "libudis/libudis.pyx":113
 * 
 * 
 * cdef class LabelStorage(TextStorage):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         TextStorage.__init__(self, 256*256, 256*256)
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage __pyx_base;
};


/* "libudis/libudis.pyx":263
 * 
 * 
 * cdef class StringifiedDisassembly:             # <<<<<<<<<<<<<<
 *     cdef public int origin
 *     cdef public int last_pc
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly {
  PyObject_HEAD
  struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_vtab;
  int origin;
  int last_pc;
  int start_index;
  PyArrayObject *jmp_targets;
  struct __pyx_t_7libudis_7libudis_jmp_targets_t *jmp_targets_data;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *disasm_text;
  int mnemonic_case;
  char *hex_case;
};


/* "libudis/libudis.pyx":344
 * 
 * 
 * cdef class ParsedDisassembly:             # <<<<<<<<<<<<<<
 *     cdef history_entry_t *history_entries
 *     cdef public int max_entries
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly {
  PyObject_HEAD
  struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_vtab;
  struct __pyx_t_7libudis_7libudis_history_entry_t *history_entries;
  int max_entries;
  int entry_size;
  PyArrayObject *raw_entries;
  int num_entries;
  int origin;
  int last_pc;
  int current_pc;
  PyArrayObject *jmp_targets;
  struct __pyx_t_7libudis_7libudis_jmp_targets_t *jmp_targets_data;
  int num_bytes;
  __pyx_t_5numpy_uint32_t *index_to_row_data;
  PyArrayObject *index_to_row;
  int index_index;
  int max_text_lines;
};


/* "libudis/libudis.pyx":444
 * cdef int data_style = 0
 * 
 * cdef class DisassemblyConfig:             # <<<<<<<<<<<<<<
 *     cdef np.uint8_t c_split_comments[256]
 *     cdef parse_func_t segment_parsers[256]
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig {
  PyObject_HEAD
  __pyx_t_5numpy_uint8_t c_split_comments[0x100];
  __pyx_t_7libudis_7libudis_parse_func_t segment_parsers[0x100];
  __pyx_t_5numpy_uint8_t default_disasm_type;
};


/* "libudis/libudis.pyx":525
 * 
 * 
 * cdef class StringifiedHistory:             # <<<<<<<<<<<<<<
 *     cdef public int origin
 *     cdef public int last_pc
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory {
  PyObject_HEAD
  struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_vtab;
  int origin;
  int last_pc;
  int start_index;
  PyArrayObject *jmp_targets;
  struct __pyx_t_7libudis_7libudis_jmp_targets_t *jmp_targets_data;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *history_text;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *result_text;
  int mnemonic_case;
  char *hex_case;
};


/* "libudis/libudis.pyx":616
 *                 index = 0
 * 
 * cdef class HistoryStorage:             # <<<<<<<<<<<<<<
 *     cdef public np.ndarray history_array
 *     cdef emulator_history_t *history
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage {
  PyObject_HEAD
  struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_vtab;
  PyArrayObject *history_array;
  struct __pyx_t_7libudis_7libudis_emulator_history_t *history;
  PyArrayObject *entries;
};


/* "libudis/libudis.pyx":74
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ {
  PyObject_HEAD
  int __pyx_v_count;
  int __pyx_v_i;
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self;
  int __pyx_v_start;
  int __pyx_t_0;
  int __pyx_t_1;
  int __pyx_t_2;
};


/* "libudis/libudis.pyx":140
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef label_info_t *info
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ {
  PyObject_HEAD
  int __pyx_v_i;
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self;
  int __pyx_t_0;
  int __pyx_t_1;
  int __pyx_t_2;
};


/* "libudis/libudis.pyx":319
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(len(self)):
 *             yield self.disasm_text[i]
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ {
  PyObject_HEAD
  Py_ssize_t __pyx_v_i;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self;
  Py_ssize_t __pyx_t_0;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
};


/* "libudis/libudis.pyx":578
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(len(self)):
 *             yield self.history_text[i], self.result_text[i]
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ {
  PyObject_HEAD
  Py_ssize_t __pyx_v_i;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self;
  Py_ssize_t __pyx_t_0;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
};


/* "libudis/libudis.pyx":648
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(self.num_lines):
 *             yield self.entries[i]
 */
struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ {
  PyObject_HEAD
  PyObject *__pyx_v_i;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self;
  PyObject *__pyx_t_0;
  Py_ssize_t __pyx_t_1;
  PyObject *(*__pyx_t_2)(PyObject *);
};



/* "libudis/libudis.pyx":22
 * 
 * 
 * cdef class TextStorage:             # <<<<<<<<<<<<<<
 *     cdef int max_lines
 *     cdef public int num_lines
 */

struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage {
  PyObject *(*clear)(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *);
  PyObject *(*store)(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *, int);
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *__pyx_vtabptr_8omnivore_12disassembler_7libudis_TextStorage;


/* "libudis/libudis.pyx":113
 * 
 * 
 * cdef class LabelStorage(TextStorage):             # <<<<<<<<<<<<<<
 *     def __init__(self):
 *         TextStorage.__init__(self, 256*256, 256*256)
 */

struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_LabelStorage {
  struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage __pyx_base;
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_vtabptr_8omnivore_12disassembler_7libudis_LabelStorage;


/* "libudis/libudis.pyx":263
 * 
 * 
 * cdef class StringifiedDisassembly:             # <<<<<<<<<<<<<<
 *     cdef public int origin
 *     cdef public int last_pc
 */

struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedDisassembly {
  PyObject *(*clear)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *);
  PyObject *(*parse_history_entries)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *, struct __pyx_t_7libudis_7libudis_history_entry_t *, int);
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedDisassembly;


/* "libudis/libudis.pyx":344
 * 
 * 
 * cdef class ParsedDisassembly:             # <<<<<<<<<<<<<<
 *     cdef history_entry_t *history_entries
 *     cdef public int max_entries
 */

struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly {
  PyObject *(*parse_next)(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *, __pyx_t_7libudis_7libudis_parse_func_t, unsigned char *, int);
  PyObject *(*fix_offset_labels)(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *);
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_vtabptr_8omnivore_12disassembler_7libudis_ParsedDisassembly;


/* "libudis/libudis.pyx":525
 * 
 * 
 * cdef class StringifiedHistory:             # <<<<<<<<<<<<<<
 *     cdef public int origin
 *     cdef public int last_pc
 */

struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedHistory {
  PyObject *(*clear)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *);
  PyObject *(*parse_history_entries)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *, struct __pyx_t_7libudis_7libudis_emulator_history_t *, int, int);
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedHistory;


/* "libudis/libudis.pyx":616
 *                 index = 0
 * 
 * cdef class HistoryStorage:             # <<<<<<<<<<<<<<
 *     cdef public np.ndarray history_array
 *     cdef emulator_history_t *history
 */

struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_HistoryStorage {
  PyObject *(*clear)(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *);
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_vtabptr_8omnivore_12disassembler_7libudis_HistoryStorage;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_str(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_str(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* IncludeStringH.proto */
#include <string.h>

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* IsLittleEndian.proto */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void);

/* BufferFormatCheck.proto */
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts);
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type);

/* BufferGetAndValidate.proto */
#define __Pyx_GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack)\
    ((obj == Py_None || obj == NULL) ?\
    (__Pyx_ZeroBuffer(buf), 0) :\
    __Pyx__GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack))
static int  __Pyx__GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static void __Pyx_ZeroBuffer(Py_buffer* buf);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);
static Py_ssize_t __Pyx_minusones[] = { -1, -1, -1, -1, -1, -1, -1, -1 };
static Py_ssize_t __Pyx_zeros[] = { 0, 0, 0, 0, 0, 0, 0, 0 };

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* None.proto */
static CYTHON_INLINE long __Pyx_mod_long(long, long);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_SubtractObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceSubtract(op1, op2) : PyNumber_Subtract(op1, op2))
#endif

/* None.proto */
static CYTHON_INLINE __pyx_t_5numpy_int32_t __Pyx_mod___pyx_t_5numpy_int32_t(__pyx_t_5numpy_int32_t, __pyx_t_5numpy_int32_t);

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* BufferStructDeclare.proto */
typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint32(npy_uint32 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int8(npy_int8 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint8(npy_uint8 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_uint8 __Pyx_PyInt_As_npy_uint8(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_int8 __Pyx_PyInt_As_npy_int8(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_int32 __Pyx_PyInt_As_npy_int32(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* CoroutineBase.proto */
typedef PyObject *(*__pyx_coroutine_body_t)(PyObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
    PyObject *gi_weakreflist;
    PyObject *classobj;
    PyObject *yieldfrom;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static PyObject *__Pyx_Coroutine_Close(PyObject *self);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);

/* PatchModuleWithCoroutine.proto */
static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code);

/* PatchGeneratorABC.proto */
static int __Pyx_patch_abc(void);

/* Generator.proto */
#define __Pyx_Generator_USED
static PyTypeObject *__pyx_GeneratorType = 0;
#define __Pyx_Generator_CheckExact(obj) (Py_TYPE(obj) == __pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_11TextStorage_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_11TextStorage_store(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, int __pyx_v_count); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_12LabelStorage_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_parse_history_entries(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, struct __pyx_t_7libudis_7libudis_history_entry_t *__pyx_v_h, int __pyx_v_num_entries); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_17ParsedDisassembly_parse_next(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, __pyx_t_7libudis_7libudis_parse_func_t __pyx_v_processor, unsigned char *__pyx_v_src, int __pyx_v_num_bytes); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_17ParsedDisassembly_fix_offset_labels(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_18StringifiedHistory_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_18StringifiedHistory_parse_history_entries(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, struct __pyx_t_7libudis_7libudis_emulator_history_t *__pyx_v_history, int __pyx_v_index, int __pyx_v_num_entries); /* proto*/
static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_14HistoryStorage_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto*/

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cython' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'cpython.mem' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;
static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *, char *, char *, int *); /*proto*/

/* Module declarations from 'libudis.libudis' */

/* Module declarations from 'omnivore.disassembler.libudis' */
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis_LabelStorage = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis_StringifiedDisassembly = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis_ParsedDisassembly = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis_DisassemblyConfig = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis_StringifiedHistory = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis_HistoryStorage = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ = 0;
static PyTypeObject *__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ = 0;
__PYX_EXTERN_C DL_IMPORT(__pyx_t_7libudis_7libudis_parse_func_t) parser_map[];
__PYX_EXTERN_C DL_IMPORT(__pyx_t_7libudis_7libudis_string_func_t) stringifier_map[];
static char *__pyx_v_8omnivore_12disassembler_7libudis_hexdigits_lower;
static char *__pyx_v_8omnivore_12disassembler_7libudis_hexdigits_upper;
static int __pyx_v_8omnivore_12disassembler_7libudis_data_style;
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t = { "uint8_t", NULL, sizeof(__pyx_t_5numpy_uint8_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_uint8_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_uint8_t), 0 };
#define __Pyx_MODULE_NAME "omnivore.disassembler.libudis"
extern int __pyx_module_is_main_omnivore__disassembler__libudis;
int __pyx_module_is_main_omnivore__disassembler__libudis = 0;

/* Implementation of 'omnivore.disassembler.libudis' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_print;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_hex;
static PyObject *__pyx_builtin_RuntimeError;
static PyObject *__pyx_builtin_ImportError;
static const char __pyx_k__6[] = "...";
static const char __pyx_k_np[] = "np";
static const char __pyx_k__18[] = " -> ";
static const char __pyx_k__19[] = ": ";
static const char __pyx_k__20[] = "  ...";
static const char __pyx_k_hex[] = "hex";
static const char __pyx_k_src[] = "src";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_iter[] = "__iter__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_more[] = "more";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_send[] = "send";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_used[] = ", used: ";
static const char __pyx_k_bytes[] = " bytes";
static const char __pyx_k_close[] = "close";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_entry[] = "entry:";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_lines[] = " lines";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_style[] = "style";
static const char __pyx_k_throw[] = "throw";
static const char __pyx_k_total[] = "total = ";
static const char __pyx_k_uint8[] = "uint8";
static const char __pyx_k_zeros[] = "zeros";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_labels[] = "labels";
static const char __pyx_k_latest[] = ", latest: ";
static const char __pyx_k_origin[] = "origin";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_uint32[] = "uint32";
static const char __pyx_k_entries[] = " entries; ";
static const char __pyx_k_indices[] = "indices";
static const char __pyx_k_segment[] = "segment";
static const char __pyx_k_summary[] = "summary:";
static const char __pyx_k_tobytes[] = "tobytes";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_tostring[] = "tostring";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_hex_lower[] = "hex_lower";
static const char __pyx_k_max_lines[] = "max_lines";
static const char __pyx_k_num_bytes[] = "num_bytes";
static const char __pyx_k_num_lines[] = "num_lines";
static const char __pyx_k_print_all[] = "print_all";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_cumulative[] = ", cumulative ";
static const char __pyx_k_get_parser[] = "get_parser";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_TextStorage[] = "TextStorage";
static const char __pyx_k_buffer_size[] = "buffer_size";
static const char __pyx_k_disasm_type[] = "disasm_type";
static const char __pyx_k_jmp_targets[] = "jmp_targets";
static const char __pyx_k_max_entries[] = "max_entries";
static const char __pyx_k_num_entries[] = "num_entries";
static const char __pyx_k_start_index[] = "start_index";
static const char __pyx_k_text_buffer[] = "text_buffer";
static const char __pyx_k_LabelStorage[] = "LabelStorage";
static const char __pyx_k_RuntimeError[] = "RuntimeError";
static const char __pyx_k_alloc_arrays[] = "alloc_arrays";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_start_of_ring[] = "start of ring: ";
static const char __pyx_k_HistoryStorage[] = "HistoryStorage";
static const char __pyx_k_mnemonic_lower[] = "mnemonic_lower";
static const char __pyx_k_split_comments[] = "split_comments";
static const char __pyx_k_def_disasm_type[] = "def_disasm_type";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_DisassemblyConfig[] = "DisassemblyConfig";
static const char __pyx_k_ParsedDisassembly[] = "ParsedDisassembly";
static const char __pyx_k_number_of_entries[] = "number of entries: ";
static const char __pyx_k_StringifiedHistory[] = "StringifiedHistory";
static const char __pyx_k_TextStorage___iter[] = "TextStorage.__iter__";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_HISTORY_ENTRY_DTYPE[] = "HISTORY_ENTRY_DTYPE";
static const char __pyx_k_LabelStorage___iter[] = "LabelStorage.__iter__";
static const char __pyx_k_get_label_data_addr[] = "get_label_data_addr";
static const char __pyx_k_num_lines_requested[] = "num_lines_requested";
static const char __pyx_k_HistoryStorage___iter[] = "HistoryStorage.__iter__";
static const char __pyx_k_get_text_storage_addr[] = "get_text_storage_addr";
static const char __pyx_k_StringifiedDisassembly[] = "StringifiedDisassembly";
static const char __pyx_k_StringifiedHistory___iter[] = "StringifiedHistory.__iter__";
static const char __pyx_k_slicing_not_yet_supported[] = "slicing not yet supported";
static const char __pyx_k_exceeded_attempted_to_save[] = " exceeded, attempted to save ";
static const char __pyx_k_ndarray_is_not_C_contiguous[] = "ndarray is not C contiguous";
static const char __pyx_k_omnivore_disassembler_dtypes[] = "omnivore.disassembler.dtypes";
static const char __pyx_k_CYTHON_ERROR_Text_buffer_size[] = "CYTHON ERROR! Text buffer size ";
static const char __pyx_k_StringifiedDisassembly___iter[] = "StringifiedDisassembly.__iter__";
static const char __pyx_k_omnivore_disassembler_libudis[] = "omnivore.disassembler.libudis";
static const char __pyx_k_index_must_be_int_or_slice_not[] = "index must be int or slice, not ";
static const char __pyx_k_exceeded_in_LabelStorage_attemp[] = " exceeded in LabelStorage, attempted to save ";
static const char __pyx_k_exceeded_in_TextStorage_attempt[] = " exceeded in TextStorage, attempted to save ";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_self_history_entries_self_index[] = "self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling";
static const char __pyx_k_self_jmp_targets_data_cannot_be[] = "self.jmp_targets_data cannot be converted to a Python object for pickling";
static const char __pyx_k_unknown_dtype_code_in_numpy_pxd[] = "unknown dtype code in numpy.pxd (%d)";
static const char __pyx_k_CYTHON_ERROR_ParsedDisassembly_d[] = "CYTHON ERROR! ParsedDisassembly disassembly entries ";
static const char __pyx_k_CYTHON_ERROR_ParsedDisassembly_i[] = "CYTHON ERROR! ParsedDisassembly index_to_row entries ";
static const char __pyx_k_CYTHON_ERROR_Text_buffer_line_co[] = "CYTHON ERROR! Text buffer line count ";
static const char __pyx_k_Format_string_allocated_too_shor[] = "Format string allocated too short, see comment in numpy.pxd";
static const char __pyx_k_Non_native_byte_order_not_suppor[] = "Non-native byte order not supported";
static const char __pyx_k_deleting_labels_via_slices_not_y[] = "deleting labels via slices not yet supported";
static const char __pyx_k_ndarray_is_not_Fortran_contiguou[] = "ndarray is not Fortran contiguous";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_self_history_cannot_be_converted[] = "self.history cannot be converted to a Python object for pickling";
static const char __pyx_k_self_label_info_data_cannot_be_c[] = "self.label_info_data cannot be converted to a Python object for pickling";
static const char __pyx_k_self_segment_parsers_cannot_be_c[] = "self.segment_parsers cannot be converted to a Python object for pickling";
static const char __pyx_k_setting_labels_via_slices_not_ye[] = "setting labels via slices not yet supported";
static const char __pyx_k_Format_string_allocated_too_shor_2[] = "Format string allocated too short.";
static PyObject *__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_d;
static PyObject *__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_i;
static PyObject *__pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co;
static PyObject *__pyx_kp_u_CYTHON_ERROR_Text_buffer_size;
static PyObject *__pyx_n_s_DisassemblyConfig;
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor;
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor_2;
static PyObject *__pyx_n_s_HISTORY_ENTRY_DTYPE;
static PyObject *__pyx_n_s_HistoryStorage;
static PyObject *__pyx_n_s_HistoryStorage___iter;
static PyObject *__pyx_n_s_ImportError;
static PyObject *__pyx_n_s_LabelStorage;
static PyObject *__pyx_n_s_LabelStorage___iter;
static PyObject *__pyx_kp_u_Non_native_byte_order_not_suppor;
static PyObject *__pyx_n_s_ParsedDisassembly;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_n_s_StringifiedDisassembly;
static PyObject *__pyx_n_s_StringifiedDisassembly___iter;
static PyObject *__pyx_n_s_StringifiedHistory;
static PyObject *__pyx_n_s_StringifiedHistory___iter;
static PyObject *__pyx_n_s_TextStorage;
static PyObject *__pyx_n_s_TextStorage___iter;
static PyObject *__pyx_n_s_TypeError;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_kp_u__18;
static PyObject *__pyx_kp_u__19;
static PyObject *__pyx_kp_u__20;
static PyObject *__pyx_kp_u__6;
static PyObject *__pyx_n_s_alloc_arrays;
static PyObject *__pyx_n_s_args;
static PyObject *__pyx_n_s_buffer_size;
static PyObject *__pyx_kp_u_bytes;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_close;
static PyObject *__pyx_kp_u_cumulative;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_def_disasm_type;
static PyObject *__pyx_kp_u_deleting_labels_via_slices_not_y;
static PyObject *__pyx_n_s_disasm_type;
static PyObject *__pyx_n_s_dtype;
static PyObject *__pyx_kp_u_entries;
static PyObject *__pyx_kp_u_entry;
static PyObject *__pyx_kp_u_exceeded_attempted_to_save;
static PyObject *__pyx_kp_u_exceeded_in_LabelStorage_attemp;
static PyObject *__pyx_kp_u_exceeded_in_TextStorage_attempt;
static PyObject *__pyx_n_s_get_label_data_addr;
static PyObject *__pyx_n_s_get_parser;
static PyObject *__pyx_n_s_get_text_storage_addr;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_n_s_hex;
static PyObject *__pyx_n_s_hex_lower;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_kp_u_index_must_be_int_or_slice_not;
static PyObject *__pyx_n_s_indices;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_iter;
static PyObject *__pyx_n_s_jmp_targets;
static PyObject *__pyx_n_s_labels;
static PyObject *__pyx_kp_u_latest;
static PyObject *__pyx_kp_u_lines;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_max_entries;
static PyObject *__pyx_n_s_max_lines;
static PyObject *__pyx_n_s_mnemonic_lower;
static PyObject *__pyx_n_u_more;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_kp_u_ndarray_is_not_C_contiguous;
static PyObject *__pyx_kp_u_ndarray_is_not_Fortran_contiguou;
static PyObject *__pyx_n_s_np;
static PyObject *__pyx_n_s_num_bytes;
static PyObject *__pyx_n_s_num_entries;
static PyObject *__pyx_n_s_num_lines;
static PyObject *__pyx_n_s_num_lines_requested;
static PyObject *__pyx_kp_u_number_of_entries;
static PyObject *__pyx_n_s_numpy;
static PyObject *__pyx_kp_u_numpy_core_multiarray_failed_to;
static PyObject *__pyx_kp_u_numpy_core_umath_failed_to_impor;
static PyObject *__pyx_n_s_omnivore_disassembler_dtypes;
static PyObject *__pyx_n_s_omnivore_disassembler_libudis;
static PyObject *__pyx_n_s_origin;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_n_u_print_all;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_segment;
static PyObject *__pyx_kp_s_self_history_cannot_be_converted;
static PyObject *__pyx_kp_s_self_history_entries_self_index;
static PyObject *__pyx_kp_s_self_jmp_targets_data_cannot_be;
static PyObject *__pyx_kp_s_self_label_info_data_cannot_be_c;
static PyObject *__pyx_kp_s_self_segment_parsers_cannot_be_c;
static PyObject *__pyx_n_s_send;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_kp_u_setting_labels_via_slices_not_ye;
static PyObject *__pyx_kp_u_slicing_not_yet_supported;
static PyObject *__pyx_n_s_split_comments;
static PyObject *__pyx_n_s_src;
static PyObject *__pyx_n_s_start_index;
static PyObject *__pyx_kp_u_start_of_ring;
static PyObject *__pyx_n_s_style;
static PyObject *__pyx_kp_u_summary;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_text_buffer;
static PyObject *__pyx_n_s_throw;
static PyObject *__pyx_n_s_tobytes;
static PyObject *__pyx_n_s_tostring;
static PyObject *__pyx_kp_u_total;
static PyObject *__pyx_n_s_uint32;
static PyObject *__pyx_n_s_uint8;
static PyObject *__pyx_kp_u_unknown_dtype_code_in_numpy_pxd;
static PyObject *__pyx_kp_u_used;
static PyObject *__pyx_n_s_zeros;
static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_buffer_size); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_2alloc_arrays(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_buffer_size); /* proto */
static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_4__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_6__contains__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_8__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_13get_label_data_addr(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_15get_text_storage_addr(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_17__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_19__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_2__contains__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_9__setitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_11__delitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_13print_all(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_15keys(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_17update(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_other); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_19__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_21__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_start_index, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_jmp_targets, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower); /* proto */
static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_9__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_max_entries, PyObject *__pyx_v_origin, PyObject *__pyx_v_num_bytes); /* proto */
static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_4parse_test(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_disasm_type, PyArrayObject *__pyx_v_src); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6stringify(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, int __pyx_v_index, int __pyx_v_num_lines_requested, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, PyObject *__pyx_v_def_disasm_type, PyObject *__pyx_v_split_comments); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_2get_parser(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, PyObject *__pyx_v_num_entries, PyObject *__pyx_v_origin, PyObject *__pyx_v_num_bytes); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_4parse(struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, PyObject *__pyx_v_segment, PyObject *__pyx_v_num_entries); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower); /* proto */
static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_9__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_num_entries); /* proto */
static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_17first_entry_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_18latest_entry_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_16next_entry_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_16cumulative_count___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_9summary(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_11debug_range(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_from_index); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13stringify(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, int __pyx_v_index, int __pyx_v_num_lines_requested, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_15__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_17__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_TextStorage(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_LabelStorage(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_StringifiedDisassembly(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_ParsedDisassembly(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_DisassemblyConfig(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_StringifiedHistory(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_HistoryStorage(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_64;
static PyObject *__pyx_int_65536;
static PyObject *__pyx_k__13;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_tuple__21;
static PyObject *__pyx_tuple__22;
static PyObject *__pyx_tuple__23;
static PyObject *__pyx_tuple__24;
static PyObject *__pyx_tuple__25;
static PyObject *__pyx_tuple__26;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__28;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
/* Late includes */

/* "libudis/libudis.pyx":33
 *     cdef np.uint32_t text_index
 * 
 *     def __init__(self, max_lines, buffer_size=None):             # <<<<<<<<<<<<<<
 *         if buffer_size is None:
 *             buffer_size = max_lines * 64
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_max_lines = 0;
  PyObject *__pyx_v_buffer_size = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_max_lines,&__pyx_n_s_buffer_size,0};
    PyObject* values[2] = {0,0};
    values[1] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_lines)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_buffer_size);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 33, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_max_lines = values[0];
    __pyx_v_buffer_size = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 33, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage___init__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), __pyx_v_max_lines, __pyx_v_buffer_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_buffer_size) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);
  __Pyx_INCREF(__pyx_v_buffer_size);

  /* "libudis/libudis.pyx":34
 * 
 *     def __init__(self, max_lines, buffer_size=None):
 *         if buffer_size is None:             # <<<<<<<<<<<<<<
 *             buffer_size = max_lines * 64
 *         self.alloc_arrays(max_lines, buffer_size)
 */
  __pyx_t_1 = (__pyx_v_buffer_size == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":35
 *     def __init__(self, max_lines, buffer_size=None):
 *         if buffer_size is None:
 *             buffer_size = max_lines * 64             # <<<<<<<<<<<<<<
 *         self.alloc_arrays(max_lines, buffer_size)
 *         self.clear()
 */
    __pyx_t_3 = PyNumber_Multiply(__pyx_v_max_lines, __pyx_int_64); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 35, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_buffer_size, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":34
 * 
 *     def __init__(self, max_lines, buffer_size=None):
 *         if buffer_size is None:             # <<<<<<<<<<<<<<
 *             buffer_size = max_lines * 64
 *         self.alloc_arrays(max_lines, buffer_size)
 */
  }

  /* "libudis/libudis.pyx":36
 *         if buffer_size is None:
 *             buffer_size = max_lines * 64
 *         self.alloc_arrays(max_lines, buffer_size)             # <<<<<<<<<<<<<<
 *         self.clear()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_alloc_arrays); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_max_lines, __pyx_v_buffer_size};
    __pyx_t_3 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 36, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[3] = {__pyx_t_5, __pyx_v_max_lines, __pyx_v_buffer_size};
    __pyx_t_3 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_6, 2+__pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 36, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GOTREF(__pyx_t_3);
  } else
  #endif
  {
    __pyx_t_7 = PyTuple_New(2+__pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 36, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    if (__pyx_t_5) {
      __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5); __pyx_t_5 = NULL;
    }
    __Pyx_INCREF(__pyx_v_max_lines);
    __Pyx_GIVEREF(__pyx_v_max_lines);
    PyTuple_SET_ITEM(__pyx_t_7, 0+__pyx_t_6, __pyx_v_max_lines);
    __Pyx_INCREF(__pyx_v_buffer_size);
    __Pyx_GIVEREF(__pyx_v_buffer_size);
    PyTuple_SET_ITEM(__pyx_t_7, 1+__pyx_t_6, __pyx_v_buffer_size);
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_7, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 36, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "libudis/libudis.pyx":37
 *             buffer_size = max_lines * 64
 *         self.alloc_arrays(max_lines, buffer_size)
 *         self.clear()             # <<<<<<<<<<<<<<
 * 
 *     def alloc_arrays(self, max_lines, buffer_size):
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->__pyx_vtab)->clear(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "libudis/libudis.pyx":33
 *     cdef np.uint32_t text_index
 * 
 *     def __init__(self, max_lines, buffer_size=None):             # <<<<<<<<<<<<<<
 *         if buffer_size is None:
 *             buffer_size = max_lines * 64
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_buffer_size);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":39
 *         self.clear()
 * 
 *     def alloc_arrays(self, max_lines, buffer_size):             # <<<<<<<<<<<<<<
 *         self.label_info = np.zeros(max_lines * sizeof(label_info_t), dtype=np.uint8)
 *         self.label_info_data = <label_info_t *>self.label_info.data
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_3alloc_arrays(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_3alloc_arrays(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_max_lines = 0;
  PyObject *__pyx_v_buffer_size = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("alloc_arrays (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_max_lines,&__pyx_n_s_buffer_size,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_lines)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_buffer_size)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("alloc_arrays", 1, 2, 2, 1); __PYX_ERR(0, 39, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "alloc_arrays") < 0)) __PYX_ERR(0, 39, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_max_lines = values[0];
    __pyx_v_buffer_size = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("alloc_arrays", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 39, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.alloc_arrays", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_2alloc_arrays(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), __pyx_v_max_lines, __pyx_v_buffer_size);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_2alloc_arrays(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_buffer_size) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("alloc_arrays", 0);

  /* "libudis/libudis.pyx":40
 * 
 *     def alloc_arrays(self, max_lines, buffer_size):
 *         self.label_info = np.zeros(max_lines * sizeof(label_info_t), dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         self.label_info_data = <label_info_t *>self.label_info.data
 *         self.text_buffer_size = buffer_size
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((sizeof(struct __pyx_t_7libudis_7libudis_label_info_t))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyNumber_Multiply(__pyx_v_max_lines, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_uint8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_1, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->label_info);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->label_info));
  __pyx_v_self->label_info = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "libudis/libudis.pyx":41
 *     def alloc_arrays(self, max_lines, buffer_size):
 *         self.label_info = np.zeros(max_lines * sizeof(label_info_t), dtype=np.uint8)
 *         self.label_info_data = <label_info_t *>self.label_info.data             # <<<<<<<<<<<<<<
 *         self.text_buffer_size = buffer_size
 *         self.text_buffer = np.zeros(buffer_size, dtype=np.uint8)
 */
  __pyx_v_self->label_info_data = ((struct __pyx_t_7libudis_7libudis_label_info_t *)__pyx_v_self->label_info->data);

  /* "libudis/libudis.pyx":42
 *         self.label_info = np.zeros(max_lines * sizeof(label_info_t), dtype=np.uint8)
 *         self.label_info_data = <label_info_t *>self.label_info.data
 *         self.text_buffer_size = buffer_size             # <<<<<<<<<<<<<<
 *         self.text_buffer = np.zeros(buffer_size, dtype=np.uint8)
 *         self.text_buffer_data = <char *>self.text_buffer.data
 */
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_buffer_size); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 42, __pyx_L1_error)
  __pyx_v_self->text_buffer_size = __pyx_t_6;

  /* "libudis/libudis.pyx":43
 *         self.label_info_data = <label_info_t *>self.label_info.data
 *         self.text_buffer_size = buffer_size
 *         self.text_buffer = np.zeros(buffer_size, dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         self.text_buffer_data = <char *>self.text_buffer.data
 *         self.max_lines = max_lines
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_buffer_size);
  __Pyx_GIVEREF(__pyx_v_buffer_size);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_buffer_size);
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_uint8); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_4) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->text_buffer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->text_buffer));
  __pyx_v_self->text_buffer = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "libudis/libudis.pyx":44
 *         self.text_buffer_size = buffer_size
 *         self.text_buffer = np.zeros(buffer_size, dtype=np.uint8)
 *         self.text_buffer_data = <char *>self.text_buffer.data             # <<<<<<<<<<<<<<
 *         self.max_lines = max_lines
 * 
 */
  __pyx_v_self->text_buffer_data = ((char *)__pyx_v_self->text_buffer->data);

  /* "libudis/libudis.pyx":45
 *         self.text_buffer = np.zeros(buffer_size, dtype=np.uint8)
 *         self.text_buffer_data = <char *>self.text_buffer.data
 *         self.max_lines = max_lines             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_max_lines); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 45, __pyx_L1_error)
  __pyx_v_self->max_lines = __pyx_t_6;

  /* "libudis/libudis.pyx":39
 *         self.clear()
 * 
 *     def alloc_arrays(self, max_lines, buffer_size):             # <<<<<<<<<<<<<<
 *         self.label_info = np.zeros(max_lines * sizeof(label_info_t), dtype=np.uint8)
 *         self.label_info_data = <label_info_t *>self.label_info.data
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.alloc_arrays", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":47
 *         self.max_lines = max_lines
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.num_lines
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_5__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_4__len__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_4__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "libudis/libudis.pyx":48
 * 
 *     def __len__(self):
 *         return self.num_lines             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, index):
 */
  __pyx_r = __pyx_v_self->num_lines;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":47
 *         self.max_lines = max_lines
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.num_lines
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":50
 *         return self.num_lines
 * 
 *     def __contains__(self, index):             # <<<<<<<<<<<<<<
 *         return index > 0 and index < self.num_lines
 * 
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_6__contains__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_6__contains__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_index) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__contains__", 0);

  /* "libudis/libudis.pyx":51
 * 
 *     def __contains__(self, index):
 *         return index > 0 and index < self.num_lines             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, index):
 */
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_index, __pyx_int_0, Py_GT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 51, __pyx_L1_error)
  if (__pyx_t_3) {
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 51, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_4;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_self->num_lines); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_index, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 51, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_5); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 51, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_4;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":50
 *         return self.num_lines
 * 
 *     def __contains__(self, index):             # <<<<<<<<<<<<<<
 *         return index > 0 and index < self.num_lines
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":53
 *         return index > 0 and index < self.num_lines
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_8__getitem__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_8__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_index) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  int __pyx_v_start;
  int __pyx_v_count;
  PyObject *__pyx_v_lines = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  __pyx_t_5numpy_uint32_t __pyx_t_10;
  __pyx_t_5numpy_int8_t __pyx_t_11;
  int __pyx_t_12;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "libudis/libudis.pyx":57
 *         cdef int i, start, count
 * 
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  __pyx_t_1 = PySlice_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":58
 * 
 *         if isinstance(index, slice):
 *             lines = []             # <<<<<<<<<<<<<<
 *             for i in range(*index.indices(len(self))):
 *                 info = &self.label_info_data[i]
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 58, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_lines = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":59
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 info = &self.label_info_data[i]
 *                 start = info.text_start_index
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_indices); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_Length(((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 59, __pyx_L1_error)
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 59, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 59, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 59, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 59, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 59, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_8(__pyx_t_4);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 59, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 59, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_i = __pyx_t_9;

      /* "libudis/libudis.pyx":60
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 *                 info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *                 start = info.text_start_index
 *                 count = info.line_length
 */
      __pyx_v_info = (&(__pyx_v_self->label_info_data[__pyx_v_i]));

      /* "libudis/libudis.pyx":61
 *             for i in range(*index.indices(len(self))):
 *                 info = &self.label_info_data[i]
 *                 start = info.text_start_index             # <<<<<<<<<<<<<<
 *                 count = info.line_length
 *                 lines.append(self.text_buffer[start:start + count].tostring())
 */
      __pyx_t_10 = __pyx_v_info->text_start_index;
      __pyx_v_start = __pyx_t_10;

      /* "libudis/libudis.pyx":62
 *                 info = &self.label_info_data[i]
 *                 start = info.text_start_index
 *                 count = info.line_length             # <<<<<<<<<<<<<<
 *                 lines.append(self.text_buffer[start:start + count].tostring())
 *             return lines
 */
      __pyx_t_11 = __pyx_v_info->line_length;
      __pyx_v_count = __pyx_t_11;

      /* "libudis/libudis.pyx":63
 *                 start = info.text_start_index
 *                 count = info.line_length
 *                 lines.append(self.text_buffer[start:start + count].tostring())             # <<<<<<<<<<<<<<
 *             return lines
 *         elif isinstance(index, int):
 */
      __pyx_t_6 = __Pyx_PyObject_GetSlice(((PyObject *)__pyx_v_self->text_buffer), __pyx_v_start, (__pyx_v_start + __pyx_v_count), NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 63, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_tostring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 63, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_7, function);
        }
      }
      __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 63, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_12 = __Pyx_PyList_Append(__pyx_v_lines, __pyx_t_3); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(0, 63, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "libudis/libudis.pyx":59
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 info = &self.label_info_data[i]
 *                 start = info.text_start_index
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "libudis/libudis.pyx":64
 *                 count = info.line_length
 *                 lines.append(self.text_buffer[start:start + count].tostring())
 *             return lines             # <<<<<<<<<<<<<<
 *         elif isinstance(index, int):
 *             i = index
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_lines);
    __pyx_r = __pyx_v_lines;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":57
 *         cdef int i, start, count
 * 
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  }

  /* "libudis/libudis.pyx":65
 *                 lines.append(self.text_buffer[start:start + count].tostring())
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             info = &self.label_info_data[i]
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_index); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (likely(__pyx_t_1)) {

    /* "libudis/libudis.pyx":66
 *             return lines
 *         elif isinstance(index, int):
 *             i = index             # <<<<<<<<<<<<<<
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index
 */
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_v_index); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 66, __pyx_L1_error)
    __pyx_v_i = __pyx_t_9;

    /* "libudis/libudis.pyx":67
 *         elif isinstance(index, int):
 *             i = index
 *             info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *             start = info.text_start_index
 *             count = info.line_length
 */
    __pyx_v_info = (&(__pyx_v_self->label_info_data[__pyx_v_i]));

    /* "libudis/libudis.pyx":68
 *             i = index
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index             # <<<<<<<<<<<<<<
 *             count = info.line_length
 *             return self.text_buffer[start:start + count].tostring()
 */
    __pyx_t_10 = __pyx_v_info->text_start_index;
    __pyx_v_start = __pyx_t_10;

    /* "libudis/libudis.pyx":69
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index
 *             count = info.line_length             # <<<<<<<<<<<<<<
 *             return self.text_buffer[start:start + count].tostring()
 *         else:
 */
    __pyx_t_11 = __pyx_v_info->line_length;
    __pyx_v_count = __pyx_t_11;

    /* "libudis/libudis.pyx":70
 *             start = info.text_start_index
 *             count = info.line_length
 *             return self.text_buffer[start:start + count].tostring()             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetSlice(((PyObject *)__pyx_v_self->text_buffer), __pyx_v_start, (__pyx_v_start + __pyx_v_count), NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tostring); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_4 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 70, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":65
 *                 lines.append(self.text_buffer[start:start + count].tostring())
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             info = &self.label_info_data[i]
 */
  }

  /* "libudis/libudis.pyx":72
 *             return self.text_buffer[start:start + count].tostring()
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_index)), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 72, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 72, __pyx_L1_error)
  }

  /* "libudis/libudis.pyx":53
 *         return index > 0 and index < self.num_lines
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lines);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_11TextStorage_12generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "libudis/libudis.pyx":74
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11__iter__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10__iter__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *)__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__(__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 74, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8omnivore_12disassembler_7libudis_11TextStorage_12generator, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_TextStorage___iter, __pyx_n_s_omnivore_disassembler_libudis); if (unlikely(!gen)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_11TextStorage_12generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *__pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __pyx_t_5numpy_uint32_t __pyx_t_4;
  __pyx_t_5numpy_int8_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 74, __pyx_L1_error)

  /* "libudis/libudis.pyx":78
 *         cdef int i, start, count
 * 
 *         for i in range(self.num_lines):             # <<<<<<<<<<<<<<
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self->num_lines;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_cur_scope->__pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":79
 * 
 *         for i in range(self.num_lines):
 *             info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *             start = info.text_start_index
 *             count = info.line_length
 */
    __pyx_cur_scope->__pyx_v_info = (&(__pyx_cur_scope->__pyx_v_self->label_info_data[__pyx_cur_scope->__pyx_v_i]));

    /* "libudis/libudis.pyx":80
 *         for i in range(self.num_lines):
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index             # <<<<<<<<<<<<<<
 *             count = info.line_length
 *             yield self.text_buffer[start:start + count].tostring()
 */
    __pyx_t_4 = __pyx_cur_scope->__pyx_v_info->text_start_index;
    __pyx_cur_scope->__pyx_v_start = __pyx_t_4;

    /* "libudis/libudis.pyx":81
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index
 *             count = info.line_length             # <<<<<<<<<<<<<<
 *             yield self.text_buffer[start:start + count].tostring()
 * 
 */
    __pyx_t_5 = __pyx_cur_scope->__pyx_v_info->line_length;
    __pyx_cur_scope->__pyx_v_count = __pyx_t_5;

    /* "libudis/libudis.pyx":82
 *             start = info.text_start_index
 *             count = info.line_length
 *             yield self.text_buffer[start:start + count].tostring()             # <<<<<<<<<<<<<<
 * 
 *     cdef clear(self):
 */
    __pyx_t_7 = __Pyx_PyObject_GetSlice(((PyObject *)__pyx_cur_scope->__pyx_v_self->text_buffer), __pyx_cur_scope->__pyx_v_start, (__pyx_cur_scope->__pyx_v_start + __pyx_cur_scope->__pyx_v_count), NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tostring); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 82, __pyx_L1_error)
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "libudis/libudis.pyx":74
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":84
 *             yield self.text_buffer[start:start + count].tostring()
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.num_lines = 0
 *         self.text_index = 0
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_11TextStorage_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  __Pyx_RefNannySetupContext("clear", 0);

  /* "libudis/libudis.pyx":85
 * 
 *     cdef clear(self):
 *         self.num_lines = 0             # <<<<<<<<<<<<<<
 *         self.text_index = 0
 *         self.text_ptr = self.text_buffer_data
 */
  __pyx_v_self->num_lines = 0;

  /* "libudis/libudis.pyx":86
 *     cdef clear(self):
 *         self.num_lines = 0
 *         self.text_index = 0             # <<<<<<<<<<<<<<
 *         self.text_ptr = self.text_buffer_data
 * 
 */
  __pyx_v_self->text_index = 0;

  /* "libudis/libudis.pyx":87
 *         self.num_lines = 0
 *         self.text_index = 0
 *         self.text_ptr = self.text_buffer_data             # <<<<<<<<<<<<<<
 * 
 *     cdef store(self, int count):
 */
  __pyx_t_1 = __pyx_v_self->text_buffer_data;
  __pyx_v_self->text_ptr = __pyx_t_1;

  /* "libudis/libudis.pyx":84
 *             yield self.text_buffer[start:start + count].tostring()
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.num_lines = 0
 *         self.text_index = 0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":89
 *         self.text_ptr = self.text_buffer_data
 * 
 *     cdef store(self, int count):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_11TextStorage_store(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, int __pyx_v_count) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_UCS4 __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  __pyx_t_5numpy_uint32_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("store", 0);

  /* "libudis/libudis.pyx":93
 *         cdef int i
 * 
 *         i = self.num_lines             # <<<<<<<<<<<<<<
 *         if i >= self.max_lines:
 *             print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in TextStorage, attempted to save {i} lines")
 */
  __pyx_t_1 = __pyx_v_self->num_lines;
  __pyx_v_i = __pyx_t_1;

  /* "libudis/libudis.pyx":94
 * 
 *         i = self.num_lines
 *         if i >= self.max_lines:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in TextStorage, attempted to save {i} lines")
 *         info = &self.label_info_data[i]
 */
  __pyx_t_2 = ((__pyx_v_i >= __pyx_v_self->max_lines) != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":95
 *         i = self.num_lines
 *         if i >= self.max_lines:
 *             print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in TextStorage, attempted to save {i} lines")             # <<<<<<<<<<<<<<
 *         info = &self.label_info_data[i]
 *         info.line_length = count
 */
    __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co);
    __pyx_t_4 += 37;
    __Pyx_GIVEREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_self->max_lines, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_exceeded_in_TextStorage_attempt);
    __pyx_t_4 += 44;
    __Pyx_GIVEREF(__pyx_kp_u_exceeded_in_TextStorage_attempt);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_exceeded_in_TextStorage_attempt);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_i, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_lines);
    __pyx_t_4 += 6;
    __Pyx_GIVEREF(__pyx_kp_u_lines);
    PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_kp_u_lines);
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_3, 5, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":94
 * 
 *         i = self.num_lines
 *         if i >= self.max_lines:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in TextStorage, attempted to save {i} lines")
 *         info = &self.label_info_data[i]
 */
  }

  /* "libudis/libudis.pyx":96
 *         if i >= self.max_lines:
 *             print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in TextStorage, attempted to save {i} lines")
 *         info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *         info.line_length = count
 *         info.text_start_index = self.text_index
 */
  __pyx_v_info = (&(__pyx_v_self->label_info_data[__pyx_v_i]));

  /* "libudis/libudis.pyx":97
 *             print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in TextStorage, attempted to save {i} lines")
 *         info = &self.label_info_data[i]
 *         info.line_length = count             # <<<<<<<<<<<<<<
 *         info.text_start_index = self.text_index
 *         self.text_index += count
 */
  __pyx_v_info->line_length = __pyx_v_count;

  /* "libudis/libudis.pyx":98
 *         info = &self.label_info_data[i]
 *         info.line_length = count
 *         info.text_start_index = self.text_index             # <<<<<<<<<<<<<<
 *         self.text_index += count
 *         self.text_ptr += count
 */
  __pyx_t_7 = __pyx_v_self->text_index;
  __pyx_v_info->text_start_index = __pyx_t_7;

  /* "libudis/libudis.pyx":99
 *         info.line_length = count
 *         info.text_start_index = self.text_index
 *         self.text_index += count             # <<<<<<<<<<<<<<
 *         self.text_ptr += count
 *         self.num_lines += 1
 */
  __pyx_v_self->text_index = (__pyx_v_self->text_index + __pyx_v_count);

  /* "libudis/libudis.pyx":100
 *         info.text_start_index = self.text_index
 *         self.text_index += count
 *         self.text_ptr += count             # <<<<<<<<<<<<<<
 *         self.num_lines += 1
 *         if self.text_index >= self.text_buffer_size:
 */
  __pyx_v_self->text_ptr = (__pyx_v_self->text_ptr + __pyx_v_count);

  /* "libudis/libudis.pyx":101
 *         self.text_index += count
 *         self.text_ptr += count
 *         self.num_lines += 1             # <<<<<<<<<<<<<<
 *         if self.text_index >= self.text_buffer_size:
 *             print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in TextStorage, attempted to save {self.text_index} bytes")
 */
  __pyx_v_self->num_lines = (__pyx_v_self->num_lines + 1);

  /* "libudis/libudis.pyx":102
 *         self.text_ptr += count
 *         self.num_lines += 1
 *         if self.text_index >= self.text_buffer_size:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in TextStorage, attempted to save {self.text_index} bytes")
 *         #print(f"stored line {i}, max={self.max_lines}, storage: index={self.text_index}, max={self.text_buffer_size}")
 */
  __pyx_t_2 = ((__pyx_v_self->text_index >= __pyx_v_self->text_buffer_size) != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":103
 *         self.num_lines += 1
 *         if self.text_index >= self.text_buffer_size:
 *             print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in TextStorage, attempted to save {self.text_index} bytes")             # <<<<<<<<<<<<<<
 *         #print(f"stored line {i}, max={self.max_lines}, storage: index={self.text_index}, max={self.text_buffer_size}")
 * 
 */
    __pyx_t_3 = PyTuple_New(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_5 = 127;
    __Pyx_INCREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_size);
    __pyx_t_4 += 31;
    __Pyx_GIVEREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_size);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_CYTHON_ERROR_Text_buffer_size);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_self->text_buffer_size, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_exceeded_in_TextStorage_attempt);
    __pyx_t_4 += 44;
    __Pyx_GIVEREF(__pyx_kp_u_exceeded_in_TextStorage_attempt);
    PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u_exceeded_in_TextStorage_attempt);
    __pyx_t_6 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->text_index); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_5 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) > __pyx_t_5) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_8) : __pyx_t_5;
    __pyx_t_4 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_t_8);
    __pyx_t_8 = 0;
    __Pyx_INCREF(__pyx_kp_u_bytes);
    __pyx_t_4 += 6;
    __Pyx_GIVEREF(__pyx_kp_u_bytes);
    PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_kp_u_bytes);
    __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_3, 5, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":102
 *         self.text_ptr += count
 *         self.num_lines += 1
 *         if self.text_index >= self.text_buffer_size:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in TextStorage, attempted to save {self.text_index} bytes")
 *         #print(f"stored line {i}, max={self.max_lines}, storage: index={self.text_index}, max={self.text_buffer_size}")
 */
  }

  /* "libudis/libudis.pyx":89
 *         self.text_ptr = self.text_buffer_data
 * 
 *     cdef store(self, int count):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.store", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":106
 *         #print(f"stored line {i}, max={self.max_lines}, storage: index={self.text_index}, max={self.text_buffer_size}")
 * 
 *     def get_label_data_addr(self):             # <<<<<<<<<<<<<<
 *         return long(<long>&self.label_info_data[0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_14get_label_data_addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_14get_label_data_addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_label_data_addr (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_13get_label_data_addr(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_13get_label_data_addr(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_label_data_addr", 0);

  /* "libudis/libudis.pyx":107
 * 
 *     def get_label_data_addr(self):
 *         return long(<long>&self.label_info_data[0])             # <<<<<<<<<<<<<<
 * 
 *     def get_text_storage_addr(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(((long)(&(__pyx_v_self->label_info_data[0])))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyLong_Type)), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":106
 *         #print(f"stored line {i}, max={self.max_lines}, storage: index={self.text_index}, max={self.text_buffer_size}")
 * 
 *     def get_label_data_addr(self):             # <<<<<<<<<<<<<<
 *         return long(<long>&self.label_info_data[0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.get_label_data_addr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":109
 *         return long(<long>&self.label_info_data[0])
 * 
 *     def get_text_storage_addr(self):             # <<<<<<<<<<<<<<
 *         return long(<long>&self.text_buffer_data[0])
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_16get_text_storage_addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_16get_text_storage_addr(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_text_storage_addr (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_15get_text_storage_addr(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_15get_text_storage_addr(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_text_storage_addr", 0);

  /* "libudis/libudis.pyx":110
 * 
 *     def get_text_storage_addr(self):
 *         return long(<long>&self.text_buffer_data[0])             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_long(((long)(&(__pyx_v_self->text_buffer_data[0])))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyLong_Type)), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":109
 *         return long(<long>&self.label_info_data[0])
 * 
 *     def get_text_storage_addr(self):             # <<<<<<<<<<<<<<
 *         return long(<long>&self.text_buffer_data[0])
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.get_text_storage_addr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":24
 * cdef class TextStorage:
 *     cdef int max_lines
 *     cdef public int num_lines             # <<<<<<<<<<<<<<
 *     cdef public np.ndarray label_info
 *     cdef label_info_t *label_info_data
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->num_lines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.num_lines.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 24, __pyx_L1_error)
  __pyx_v_self->num_lines = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.num_lines.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":25
 *     cdef int max_lines
 *     cdef public int num_lines
 *     cdef public np.ndarray label_info             # <<<<<<<<<<<<<<
 *     cdef label_info_t *label_info_data
 *     cdef public np.ndarray text_buffer
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->label_info));
  __pyx_r = ((PyObject *)__pyx_v_self->label_info);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 25, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->label_info);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->label_info));
  __pyx_v_self->label_info = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.label_info.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->label_info);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->label_info));
  __pyx_v_self->label_info = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":27
 *     cdef public np.ndarray label_info
 *     cdef label_info_t *label_info_data
 *     cdef public np.ndarray text_buffer             # <<<<<<<<<<<<<<
 *     cdef char *text_buffer_data
 *     cdef int text_buffer_size
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->text_buffer));
  __pyx_r = ((PyObject *)__pyx_v_self->text_buffer);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 27, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->text_buffer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->text_buffer));
  __pyx_v_self->text_buffer = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.text_buffer.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->text_buffer);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->text_buffer));
  __pyx_v_self->text_buffer = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_18__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_18__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_17__reduce_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_17__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_20__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_20__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_19__setstate_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_11TextStorage_19__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.TextStorage.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":114
 * 
 * cdef class LabelStorage(TextStorage):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         TextStorage.__init__(self, 256*256, 256*256)
 * 
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage___init__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "libudis/libudis.pyx":115
 * cdef class LabelStorage(TextStorage):
 *     def __init__(self):
 *         TextStorage.__init__(self, 256*256, 256*256)             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, index):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage), __pyx_n_s_init); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_4 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_int_65536, __pyx_int_65536};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[4] = {__pyx_t_3, ((PyObject *)__pyx_v_self), __pyx_int_65536, __pyx_int_65536};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_4, 3+__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_5 = PyTuple_New(3+__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__pyx_t_3) {
      __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3); __pyx_t_3 = NULL;
    }
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    PyTuple_SET_ITEM(__pyx_t_5, 0+__pyx_t_4, ((PyObject *)__pyx_v_self));
    __Pyx_INCREF(__pyx_int_65536);
    __Pyx_GIVEREF(__pyx_int_65536);
    PyTuple_SET_ITEM(__pyx_t_5, 1+__pyx_t_4, __pyx_int_65536);
    __Pyx_INCREF(__pyx_int_65536);
    __Pyx_GIVEREF(__pyx_int_65536);
    PyTuple_SET_ITEM(__pyx_t_5, 2+__pyx_t_4, __pyx_int_65536);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":114
 * 
 * cdef class LabelStorage(TextStorage):
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         TextStorage.__init__(self, 256*256, 256*256)
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":117
 *         TextStorage.__init__(self, 256*256, 256*256)
 * 
 *     def __contains__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i = index
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_3__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_3__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_2__contains__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_2__contains__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__contains__", 0);

  /* "libudis/libudis.pyx":119
 *     def __contains__(self, index):
 *         cdef label_info_t *info
 *         cdef int i = index             # <<<<<<<<<<<<<<
 * 
 *         info = &self.label_info_data[i]
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_index); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 119, __pyx_L1_error)
  __pyx_v_i = __pyx_t_1;

  /* "libudis/libudis.pyx":121
 *         cdef int i = index
 * 
 *         info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *         return info.text_start_index > 0
 * 
 */
  __pyx_v_info = (&(__pyx_v_self->__pyx_base.label_info_data[__pyx_v_i]));

  /* "libudis/libudis.pyx":122
 * 
 *         info = &self.label_info_data[i]
 *         return info.text_start_index > 0             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, index):
 */
  __pyx_r = (__pyx_v_info->text_start_index > 0);
  goto __pyx_L0;

  /* "libudis/libudis.pyx":117
 *         TextStorage.__init__(self, 256*256, 256*256)
 * 
 *     def __contains__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i = index
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":124
 *         return info.text_start_index > 0
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_4__getitem__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  int __pyx_v_start;
  int __pyx_v_count;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __pyx_t_5numpy_uint32_t __pyx_t_4;
  __pyx_t_5numpy_int8_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "libudis/libudis.pyx":129
 *         cdef np.uint8_t num_bytes, item_count, type_code
 * 
 *         if isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             info = &self.label_info_data[i]
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":130
 * 
 *         if isinstance(index, int):
 *             i = index             # <<<<<<<<<<<<<<
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index
 */
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_index); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 130, __pyx_L1_error)
    __pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":131
 *         if isinstance(index, int):
 *             i = index
 *             info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *             start = info.text_start_index
 *             count = info.line_length
 */
    __pyx_v_info = (&(__pyx_v_self->__pyx_base.label_info_data[__pyx_v_i]));

    /* "libudis/libudis.pyx":132
 *             i = index
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index             # <<<<<<<<<<<<<<
 *             count = info.line_length
 *             return (self.text_buffer[start:start + count].tostring(), info.num_bytes, info.item_count, info.type_code)
 */
    __pyx_t_4 = __pyx_v_info->text_start_index;
    __pyx_v_start = __pyx_t_4;

    /* "libudis/libudis.pyx":133
 *             info = &self.label_info_data[i]
 *             start = info.text_start_index
 *             count = info.line_length             # <<<<<<<<<<<<<<
 *             return (self.text_buffer[start:start + count].tostring(), info.num_bytes, info.item_count, info.type_code)
 *         elif isinstance(index, slice):
 */
    __pyx_t_5 = __pyx_v_info->line_length;
    __pyx_v_count = __pyx_t_5;

    /* "libudis/libudis.pyx":134
 *             start = info.text_start_index
 *             count = info.line_length
 *             return (self.text_buffer[start:start + count].tostring(), info.num_bytes, info.item_count, info.type_code)             # <<<<<<<<<<<<<<
 *         elif isinstance(index, slice):
 *             raise TypeError(f"slicing not yet supported")
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_7 = __Pyx_PyObject_GetSlice(((PyObject *)__pyx_v_self->__pyx_base.text_buffer), __pyx_v_start, (__pyx_v_start + __pyx_v_count), NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_tostring); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_6 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->num_bytes); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_7 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->item_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->type_code); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = PyTuple_New(4); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 134, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_10, 1, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_10, 2, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_10, 3, __pyx_t_9);
    __pyx_t_6 = 0;
    __pyx_t_8 = 0;
    __pyx_t_7 = 0;
    __pyx_t_9 = 0;
    __pyx_r = __pyx_t_10;
    __pyx_t_10 = 0;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":129
 *         cdef np.uint8_t num_bytes, item_count, type_code
 * 
 *         if isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             info = &self.label_info_data[i]
 */
  }

  /* "libudis/libudis.pyx":135
 *             count = info.line_length
 *             return (self.text_buffer[start:start + count].tostring(), info.num_bytes, info.item_count, info.type_code)
 *         elif isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"slicing not yet supported")
 *         else:
 */
  __pyx_t_2 = PySlice_Check(__pyx_v_index); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (unlikely(__pyx_t_1)) {

    /* "libudis/libudis.pyx":136
 *             return (self.text_buffer[start:start + count].tostring(), info.num_bytes, info.item_count, info.type_code)
 *         elif isinstance(index, slice):
 *             raise TypeError(f"slicing not yet supported")             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 136, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_Raise(__pyx_t_10, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __PYX_ERR(0, 136, __pyx_L1_error)

    /* "libudis/libudis.pyx":135
 *             count = info.line_length
 *             return (self.text_buffer[start:start + count].tostring(), info.num_bytes, info.item_count, info.type_code)
 *         elif isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"slicing not yet supported")
 *         else:
 */
  }

  /* "libudis/libudis.pyx":138
 *             raise TypeError(f"slicing not yet supported")
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  /*else*/ {
    __pyx_t_10 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_index)), __pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_10 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_Raise(__pyx_t_10, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __PYX_ERR(0, 138, __pyx_L1_error)
  }

  /* "libudis/libudis.pyx":124
 *         return info.text_start_index > 0
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_12LabelStorage_8generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "libudis/libudis.pyx":140
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef label_info_t *info
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_7__iter__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_7__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_6__iter__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *)__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__(__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 140, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8omnivore_12disassembler_7libudis_12LabelStorage_8generator1, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_LabelStorage___iter, __pyx_n_s_omnivore_disassembler_libudis); if (unlikely(!gen)) __PYX_ERR(0, 140, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_12LabelStorage_8generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *__pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L7_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 140, __pyx_L1_error)

  /* "libudis/libudis.pyx":143
 *         cdef int i
 *         cdef label_info_t *info
 *         info = &self.label_info_data[0]             # <<<<<<<<<<<<<<
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:
 */
  __pyx_cur_scope->__pyx_v_info = (&(__pyx_cur_scope->__pyx_v_self->__pyx_base.label_info_data[0]));

  /* "libudis/libudis.pyx":144
 *         cdef label_info_t *info
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):             # <<<<<<<<<<<<<<
 *             if info.text_start_index > 0:
 *                 yield self[i]
 */
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_self->__pyx_base.max_lines;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_cur_scope->__pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":145
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:             # <<<<<<<<<<<<<<
 *                 yield self[i]
 *             info += 1
 */
    __pyx_t_4 = ((__pyx_cur_scope->__pyx_v_info->text_start_index > 0) != 0);
    if (__pyx_t_4) {

      /* "libudis/libudis.pyx":146
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:
 *                 yield self[i]             # <<<<<<<<<<<<<<
 *             info += 1
 * 
 */
      __pyx_t_5 = __Pyx_GetItemInt(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_cur_scope->__pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 146, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
      __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
      __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L7_resume_from_yield:;
      __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
      __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
      __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 146, __pyx_L1_error)

      /* "libudis/libudis.pyx":145
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:             # <<<<<<<<<<<<<<
 *                 yield self[i]
 *             info += 1
 */
    }

    /* "libudis/libudis.pyx":147
 *             if info.text_start_index > 0:
 *                 yield self[i]
 *             info += 1             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, index, value):
 */
    __pyx_cur_scope->__pyx_v_info = (__pyx_cur_scope->__pyx_v_info + 1);
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "libudis/libudis.pyx":140
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef label_info_t *info
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":149
 *             info += 1
 * 
 *     def __setitem__(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_10__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_10__setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_9__setitem__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_9__setitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  int __pyx_v_start;
  int __pyx_v_count;
  __pyx_t_5numpy_uint8_t __pyx_v_num_bytes;
  __pyx_t_5numpy_uint8_t __pyx_v_item_count;
  __pyx_t_5numpy_uint8_t __pyx_v_type_code;
  PyObject *__pyx_v_desc_code = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __pyx_t_5numpy_uint32_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *(*__pyx_t_17)(PyObject *);
  __pyx_t_5numpy_uint8_t __pyx_t_18;
  __pyx_t_5numpy_uint8_t __pyx_t_19;
  __pyx_t_5numpy_uint8_t __pyx_t_20;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  Py_ssize_t __pyx_t_23;
  Py_UCS4 __pyx_t_24;
  __pyx_t_5numpy_int8_t __pyx_t_25;
  int __pyx_t_26;
  int __pyx_t_27;
  __Pyx_RefNannySetupContext("__setitem__", 0);
  __Pyx_INCREF(__pyx_v_value);

  /* "libudis/libudis.pyx":154
 *         cdef np.uint8_t num_bytes, item_count, type_code
 * 
 *         if isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             start = self.text_index
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":155
 * 
 *         if isinstance(index, int):
 *             i = index             # <<<<<<<<<<<<<<
 *             start = self.text_index
 *             try:
 */
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_index); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 155, __pyx_L1_error)
    __pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":156
 *         if isinstance(index, int):
 *             i = index
 *             start = self.text_index             # <<<<<<<<<<<<<<
 *             try:
 *                 if isinstance(value, bytes):
 */
    __pyx_t_4 = __pyx_v_self->__pyx_base.text_index;
    __pyx_v_start = __pyx_t_4;

    /* "libudis/libudis.pyx":157
 *             i = index
 *             start = self.text_index
 *             try:             # <<<<<<<<<<<<<<
 *                 if isinstance(value, bytes):
 *                     raise ValueError
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "libudis/libudis.pyx":158
 *             start = self.text_index
 *             try:
 *                 if isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *                     raise ValueError
 *                 try:
 */
        __pyx_t_2 = PyBytes_Check(__pyx_v_value); 
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (unlikely(__pyx_t_1)) {

          /* "libudis/libudis.pyx":159
 *             try:
 *                 if isinstance(value, bytes):
 *                     raise ValueError             # <<<<<<<<<<<<<<
 *                 try:
 *                     value, num_bytes, item_count, type_code, desc_code = value
 */
          __Pyx_Raise(__pyx_builtin_ValueError, 0, 0, 0);
          __PYX_ERR(0, 159, __pyx_L4_error)

          /* "libudis/libudis.pyx":158
 *             start = self.text_index
 *             try:
 *                 if isinstance(value, bytes):             # <<<<<<<<<<<<<<
 *                     raise ValueError
 *                 try:
 */
        }

        /* "libudis/libudis.pyx":160
 *                 if isinstance(value, bytes):
 *                     raise ValueError
 *                 try:             # <<<<<<<<<<<<<<
 *                     value, num_bytes, item_count, type_code, desc_code = value
 *                 except ValueError:
 */
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_8);
          __Pyx_XGOTREF(__pyx_t_9);
          __Pyx_XGOTREF(__pyx_t_10);
          /*try:*/ {

            /* "libudis/libudis.pyx":161
 *                     raise ValueError
 *                 try:
 *                     value, num_bytes, item_count, type_code, desc_code = value             # <<<<<<<<<<<<<<
 *                 except ValueError:
 *                     value, num_bytes, item_count, type_code = value
 */
            if ((likely(PyTuple_CheckExact(__pyx_v_value))) || (PyList_CheckExact(__pyx_v_value))) {
              PyObject* sequence = __pyx_v_value;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 5)) {
                if (size > 5) __Pyx_RaiseTooManyValuesError(5);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 161, __pyx_L11_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_11 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_12 = PyTuple_GET_ITEM(sequence, 1); 
                __pyx_t_13 = PyTuple_GET_ITEM(sequence, 2); 
                __pyx_t_14 = PyTuple_GET_ITEM(sequence, 3); 
                __pyx_t_15 = PyTuple_GET_ITEM(sequence, 4); 
              } else {
                __pyx_t_11 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_12 = PyList_GET_ITEM(sequence, 1); 
                __pyx_t_13 = PyList_GET_ITEM(sequence, 2); 
                __pyx_t_14 = PyList_GET_ITEM(sequence, 3); 
                __pyx_t_15 = PyList_GET_ITEM(sequence, 4); 
              }
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_14);
              __Pyx_INCREF(__pyx_t_15);
              #else
              {
                Py_ssize_t i;
                PyObject** temps[5] = {&__pyx_t_11,&__pyx_t_12,&__pyx_t_13,&__pyx_t_14,&__pyx_t_15};
                for (i=0; i < 5; i++) {
                  PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 161, __pyx_L11_error)
                  __Pyx_GOTREF(item);
                  *(temps[i]) = item;
                }
              }
              #endif
            } else {
              Py_ssize_t index = -1;
              PyObject** temps[5] = {&__pyx_t_11,&__pyx_t_12,&__pyx_t_13,&__pyx_t_14,&__pyx_t_15};
              __pyx_t_16 = PyObject_GetIter(__pyx_v_value); if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 161, __pyx_L11_error)
              __Pyx_GOTREF(__pyx_t_16);
              __pyx_t_17 = Py_TYPE(__pyx_t_16)->tp_iternext;
              for (index=0; index < 5; index++) {
                PyObject* item = __pyx_t_17(__pyx_t_16); if (unlikely(!item)) goto __pyx_L17_unpacking_failed;
                __Pyx_GOTREF(item);
                *(temps[index]) = item;
              }
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_17(__pyx_t_16), 5) < 0) __PYX_ERR(0, 161, __pyx_L11_error)
              __pyx_t_17 = NULL;
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              goto __pyx_L18_unpacking_done;
              __pyx_L17_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
              __pyx_t_17 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 161, __pyx_L11_error)
              __pyx_L18_unpacking_done:;
            }
            __pyx_t_18 = __Pyx_PyInt_As_npy_uint8(__pyx_t_12); if (unlikely((__pyx_t_18 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 161, __pyx_L11_error)
            __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
            __pyx_t_19 = __Pyx_PyInt_As_npy_uint8(__pyx_t_13); if (unlikely((__pyx_t_19 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 161, __pyx_L11_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_20 = __Pyx_PyInt_As_npy_uint8(__pyx_t_14); if (unlikely((__pyx_t_20 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 161, __pyx_L11_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_11);
            __pyx_t_11 = 0;
            __pyx_v_num_bytes = __pyx_t_18;
            __pyx_v_item_count = __pyx_t_19;
            __pyx_v_type_code = __pyx_t_20;
            __pyx_v_desc_code = __pyx_t_15;
            __pyx_t_15 = 0;

            /* "libudis/libudis.pyx":160
 *                 if isinstance(value, bytes):
 *                     raise ValueError
 *                 try:             # <<<<<<<<<<<<<<
 *                     value, num_bytes, item_count, type_code, desc_code = value
 *                 except ValueError:
 */
          }
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          goto __pyx_L16_try_end;
          __pyx_L11_error:;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;

          /* "libudis/libudis.pyx":162
 *                 try:
 *                     value, num_bytes, item_count, type_code, desc_code = value
 *                 except ValueError:             # <<<<<<<<<<<<<<
 *                     value, num_bytes, item_count, type_code = value
 *                     desc_code = type_code
 */
          __pyx_t_3 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
          if (__pyx_t_3) {
            __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
            if (__Pyx_GetException(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13) < 0) __PYX_ERR(0, 162, __pyx_L13_except_error)
            __Pyx_GOTREF(__pyx_t_15);
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_GOTREF(__pyx_t_13);

            /* "libudis/libudis.pyx":163
 *                     value, num_bytes, item_count, type_code, desc_code = value
 *                 except ValueError:
 *                     value, num_bytes, item_count, type_code = value             # <<<<<<<<<<<<<<
 *                     desc_code = type_code
 *             except ValueError:
 */
            if ((likely(PyTuple_CheckExact(__pyx_v_value))) || (PyList_CheckExact(__pyx_v_value))) {
              PyObject* sequence = __pyx_v_value;
              Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
              if (unlikely(size != 4)) {
                if (size > 4) __Pyx_RaiseTooManyValuesError(4);
                else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
                __PYX_ERR(0, 163, __pyx_L13_except_error)
              }
              #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
              if (likely(PyTuple_CheckExact(sequence))) {
                __pyx_t_12 = PyTuple_GET_ITEM(sequence, 0); 
                __pyx_t_11 = PyTuple_GET_ITEM(sequence, 1); 
                __pyx_t_16 = PyTuple_GET_ITEM(sequence, 2); 
                __pyx_t_21 = PyTuple_GET_ITEM(sequence, 3); 
              } else {
                __pyx_t_12 = PyList_GET_ITEM(sequence, 0); 
                __pyx_t_11 = PyList_GET_ITEM(sequence, 1); 
                __pyx_t_16 = PyList_GET_ITEM(sequence, 2); 
                __pyx_t_21 = PyList_GET_ITEM(sequence, 3); 
              }
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_16);
              __Pyx_INCREF(__pyx_t_21);
              #else
              {
                Py_ssize_t i;
                PyObject** temps[4] = {&__pyx_t_12,&__pyx_t_11,&__pyx_t_16,&__pyx_t_21};
                for (i=0; i < 4; i++) {
                  PyObject* item = PySequence_ITEM(sequence, i); if (unlikely(!item)) __PYX_ERR(0, 163, __pyx_L13_except_error)
                  __Pyx_GOTREF(item);
                  *(temps[i]) = item;
                }
              }
              #endif
            } else {
              Py_ssize_t index = -1;
              PyObject** temps[4] = {&__pyx_t_12,&__pyx_t_11,&__pyx_t_16,&__pyx_t_21};
              __pyx_t_22 = PyObject_GetIter(__pyx_v_value); if (unlikely(!__pyx_t_22)) __PYX_ERR(0, 163, __pyx_L13_except_error)
              __Pyx_GOTREF(__pyx_t_22);
              __pyx_t_17 = Py_TYPE(__pyx_t_22)->tp_iternext;
              for (index=0; index < 4; index++) {
                PyObject* item = __pyx_t_17(__pyx_t_22); if (unlikely(!item)) goto __pyx_L21_unpacking_failed;
                __Pyx_GOTREF(item);
                *(temps[index]) = item;
              }
              if (__Pyx_IternextUnpackEndCheck(__pyx_t_17(__pyx_t_22), 4) < 0) __PYX_ERR(0, 163, __pyx_L13_except_error)
              __pyx_t_17 = NULL;
              __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
              goto __pyx_L22_unpacking_done;
              __pyx_L21_unpacking_failed:;
              __Pyx_DECREF(__pyx_t_22); __pyx_t_22 = 0;
              __pyx_t_17 = NULL;
              if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
              __PYX_ERR(0, 163, __pyx_L13_except_error)
              __pyx_L22_unpacking_done:;
            }
            __pyx_t_20 = __Pyx_PyInt_As_npy_uint8(__pyx_t_11); if (unlikely((__pyx_t_20 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 163, __pyx_L13_except_error)
            __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
            __pyx_t_19 = __Pyx_PyInt_As_npy_uint8(__pyx_t_16); if (unlikely((__pyx_t_19 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 163, __pyx_L13_except_error)
            __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
            __pyx_t_18 = __Pyx_PyInt_As_npy_uint8(__pyx_t_21); if (unlikely((__pyx_t_18 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 163, __pyx_L13_except_error)
            __Pyx_DECREF(__pyx_t_21); __pyx_t_21 = 0;
            __Pyx_DECREF_SET(__pyx_v_value, __pyx_t_12);
            __pyx_t_12 = 0;
            __pyx_v_num_bytes = __pyx_t_20;
            __pyx_v_item_count = __pyx_t_19;
            __pyx_v_type_code = __pyx_t_18;

            /* "libudis/libudis.pyx":164
 *                 except ValueError:
 *                     value, num_bytes, item_count, type_code = value
 *                     desc_code = type_code             # <<<<<<<<<<<<<<
 *             except ValueError:
 *                 num_bytes = 1
 */
            __pyx_t_21 = __Pyx_PyInt_From_npy_uint8(__pyx_v_type_code); if (unlikely(!__pyx_t_21)) __PYX_ERR(0, 164, __pyx_L13_except_error)
            __Pyx_GOTREF(__pyx_t_21);
            __Pyx_XDECREF_SET(__pyx_v_desc_code, __pyx_t_21);
            __pyx_t_21 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            goto __pyx_L12_exception_handled;
          }
          goto __pyx_L13_except_error;
          __pyx_L13_except_error:;

          /* "libudis/libudis.pyx":160
 *                 if isinstance(value, bytes):
 *                     raise ValueError
 *                 try:             # <<<<<<<<<<<<<<
 *                     value, num_bytes, item_count, type_code, desc_code = value
 *                 except ValueError:
 */
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          goto __pyx_L4_error;
          __pyx_L12_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_8);
          __Pyx_XGIVEREF(__pyx_t_9);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
          __pyx_L16_try_end:;
        }

        /* "libudis/libudis.pyx":157
 *             i = index
 *             start = self.text_index
 *             try:             # <<<<<<<<<<<<<<
 *                 if isinstance(value, bytes):
 *                     raise ValueError
 */
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
      __Pyx_XDECREF(__pyx_t_21); __pyx_t_21 = 0;
      __Pyx_XDECREF(__pyx_t_22); __pyx_t_22 = 0;

      /* "libudis/libudis.pyx":165
 *                     value, num_bytes, item_count, type_code = value
 *                     desc_code = type_code
 *             except ValueError:             # <<<<<<<<<<<<<<
 *                 num_bytes = 1
 *                 item_count = 1
 */
      __pyx_t_3 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_ValueError);
      if (__pyx_t_3) {
        __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15) < 0) __PYX_ERR(0, 165, __pyx_L6_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_GOTREF(__pyx_t_15);

        /* "libudis/libudis.pyx":166
 *                     desc_code = type_code
 *             except ValueError:
 *                 num_bytes = 1             # <<<<<<<<<<<<<<
 *                 item_count = 1
 *                 type_code = 0
 */
        __pyx_v_num_bytes = 1;

        /* "libudis/libudis.pyx":167
 *             except ValueError:
 *                 num_bytes = 1
 *                 item_count = 1             # <<<<<<<<<<<<<<
 *                 type_code = 0
 *                 desc_code = 0
 */
        __pyx_v_item_count = 1;

        /* "libudis/libudis.pyx":168
 *                 num_bytes = 1
 *                 item_count = 1
 *                 type_code = 0             # <<<<<<<<<<<<<<
 *                 desc_code = 0
 *             count = len(value)
 */
        __pyx_v_type_code = 0;

        /* "libudis/libudis.pyx":169
 *                 item_count = 1
 *                 type_code = 0
 *                 desc_code = 0             # <<<<<<<<<<<<<<
 *             count = len(value)
 *             if i >= self.max_lines:
 */
        __Pyx_INCREF(__pyx_int_0);
        __Pyx_XDECREF_SET(__pyx_v_desc_code, __pyx_int_0);
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        goto __pyx_L5_exception_handled;
      }
      goto __pyx_L6_except_error;
      __pyx_L6_except_error:;

      /* "libudis/libudis.pyx":157
 *             i = index
 *             start = self.text_index
 *             try:             # <<<<<<<<<<<<<<
 *                 if isinstance(value, bytes):
 *                     raise ValueError
 */
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L5_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L9_try_end:;
    }

    /* "libudis/libudis.pyx":170
 *                 type_code = 0
 *                 desc_code = 0
 *             count = len(value)             # <<<<<<<<<<<<<<
 *             if i >= self.max_lines:
 *                 print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in LabelStorage, attempted to save {i} lines")
 */
    __pyx_t_23 = PyObject_Length(__pyx_v_value); if (unlikely(__pyx_t_23 == ((Py_ssize_t)-1))) __PYX_ERR(0, 170, __pyx_L1_error)
    __pyx_v_count = __pyx_t_23;

    /* "libudis/libudis.pyx":171
 *                 desc_code = 0
 *             count = len(value)
 *             if i >= self.max_lines:             # <<<<<<<<<<<<<<
 *                 print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in LabelStorage, attempted to save {i} lines")
 *             if start + count >= self.text_buffer_size:
 */
    __pyx_t_1 = ((__pyx_v_i >= __pyx_v_self->__pyx_base.max_lines) != 0);
    if (__pyx_t_1) {

      /* "libudis/libudis.pyx":172
 *             count = len(value)
 *             if i >= self.max_lines:
 *                 print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in LabelStorage, attempted to save {i} lines")             # <<<<<<<<<<<<<<
 *             if start + count >= self.text_buffer_size:
 *                 print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in LabelStorage, attempted to save {start + count} bytes")
 */
      __pyx_t_15 = PyTuple_New(5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_23 = 0;
      __pyx_t_24 = 127;
      __Pyx_INCREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co);
      __pyx_t_23 += 37;
      __Pyx_GIVEREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co);
      __pyx_t_14 = __Pyx_PyUnicode_From_int(__pyx_v_self->__pyx_base.max_lines, 0, ' ', 'd'); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_23 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u_exceeded_in_LabelStorage_attemp);
      __pyx_t_23 += 45;
      __Pyx_GIVEREF(__pyx_kp_u_exceeded_in_LabelStorage_attemp);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_kp_u_exceeded_in_LabelStorage_attemp);
      __pyx_t_14 = __Pyx_PyUnicode_From_int(__pyx_v_i, 0, ' ', 'd'); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_23 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_15, 3, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u_lines);
      __pyx_t_23 += 6;
      __Pyx_GIVEREF(__pyx_kp_u_lines);
      PyTuple_SET_ITEM(__pyx_t_15, 4, __pyx_kp_u_lines);
      __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_15, 5, __pyx_t_23, __pyx_t_24); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 172, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

      /* "libudis/libudis.pyx":171
 *                 desc_code = 0
 *             count = len(value)
 *             if i >= self.max_lines:             # <<<<<<<<<<<<<<
 *                 print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in LabelStorage, attempted to save {i} lines")
 *             if start + count >= self.text_buffer_size:
 */
    }

    /* "libudis/libudis.pyx":173
 *             if i >= self.max_lines:
 *                 print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in LabelStorage, attempted to save {i} lines")
 *             if start + count >= self.text_buffer_size:             # <<<<<<<<<<<<<<
 *                 print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in LabelStorage, attempted to save {start + count} bytes")
 *             info = &self.label_info_data[i]
 */
    __pyx_t_1 = (((__pyx_v_start + __pyx_v_count) >= __pyx_v_self->__pyx_base.text_buffer_size) != 0);
    if (__pyx_t_1) {

      /* "libudis/libudis.pyx":174
 *                 print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in LabelStorage, attempted to save {i} lines")
 *             if start + count >= self.text_buffer_size:
 *                 print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in LabelStorage, attempted to save {start + count} bytes")             # <<<<<<<<<<<<<<
 *             info = &self.label_info_data[i]
 *             info.line_length = count
 */
      __pyx_t_15 = PyTuple_New(5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_23 = 0;
      __pyx_t_24 = 127;
      __Pyx_INCREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_size);
      __pyx_t_23 += 31;
      __Pyx_GIVEREF(__pyx_kp_u_CYTHON_ERROR_Text_buffer_size);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u_CYTHON_ERROR_Text_buffer_size);
      __pyx_t_14 = __Pyx_PyUnicode_From_int(__pyx_v_self->__pyx_base.text_buffer_size, 0, ' ', 'd'); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_23 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u_exceeded_in_LabelStorage_attemp);
      __pyx_t_23 += 45;
      __Pyx_GIVEREF(__pyx_kp_u_exceeded_in_LabelStorage_attemp);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_kp_u_exceeded_in_LabelStorage_attemp);
      __pyx_t_14 = __Pyx_PyUnicode_From_int((__pyx_v_start + __pyx_v_count), 0, ' ', 'd'); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_23 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_14);
      __Pyx_GIVEREF(__pyx_t_14);
      PyTuple_SET_ITEM(__pyx_t_15, 3, __pyx_t_14);
      __pyx_t_14 = 0;
      __Pyx_INCREF(__pyx_kp_u_bytes);
      __pyx_t_23 += 6;
      __Pyx_GIVEREF(__pyx_kp_u_bytes);
      PyTuple_SET_ITEM(__pyx_t_15, 4, __pyx_kp_u_bytes);
      __pyx_t_14 = __Pyx_PyUnicode_Join(__pyx_t_15, 5, __pyx_t_23, __pyx_t_24); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 174, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

      /* "libudis/libudis.pyx":173
 *             if i >= self.max_lines:
 *                 print(f"CYTHON ERROR! Text buffer line count {self.max_lines} exceeded in LabelStorage, attempted to save {i} lines")
 *             if start + count >= self.text_buffer_size:             # <<<<<<<<<<<<<<
 *                 print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in LabelStorage, attempted to save {start + count} bytes")
 *             info = &self.label_info_data[i]
 */
    }

    /* "libudis/libudis.pyx":175
 *             if start + count >= self.text_buffer_size:
 *                 print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in LabelStorage, attempted to save {start + count} bytes")
 *             info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *             info.line_length = count
 *             info.text_start_index = self.text_index
 */
    __pyx_v_info = (&(__pyx_v_self->__pyx_base.label_info_data[__pyx_v_i]));

    /* "libudis/libudis.pyx":176
 *                 print(f"CYTHON ERROR! Text buffer size {self.text_buffer_size} exceeded in LabelStorage, attempted to save {start + count} bytes")
 *             info = &self.label_info_data[i]
 *             info.line_length = count             # <<<<<<<<<<<<<<
 *             info.text_start_index = self.text_index
 *             info.num_bytes = num_bytes
 */
    __pyx_v_info->line_length = __pyx_v_count;

    /* "libudis/libudis.pyx":177
 *             info = &self.label_info_data[i]
 *             info.line_length = count
 *             info.text_start_index = self.text_index             # <<<<<<<<<<<<<<
 *             info.num_bytes = num_bytes
 *             info.item_count = item_count
 */
    __pyx_t_4 = __pyx_v_self->__pyx_base.text_index;
    __pyx_v_info->text_start_index = __pyx_t_4;

    /* "libudis/libudis.pyx":178
 *             info.line_length = count
 *             info.text_start_index = self.text_index
 *             info.num_bytes = num_bytes             # <<<<<<<<<<<<<<
 *             info.item_count = item_count
 *             info.type_code = (type_code & 0x03) | desc_code
 */
    __pyx_v_info->num_bytes = __pyx_v_num_bytes;

    /* "libudis/libudis.pyx":179
 *             info.text_start_index = self.text_index
 *             info.num_bytes = num_bytes
 *             info.item_count = item_count             # <<<<<<<<<<<<<<
 *             info.type_code = (type_code & 0x03) | desc_code
 *             self.text_index += count
 */
    __pyx_v_info->item_count = __pyx_v_item_count;

    /* "libudis/libudis.pyx":180
 *             info.num_bytes = num_bytes
 *             info.item_count = item_count
 *             info.type_code = (type_code & 0x03) | desc_code             # <<<<<<<<<<<<<<
 *             self.text_index += count
 *             self.num_lines += 1
 */
    __pyx_t_15 = __Pyx_PyInt_From_long((__pyx_v_type_code & 0x03)); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = PyNumber_Or(__pyx_t_15, __pyx_v_desc_code); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __pyx_t_25 = __Pyx_PyInt_As_npy_int8(__pyx_t_14); if (unlikely((__pyx_t_25 == ((npy_int8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 180, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_v_info->type_code = __pyx_t_25;

    /* "libudis/libudis.pyx":181
 *             info.item_count = item_count
 *             info.type_code = (type_code & 0x03) | desc_code
 *             self.text_index += count             # <<<<<<<<<<<<<<
 *             self.num_lines += 1
 *             # print("assigning value", value, type(value), hex(<long>info))
 */
    __pyx_v_self->__pyx_base.text_index = (__pyx_v_self->__pyx_base.text_index + __pyx_v_count);

    /* "libudis/libudis.pyx":182
 *             info.type_code = (type_code & 0x03) | desc_code
 *             self.text_index += count
 *             self.num_lines += 1             # <<<<<<<<<<<<<<
 *             # print("assigning value", value, type(value), hex(<long>info))
 *             for i in range(count):
 */
    __pyx_v_self->__pyx_base.num_lines = (__pyx_v_self->__pyx_base.num_lines + 1);

    /* "libudis/libudis.pyx":184
 *             self.num_lines += 1
 *             # print("assigning value", value, type(value), hex(<long>info))
 *             for i in range(count):             # <<<<<<<<<<<<<<
 *                 self.text_buffer[start] = value[i]
 *                 start += 1
 */
    __pyx_t_3 = __pyx_v_count;
    __pyx_t_26 = __pyx_t_3;
    for (__pyx_t_27 = 0; __pyx_t_27 < __pyx_t_26; __pyx_t_27+=1) {
      __pyx_v_i = __pyx_t_27;

      /* "libudis/libudis.pyx":185
 *             # print("assigning value", value, type(value), hex(<long>info))
 *             for i in range(count):
 *                 self.text_buffer[start] = value[i]             # <<<<<<<<<<<<<<
 *                 start += 1
 *         elif isinstance(index, slice):
 */
      __pyx_t_14 = __Pyx_GetItemInt(__pyx_v_value, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 185, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self->__pyx_base.text_buffer), __pyx_v_start, __pyx_t_14, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0)) __PYX_ERR(0, 185, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "libudis/libudis.pyx":186
 *             for i in range(count):
 *                 self.text_buffer[start] = value[i]
 *                 start += 1             # <<<<<<<<<<<<<<
 *         elif isinstance(index, slice):
 *             raise TypeError(f"setting labels via slices not yet supported")
 */
      __pyx_v_start = (__pyx_v_start + 1);
    }

    /* "libudis/libudis.pyx":154
 *         cdef np.uint8_t num_bytes, item_count, type_code
 * 
 *         if isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             start = self.text_index
 */
    goto __pyx_L3;
  }

  /* "libudis/libudis.pyx":187
 *                 self.text_buffer[start] = value[i]
 *                 start += 1
 *         elif isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"setting labels via slices not yet supported")
 *         else:
 */
  __pyx_t_1 = PySlice_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (unlikely(__pyx_t_2)) {

    /* "libudis/libudis.pyx":188
 *                 start += 1
 *         elif isinstance(index, slice):
 *             raise TypeError(f"setting labels via slices not yet supported")             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 188, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_Raise(__pyx_t_14, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __PYX_ERR(0, 188, __pyx_L1_error)

    /* "libudis/libudis.pyx":187
 *                 self.text_buffer[start] = value[i]
 *                 start += 1
 *         elif isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"setting labels via slices not yet supported")
 *         else:
 */
  }

  /* "libudis/libudis.pyx":190
 *             raise TypeError(f"setting labels via slices not yet supported")
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")             # <<<<<<<<<<<<<<
 * 
 *     def __delitem__(self, index):
 */
  /*else*/ {
    __pyx_t_14 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_index)), __pyx_empty_unicode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_15 = __Pyx_PyUnicode_Concat(__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_t_14); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_t_14 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_Raise(__pyx_t_14, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __PYX_ERR(0, 190, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "libudis/libudis.pyx":149
 *             info += 1
 * 
 *     def __setitem__(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_21);
  __Pyx_XDECREF(__pyx_t_22);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_desc_code);
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":192
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __delitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_12__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_12__delitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__delitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_11__delitem__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_11__delitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_index) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __Pyx_RefNannySetupContext("__delitem__", 0);

  /* "libudis/libudis.pyx":196
 *         cdef int i
 * 
 *         if isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             info = &self.label_info_data[i]
 */
  __pyx_t_1 = PyInt_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":197
 * 
 *         if isinstance(index, int):
 *             i = index             # <<<<<<<<<<<<<<
 *             info = &self.label_info_data[i]
 *             info.text_start_index = 0
 */
    __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_v_index); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 197, __pyx_L1_error)
    __pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":198
 *         if isinstance(index, int):
 *             i = index
 *             info = &self.label_info_data[i]             # <<<<<<<<<<<<<<
 *             info.text_start_index = 0
 *             self.num_lines -= 1
 */
    __pyx_v_info = (&(__pyx_v_self->__pyx_base.label_info_data[__pyx_v_i]));

    /* "libudis/libudis.pyx":199
 *             i = index
 *             info = &self.label_info_data[i]
 *             info.text_start_index = 0             # <<<<<<<<<<<<<<
 *             self.num_lines -= 1
 *         elif isinstance(index, slice):
 */
    __pyx_v_info->text_start_index = 0;

    /* "libudis/libudis.pyx":200
 *             info = &self.label_info_data[i]
 *             info.text_start_index = 0
 *             self.num_lines -= 1             # <<<<<<<<<<<<<<
 *         elif isinstance(index, slice):
 *             raise TypeError(f"deleting labels via slices not yet supported")
 */
    __pyx_v_self->__pyx_base.num_lines = (__pyx_v_self->__pyx_base.num_lines - 1);

    /* "libudis/libudis.pyx":196
 *         cdef int i
 * 
 *         if isinstance(index, int):             # <<<<<<<<<<<<<<
 *             i = index
 *             info = &self.label_info_data[i]
 */
    goto __pyx_L3;
  }

  /* "libudis/libudis.pyx":201
 *             info.text_start_index = 0
 *             self.num_lines -= 1
 *         elif isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"deleting labels via slices not yet supported")
 *         else:
 */
  __pyx_t_2 = PySlice_Check(__pyx_v_index); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (unlikely(__pyx_t_1)) {

    /* "libudis/libudis.pyx":202
 *             self.num_lines -= 1
 *         elif isinstance(index, slice):
 *             raise TypeError(f"deleting labels via slices not yet supported")             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 202, __pyx_L1_error)

    /* "libudis/libudis.pyx":201
 *             info.text_start_index = 0
 *             self.num_lines -= 1
 *         elif isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             raise TypeError(f"deleting labels via slices not yet supported")
 *         else:
 */
  }

  /* "libudis/libudis.pyx":204
 *             raise TypeError(f"deleting labels via slices not yet supported")
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")             # <<<<<<<<<<<<<<
 * 
 *     def print_all(self):
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_index)), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 204, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "libudis/libudis.pyx":192
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __delitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__delitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":206
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def print_all(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_14print_all(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_14print_all(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("print_all (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_13print_all(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_13print_all(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  int __pyx_v_start;
  int __pyx_v_count;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  long __pyx_t_5;
  long __pyx_t_6;
  __pyx_t_5numpy_uint32_t __pyx_t_7;
  int __pyx_t_8;
  __pyx_t_5numpy_int8_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  __Pyx_RefNannySetupContext("print_all", 0);

  /* "libudis/libudis.pyx":210
 *         cdef int i, start, count
 * 
 *         info = &self.label_info_data[0]             # <<<<<<<<<<<<<<
 *         print("print_all", self, self.label_info.data, hex(<long>info), self.label_info)
 *         for i in range(min(5, self.max_lines)):
 */
  __pyx_v_info = (&(__pyx_v_self->__pyx_base.label_info_data[0]));

  /* "libudis/libudis.pyx":211
 * 
 *         info = &self.label_info_data[0]
 *         print("print_all", self, self.label_info.data, hex(<long>info), self.label_info)             # <<<<<<<<<<<<<<
 *         for i in range(min(5, self.max_lines)):
 *             start = info.text_start_index
 */
  __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_self->__pyx_base.label_info->data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_long(((long)__pyx_v_info)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_hex, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_u_print_all);
  __Pyx_GIVEREF(__pyx_n_u_print_all);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_n_u_print_all);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->__pyx_base.label_info));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->__pyx_base.label_info));
  PyTuple_SET_ITEM(__pyx_t_2, 4, ((PyObject *)__pyx_v_self->__pyx_base.label_info));
  __pyx_t_1 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_2, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 211, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "libudis/libudis.pyx":212
 *         info = &self.label_info_data[0]
 *         print("print_all", self, self.label_info.data, hex(<long>info), self.label_info)
 *         for i in range(min(5, self.max_lines)):             # <<<<<<<<<<<<<<
 *             start = info.text_start_index
 *             if start > 0:
 */
  __pyx_t_4 = __pyx_v_self->__pyx_base.max_lines;
  __pyx_t_5 = 5;
  if (((__pyx_t_4 < __pyx_t_5) != 0)) {
    __pyx_t_6 = __pyx_t_4;
  } else {
    __pyx_t_6 = __pyx_t_5;
  }
  __pyx_t_5 = __pyx_t_6;
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_6; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "libudis/libudis.pyx":213
 *         print("print_all", self, self.label_info.data, hex(<long>info), self.label_info)
 *         for i in range(min(5, self.max_lines)):
 *             start = info.text_start_index             # <<<<<<<<<<<<<<
 *             if start > 0:
 *                 count = info.line_length
 */
    __pyx_t_7 = __pyx_v_info->text_start_index;
    __pyx_v_start = __pyx_t_7;

    /* "libudis/libudis.pyx":214
 *         for i in range(min(5, self.max_lines)):
 *             start = info.text_start_index
 *             if start > 0:             # <<<<<<<<<<<<<<
 *                 count = info.line_length
 *                 print("entry:", i, start, count, info.num_bytes, info.item_count, info.type_code, self.text_buffer[start:start + count].tostring())
 */
    __pyx_t_8 = ((__pyx_v_start > 0) != 0);
    if (__pyx_t_8) {

      /* "libudis/libudis.pyx":215
 *             start = info.text_start_index
 *             if start > 0:
 *                 count = info.line_length             # <<<<<<<<<<<<<<
 *                 print("entry:", i, start, count, info.num_bytes, info.item_count, info.type_code, self.text_buffer[start:start + count].tostring())
 *             info += 1
 */
      __pyx_t_9 = __pyx_v_info->line_length;
      __pyx_v_count = __pyx_t_9;

      /* "libudis/libudis.pyx":216
 *             if start > 0:
 *                 count = info.line_length
 *                 print("entry:", i, start, count, info.num_bytes, info.item_count, info.type_code, self.text_buffer[start:start + count].tostring())             # <<<<<<<<<<<<<<
 *             info += 1
 *         if self.num_lines - 5 > 0:
 */
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_start); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_10 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->num_bytes); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->item_count); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->type_code); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_14 = __Pyx_PyObject_GetSlice(((PyObject *)__pyx_v_self->__pyx_base.text_buffer), __pyx_v_start, (__pyx_v_start + __pyx_v_count), NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_n_s_tostring); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_t_14 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_15);
        if (likely(__pyx_t_14)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
          __Pyx_INCREF(__pyx_t_14);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_15, function);
        }
      }
      __pyx_t_13 = (__pyx_t_14) ? __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_t_14) : __Pyx_PyObject_CallNoArg(__pyx_t_15);
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyTuple_New(8); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_INCREF(__pyx_kp_u_entry);
      __Pyx_GIVEREF(__pyx_kp_u_entry);
      PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u_entry);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_15, 3, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_10);
      PyTuple_SET_ITEM(__pyx_t_15, 4, __pyx_t_10);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_15, 5, __pyx_t_11);
      __Pyx_GIVEREF(__pyx_t_12);
      PyTuple_SET_ITEM(__pyx_t_15, 6, __pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_15, 7, __pyx_t_13);
      __pyx_t_3 = 0;
      __pyx_t_2 = 0;
      __pyx_t_1 = 0;
      __pyx_t_10 = 0;
      __pyx_t_11 = 0;
      __pyx_t_12 = 0;
      __pyx_t_13 = 0;
      __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_15, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "libudis/libudis.pyx":214
 *         for i in range(min(5, self.max_lines)):
 *             start = info.text_start_index
 *             if start > 0:             # <<<<<<<<<<<<<<
 *                 count = info.line_length
 *                 print("entry:", i, start, count, info.num_bytes, info.item_count, info.type_code, self.text_buffer[start:start + count].tostring())
 */
    }

    /* "libudis/libudis.pyx":217
 *                 count = info.line_length
 *                 print("entry:", i, start, count, info.num_bytes, info.item_count, info.type_code, self.text_buffer[start:start + count].tostring())
 *             info += 1             # <<<<<<<<<<<<<<
 *         if self.num_lines - 5 > 0:
 *             print("...", self.num_lines - 5, "more")
 */
    __pyx_v_info = (__pyx_v_info + 1);
  }

  /* "libudis/libudis.pyx":218
 *                 print("entry:", i, start, count, info.num_bytes, info.item_count, info.type_code, self.text_buffer[start:start + count].tostring())
 *             info += 1
 *         if self.num_lines - 5 > 0:             # <<<<<<<<<<<<<<
 *             print("...", self.num_lines - 5, "more")
 *         print("total = ", self.num_lines)
 */
  __pyx_t_8 = (((__pyx_v_self->__pyx_base.num_lines - 5) > 0) != 0);
  if (__pyx_t_8) {

    /* "libudis/libudis.pyx":219
 *             info += 1
 *         if self.num_lines - 5 > 0:
 *             print("...", self.num_lines - 5, "more")             # <<<<<<<<<<<<<<
 *         print("total = ", self.num_lines)
 * 
 */
    __pyx_t_13 = __Pyx_PyInt_From_long((__pyx_v_self->__pyx_base.num_lines - 5)); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_15 = PyTuple_New(3); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __Pyx_INCREF(__pyx_kp_u__6);
    __Pyx_GIVEREF(__pyx_kp_u__6);
    PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u__6);
    __Pyx_GIVEREF(__pyx_t_13);
    PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_13);
    __Pyx_INCREF(__pyx_n_u_more);
    __Pyx_GIVEREF(__pyx_n_u_more);
    PyTuple_SET_ITEM(__pyx_t_15, 2, __pyx_n_u_more);
    __pyx_t_13 = 0;
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_15, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 219, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

    /* "libudis/libudis.pyx":218
 *                 print("entry:", i, start, count, info.num_bytes, info.item_count, info.type_code, self.text_buffer[start:start + count].tostring())
 *             info += 1
 *         if self.num_lines - 5 > 0:             # <<<<<<<<<<<<<<
 *             print("...", self.num_lines - 5, "more")
 *         print("total = ", self.num_lines)
 */
  }

  /* "libudis/libudis.pyx":220
 *         if self.num_lines - 5 > 0:
 *             print("...", self.num_lines - 5, "more")
 *         print("total = ", self.num_lines)             # <<<<<<<<<<<<<<
 * 
 *     def keys(self):
 */
  __pyx_t_13 = __Pyx_PyInt_From_int(__pyx_v_self->__pyx_base.num_lines); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_15 = PyTuple_New(2); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_15);
  __Pyx_INCREF(__pyx_kp_u_total);
  __Pyx_GIVEREF(__pyx_kp_u_total);
  PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_kp_u_total);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_15, 1, __pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_15, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

  /* "libudis/libudis.pyx":206
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def print_all(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.print_all", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":222
 *         print("total = ", self.num_lines)
 * 
 *     def keys(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_16keys(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_16keys(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("keys (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_15keys(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_15keys(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  PyObject *__pyx_v_addresses = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  __Pyx_RefNannySetupContext("keys", 0);

  /* "libudis/libudis.pyx":226
 *         cdef int i
 * 
 *         addresses = []             # <<<<<<<<<<<<<<
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_addresses = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":227
 * 
 *         addresses = []
 *         info = &self.label_info_data[0]             # <<<<<<<<<<<<<<
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:
 */
  __pyx_v_info = (&(__pyx_v_self->__pyx_base.label_info_data[0]));

  /* "libudis/libudis.pyx":228
 *         addresses = []
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):             # <<<<<<<<<<<<<<
 *             if info.text_start_index > 0:
 *                 addresses.append(i)
 */
  __pyx_t_2 = __pyx_v_self->__pyx_base.max_lines;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "libudis/libudis.pyx":229
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:             # <<<<<<<<<<<<<<
 *                 addresses.append(i)
 *             info += 1
 */
    __pyx_t_5 = ((__pyx_v_info->text_start_index > 0) != 0);
    if (__pyx_t_5) {

      /* "libudis/libudis.pyx":230
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:
 *                 addresses.append(i)             # <<<<<<<<<<<<<<
 *             info += 1
 *         return addresses
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = __Pyx_PyList_Append(__pyx_v_addresses, __pyx_t_1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(0, 230, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "libudis/libudis.pyx":229
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):
 *             if info.text_start_index > 0:             # <<<<<<<<<<<<<<
 *                 addresses.append(i)
 *             info += 1
 */
    }

    /* "libudis/libudis.pyx":231
 *             if info.text_start_index > 0:
 *                 addresses.append(i)
 *             info += 1             # <<<<<<<<<<<<<<
 *         return addresses
 * 
 */
    __pyx_v_info = (__pyx_v_info + 1);
  }

  /* "libudis/libudis.pyx":232
 *                 addresses.append(i)
 *             info += 1
 *         return addresses             # <<<<<<<<<<<<<<
 * 
 *     def update(self, other):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_addresses);
  __pyx_r = __pyx_v_addresses;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":222
 *         print("total = ", self.num_lines)
 * 
 *     def keys(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.keys", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_addresses);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":234
 *         return addresses
 * 
 *     def update(self, other):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_18update(PyObject *__pyx_v_self, PyObject *__pyx_v_other); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_18update(PyObject *__pyx_v_self, PyObject *__pyx_v_other) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("update (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_17update(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self), ((PyObject *)__pyx_v_other));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_17update(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, PyObject *__pyx_v_other) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_v_i;
  int __pyx_v_start;
  int __pyx_v_count;
  long __pyx_v_addr;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  long __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  __pyx_t_5numpy_uint32_t __pyx_t_8;
  int __pyx_t_9;
  __pyx_t_5numpy_int8_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_RefNannySetupContext("update", 0);

  /* "libudis/libudis.pyx":239
 *         cdef long addr
 * 
 *         addr = other.get_label_data_addr()             # <<<<<<<<<<<<<<
 *         info = <label_info_t *>addr
 *         # print(other, other.label_info.data, hex(<long>info), other.label_info)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_get_label_data_addr); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_long(__pyx_t_1); if (unlikely((__pyx_t_4 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_addr = __pyx_t_4;

  /* "libudis/libudis.pyx":240
 * 
 *         addr = other.get_label_data_addr()
 *         info = <label_info_t *>addr             # <<<<<<<<<<<<<<
 *         # print(other, other.label_info.data, hex(<long>info), other.label_info)
 *         for i in range(self.max_lines):
 */
  __pyx_v_info = ((struct __pyx_t_7libudis_7libudis_label_info_t *)__pyx_v_addr);

  /* "libudis/libudis.pyx":242
 *         info = <label_info_t *>addr
 *         # print(other, other.label_info.data, hex(<long>info), other.label_info)
 *         for i in range(self.max_lines):             # <<<<<<<<<<<<<<
 *             start = info.text_start_index
 *             if start > 0:
 */
  __pyx_t_5 = __pyx_v_self->__pyx_base.max_lines;
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
    __pyx_v_i = __pyx_t_7;

    /* "libudis/libudis.pyx":243
 *         # print(other, other.label_info.data, hex(<long>info), other.label_info)
 *         for i in range(self.max_lines):
 *             start = info.text_start_index             # <<<<<<<<<<<<<<
 *             if start > 0:
 *                 count = info.line_length
 */
    __pyx_t_8 = __pyx_v_info->text_start_index;
    __pyx_v_start = __pyx_t_8;

    /* "libudis/libudis.pyx":244
 *         for i in range(self.max_lines):
 *             start = info.text_start_index
 *             if start > 0:             # <<<<<<<<<<<<<<
 *                 count = info.line_length
 *                 # print("found other", i, start, count, info.num_bytes, info.item_count, info.type_code, other.text_buffer[start:start + count])
 */
    __pyx_t_9 = ((__pyx_v_start > 0) != 0);
    if (__pyx_t_9) {

      /* "libudis/libudis.pyx":245
 *             start = info.text_start_index
 *             if start > 0:
 *                 count = info.line_length             # <<<<<<<<<<<<<<
 *                 # print("found other", i, start, count, info.num_bytes, info.item_count, info.type_code, other.text_buffer[start:start + count])
 *                 self[i] = (other.text_buffer[start:start + count], info.num_bytes, info.item_count, info.type_code)
 */
      __pyx_t_10 = __pyx_v_info->line_length;
      __pyx_v_count = __pyx_t_10;

      /* "libudis/libudis.pyx":247
 *                 count = info.line_length
 *                 # print("found other", i, start, count, info.num_bytes, info.item_count, info.type_code, other.text_buffer[start:start + count])
 *                 self[i] = (other.text_buffer[start:start + count], info.num_bytes, info.item_count, info.type_code)             # <<<<<<<<<<<<<<
 *             info += 1
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_other, __pyx_n_s_text_buffer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_t_1, __pyx_v_start, (__pyx_v_start + __pyx_v_count), NULL, NULL, NULL, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->num_bytes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->item_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_11 = __Pyx_PyInt_From_npy_int8(__pyx_v_info->type_code); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = PyTuple_New(4); if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_12, 1, __pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_12, 2, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_11);
      PyTuple_SET_ITEM(__pyx_t_12, 3, __pyx_t_11);
      __pyx_t_2 = 0;
      __pyx_t_1 = 0;
      __pyx_t_3 = 0;
      __pyx_t_11 = 0;
      if (unlikely(__Pyx_SetItemInt(((PyObject *)__pyx_v_self), __pyx_v_i, __pyx_t_12, int, 1, __Pyx_PyInt_From_int, 0, 1, 1) < 0)) __PYX_ERR(0, 247, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

      /* "libudis/libudis.pyx":244
 *         for i in range(self.max_lines):
 *             start = info.text_start_index
 *             if start > 0:             # <<<<<<<<<<<<<<
 *                 count = info.line_length
 *                 # print("found other", i, start, count, info.num_bytes, info.item_count, info.type_code, other.text_buffer[start:start + count])
 */
    }

    /* "libudis/libudis.pyx":248
 *                 # print("found other", i, start, count, info.num_bytes, info.item_count, info.type_code, other.text_buffer[start:start + count])
 *                 self[i] = (other.text_buffer[start:start + count], info.num_bytes, info.item_count, info.type_code)
 *             info += 1             # <<<<<<<<<<<<<<
 * 
 *     cdef clear(self):
 */
    __pyx_v_info = (__pyx_v_info + 1);
  }

  /* "libudis/libudis.pyx":234
 *         return addresses
 * 
 *     def update(self, other):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i, start, count
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.update", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":250
 *             info += 1
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_12LabelStorage_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  CYTHON_UNUSED int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  char *__pyx_t_4;
  __Pyx_RefNannySetupContext("clear", 0);

  /* "libudis/libudis.pyx":254
 *         cdef int i
 * 
 *         info = &self.label_info_data[0]             # <<<<<<<<<<<<<<
 *         for i in range(self.max_lines):
 *             info.text_start_index = 0
 */
  __pyx_v_info = (&(__pyx_v_self->__pyx_base.label_info_data[0]));

  /* "libudis/libudis.pyx":255
 * 
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):             # <<<<<<<<<<<<<<
 *             info.text_start_index = 0
 *             info += 1
 */
  __pyx_t_1 = __pyx_v_self->__pyx_base.max_lines;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":256
 *         info = &self.label_info_data[0]
 *         for i in range(self.max_lines):
 *             info.text_start_index = 0             # <<<<<<<<<<<<<<
 *             info += 1
 *         self.num_lines = 0
 */
    __pyx_v_info->text_start_index = 0;

    /* "libudis/libudis.pyx":257
 *         for i in range(self.max_lines):
 *             info.text_start_index = 0
 *             info += 1             # <<<<<<<<<<<<<<
 *         self.num_lines = 0
 *         self.text_index = 1  # special case: no string if text_starts[x] == 0
 */
    __pyx_v_info = (__pyx_v_info + 1);
  }

  /* "libudis/libudis.pyx":258
 *             info.text_start_index = 0
 *             info += 1
 *         self.num_lines = 0             # <<<<<<<<<<<<<<
 *         self.text_index = 1  # special case: no string if text_starts[x] == 0
 *         self.text_ptr = self.text_buffer_data
 */
  __pyx_v_self->__pyx_base.num_lines = 0;

  /* "libudis/libudis.pyx":259
 *             info += 1
 *         self.num_lines = 0
 *         self.text_index = 1  # special case: no string if text_starts[x] == 0             # <<<<<<<<<<<<<<
 *         self.text_ptr = self.text_buffer_data
 * 
 */
  __pyx_v_self->__pyx_base.text_index = 1;

  /* "libudis/libudis.pyx":260
 *         self.num_lines = 0
 *         self.text_index = 1  # special case: no string if text_starts[x] == 0
 *         self.text_ptr = self.text_buffer_data             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_v_self->__pyx_base.text_buffer_data;
  __pyx_v_self->__pyx_base.text_ptr = __pyx_t_4;

  /* "libudis/libudis.pyx":250
 *             info += 1
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef int i
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_20__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_20__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_19__reduce_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_19__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_22__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_22__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_21__setstate_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_12LabelStorage_21__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.LabelStorage.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":276
 *     cdef char *hex_case
 * 
 *     def __init__(self, start_index, max_lines, jmp_targets, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef char *text
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_start_index = 0;
  PyObject *__pyx_v_max_lines = 0;
  PyObject *__pyx_v_jmp_targets = 0;
  PyObject *__pyx_v_labels = 0;
  PyObject *__pyx_v_mnemonic_lower = 0;
  PyObject *__pyx_v_hex_lower = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_start_index,&__pyx_n_s_max_lines,&__pyx_n_s_jmp_targets,&__pyx_n_s_labels,&__pyx_n_s_mnemonic_lower,&__pyx_n_s_hex_lower,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    values[3] = ((PyObject *)Py_None);
    values[4] = ((PyObject *)Py_True);
    values[5] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_start_index)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_lines)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 6, 1); __PYX_ERR(0, 276, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_jmp_targets)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 6, 2); __PYX_ERR(0, 276, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_mnemonic_lower);
          if (value) { values[4] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_hex_lower);
          if (value) { values[5] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 276, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_start_index = values[0];
    __pyx_v_max_lines = values[1];
    __pyx_v_jmp_targets = values[2];
    __pyx_v_labels = values[3];
    __pyx_v_mnemonic_lower = values[4];
    __pyx_v_hex_lower = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 3, 6, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 276, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly___init__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), __pyx_v_start_index, __pyx_v_max_lines, __pyx_v_jmp_targets, __pyx_v_labels, __pyx_v_mnemonic_lower, __pyx_v_hex_lower);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_start_index, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_jmp_targets, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower) {
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  char *__pyx_v_text;
  long __pyx_v_addr;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  long __pyx_t_8;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "libudis/libudis.pyx":281
 *         cdef long addr
 * 
 *         self.start_index = start_index             # <<<<<<<<<<<<<<
 *         self.disasm_text = TextStorage(max_lines)
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_start_index); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 281, __pyx_L1_error)
  __pyx_v_self->start_index = __pyx_t_1;

  /* "libudis/libudis.pyx":282
 * 
 *         self.start_index = start_index
 *         self.disasm_text = TextStorage(max_lines)             # <<<<<<<<<<<<<<
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage), __pyx_v_max_lines); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->disasm_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->disasm_text));
  __pyx_v_self->disasm_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":283
 *         self.start_index = start_index
 *         self.disasm_text = TextStorage(max_lines)
 *         self.mnemonic_case = 1 if mnemonic_lower else 0             # <<<<<<<<<<<<<<
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 *         self.jmp_targets = jmp_targets
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_mnemonic_lower); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 283, __pyx_L1_error)
  if (__pyx_t_3) {
    __pyx_t_1 = 1;
  } else {
    __pyx_t_1 = 0;
  }
  __pyx_v_self->mnemonic_case = __pyx_t_1;

  /* "libudis/libudis.pyx":284
 *         self.disasm_text = TextStorage(max_lines)
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper             # <<<<<<<<<<<<<<
 *         self.jmp_targets = jmp_targets
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_hex_lower); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 284, __pyx_L1_error)
  if (__pyx_t_3) {
    __pyx_t_4 = __pyx_v_8omnivore_12disassembler_7libudis_hexdigits_lower;
  } else {
    __pyx_t_4 = __pyx_v_8omnivore_12disassembler_7libudis_hexdigits_upper;
  }
  __pyx_v_self->hex_case = __pyx_t_4;

  /* "libudis/libudis.pyx":285
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 *         self.jmp_targets = jmp_targets             # <<<<<<<<<<<<<<
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 */
  if (!(likely(((__pyx_v_jmp_targets) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_jmp_targets, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 285, __pyx_L1_error)
  __pyx_t_2 = __pyx_v_jmp_targets;
  __Pyx_INCREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":286
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 *         self.jmp_targets = jmp_targets
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data             # <<<<<<<<<<<<<<
 * 
 *         if labels is not None:
 */
  __pyx_v_self->jmp_targets_data = ((struct __pyx_t_7libudis_7libudis_jmp_targets_t *)__pyx_v_self->jmp_targets->data);

  /* "libudis/libudis.pyx":288
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 *         if labels is not None:             # <<<<<<<<<<<<<<
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr
 */
  __pyx_t_3 = (__pyx_v_labels != Py_None);
  __pyx_t_5 = (__pyx_t_3 != 0);
  if (__pyx_t_5) {

    /* "libudis/libudis.pyx":289
 * 
 *         if labels is not None:
 *             addr = labels.get_text_storage_addr()             # <<<<<<<<<<<<<<
 *             text = <char *>addr
 *             self.jmp_targets_data.text_storage = text
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_labels, __pyx_n_s_get_text_storage_addr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = __Pyx_PyInt_As_long(__pyx_t_2); if (unlikely((__pyx_t_8 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 289, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_addr = __pyx_t_8;

    /* "libudis/libudis.pyx":290
 *         if labels is not None:
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr             # <<<<<<<<<<<<<<
 *             self.jmp_targets_data.text_storage = text
 * 
 */
    __pyx_v_text = ((char *)__pyx_v_addr);

    /* "libudis/libudis.pyx":291
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr
 *             self.jmp_targets_data.text_storage = text             # <<<<<<<<<<<<<<
 * 
 *             addr = labels.get_label_data_addr()
 */
    __pyx_v_self->jmp_targets_data->text_storage = __pyx_v_text;

    /* "libudis/libudis.pyx":293
 *             self.jmp_targets_data.text_storage = text
 * 
 *             addr = labels.get_label_data_addr()             # <<<<<<<<<<<<<<
 *             info = <label_info_t *>addr
 *             self.jmp_targets_data.labels = info
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_labels, __pyx_n_s_get_label_data_addr); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_2 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 293, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = __Pyx_PyInt_As_long(__pyx_t_2); if (unlikely((__pyx_t_8 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 293, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_addr = __pyx_t_8;

    /* "libudis/libudis.pyx":294
 * 
 *             addr = labels.get_label_data_addr()
 *             info = <label_info_t *>addr             # <<<<<<<<<<<<<<
 *             self.jmp_targets_data.labels = info
 *         else:
 */
    __pyx_v_info = ((struct __pyx_t_7libudis_7libudis_label_info_t *)__pyx_v_addr);

    /* "libudis/libudis.pyx":295
 *             addr = labels.get_label_data_addr()
 *             info = <label_info_t *>addr
 *             self.jmp_targets_data.labels = info             # <<<<<<<<<<<<<<
 *         else:
 *             self.jmp_targets_data.text_storage = <char *>0
 */
    __pyx_v_self->jmp_targets_data->labels = __pyx_v_info;

    /* "libudis/libudis.pyx":288
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 *         if labels is not None:             # <<<<<<<<<<<<<<
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr
 */
    goto __pyx_L3;
  }

  /* "libudis/libudis.pyx":297
 *             self.jmp_targets_data.labels = info
 *         else:
 *             self.jmp_targets_data.text_storage = <char *>0             # <<<<<<<<<<<<<<
 *             self.jmp_targets_data.labels = <label_info_t *>0
 * 
 */
  /*else*/ {
    __pyx_v_self->jmp_targets_data->text_storage = ((char *)0);

    /* "libudis/libudis.pyx":298
 *         else:
 *             self.jmp_targets_data.text_storage = <char *>0
 *             self.jmp_targets_data.labels = <label_info_t *>0             # <<<<<<<<<<<<<<
 * 
 *         self.clear()
 */
    __pyx_v_self->jmp_targets_data->labels = ((struct __pyx_t_7libudis_7libudis_label_info_t *)0);
  }
  __pyx_L3:;

  /* "libudis/libudis.pyx":300
 *             self.jmp_targets_data.labels = <label_info_t *>0
 * 
 *         self.clear()             # <<<<<<<<<<<<<<
 *         # for disassembler_type in range(40):
 *         #     printf("stringifier[%d] = %lx\n", disassembler_type, stringifier_map[disassembler_type])
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self->__pyx_vtab)->clear(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":276
 *     cdef char *hex_case
 * 
 *     def __init__(self, start_index, max_lines, jmp_targets, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         cdef label_info_t *info
 *         cdef char *text
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":304
 *         #     printf("stringifier[%d] = %lx\n", disassembler_type, stringifier_map[disassembler_type])
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.disasm_text.num_lines
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_3__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_2__len__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "libudis/libudis.pyx":305
 * 
 *     def __len__(self):
 *         return self.disasm_text.num_lines             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, index):
 */
  __pyx_r = __pyx_v_self->disasm_text->num_lines;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":304
 *         #     printf("stringifier[%d] = %lx\n", disassembler_type, stringifier_map[disassembler_type])
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.disasm_text.num_lines
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":307
 *         return self.disasm_text.num_lines
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         if isinstance(index, slice):
 *             lines = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_4__getitem__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_v_lines = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "libudis/libudis.pyx":308
 * 
 *     def __getitem__(self, index):
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  __pyx_t_1 = PySlice_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":309
 *     def __getitem__(self, index):
 *         if isinstance(index, slice):
 *             lines = []             # <<<<<<<<<<<<<<
 *             for i in range(*index.indices(len(self))):
 *                 lines.append(self.disasm_text[i])
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 309, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_lines = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":310
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 lines.append(self.disasm_text[i])
 *             return lines
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_indices); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_Length(((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 310, __pyx_L1_error)
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 310, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 310, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 310, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 310, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 310, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_8(__pyx_t_4);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 310, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "libudis/libudis.pyx":311
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 *                 lines.append(self.disasm_text[i])             # <<<<<<<<<<<<<<
 *             return lines
 *         elif isinstance(index, int):
 */
      __pyx_t_3 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->disasm_text), __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_lines, __pyx_t_3); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 311, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "libudis/libudis.pyx":310
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 lines.append(self.disasm_text[i])
 *             return lines
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "libudis/libudis.pyx":312
 *             for i in range(*index.indices(len(self))):
 *                 lines.append(self.disasm_text[i])
 *             return lines             # <<<<<<<<<<<<<<
 *         elif isinstance(index, int):
 *             return self.disasm_text[index]
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_lines);
    __pyx_r = __pyx_v_lines;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":308
 * 
 *     def __getitem__(self, index):
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  }

  /* "libudis/libudis.pyx":313
 *                 lines.append(self.disasm_text[i])
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             return self.disasm_text[index]
 * 
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_index); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (likely(__pyx_t_1)) {

    /* "libudis/libudis.pyx":314
 *             return lines
 *         elif isinstance(index, int):
 *             return self.disasm_text[index]             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->disasm_text), __pyx_v_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 314, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":313
 *                 lines.append(self.disasm_text[i])
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             return self.disasm_text[index]
 * 
 */
  }

  /* "libudis/libudis.pyx":317
 * 
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_index)), __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(0, 317, __pyx_L1_error)
  }

  /* "libudis/libudis.pyx":307
 *         return self.disasm_text.num_lines
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         if isinstance(index, slice):
 *             lines = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lines);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_8generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "libudis/libudis.pyx":319
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(len(self)):
 *             yield self.disasm_text[i]
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7__iter__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6__iter__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *)__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__(__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 319, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_8generator2, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_StringifiedDisassembly___iter, __pyx_n_s_omnivore_disassembler_libudis); if (unlikely(!gen)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_8generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *__pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 319, __pyx_L1_error)

  /* "libudis/libudis.pyx":320
 * 
 *     def __iter__(self):
 *         for i in range(len(self)):             # <<<<<<<<<<<<<<
 *             yield self.disasm_text[i]
 * 
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_cur_scope->__pyx_v_self)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 320, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_cur_scope->__pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":321
 *     def __iter__(self):
 *         for i in range(len(self)):
 *             yield self.disasm_text[i]             # <<<<<<<<<<<<<<
 * 
 *     cdef clear(self):
 */
    __pyx_t_4 = __Pyx_GetItemInt(((PyObject *)__pyx_cur_scope->__pyx_v_self->disasm_text), __pyx_cur_scope->__pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 321, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 321, __pyx_L1_error)
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "libudis/libudis.pyx":319
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(len(self)):
 *             yield self.disasm_text[i]
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":323
 *             yield self.disasm_text[i]
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.origin = 0
 *         self.last_pc = 0
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("clear", 0);

  /* "libudis/libudis.pyx":324
 * 
 *     cdef clear(self):
 *         self.origin = 0             # <<<<<<<<<<<<<<
 *         self.last_pc = 0
 *         self.disasm_text.clear()
 */
  __pyx_v_self->origin = 0;

  /* "libudis/libudis.pyx":325
 *     cdef clear(self):
 *         self.origin = 0
 *         self.last_pc = 0             # <<<<<<<<<<<<<<
 *         self.disasm_text.clear()
 * 
 */
  __pyx_v_self->last_pc = 0;

  /* "libudis/libudis.pyx":326
 *         self.origin = 0
 *         self.last_pc = 0
 *         self.disasm_text.clear()             # <<<<<<<<<<<<<<
 * 
 *     cdef parse_history_entries(self, history_entry_t *h, int num_entries):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->disasm_text->__pyx_vtab)->clear(__pyx_v_self->disasm_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":323
 *             yield self.disasm_text[i]
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.origin = 0
 *         self.last_pc = 0
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":328
 *         self.disasm_text.clear()
 * 
 *     cdef parse_history_entries(self, history_entry_t *h, int num_entries):             # <<<<<<<<<<<<<<
 *         if num_entries > self.disasm_text.max_lines:
 *             num_entries = self.disasm_text.max_lines
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_parse_history_entries(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, struct __pyx_t_7libudis_7libudis_history_entry_t *__pyx_v_h, int __pyx_v_num_entries) {
  int __pyx_v_count;
  __pyx_t_7libudis_7libudis_string_func_t __pyx_v_stringifier;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("parse_history_entries", 0);

  /* "libudis/libudis.pyx":329
 * 
 *     cdef parse_history_entries(self, history_entry_t *h, int num_entries):
 *         if num_entries > self.disasm_text.max_lines:             # <<<<<<<<<<<<<<
 *             num_entries = self.disasm_text.max_lines
 *         cdef int count
 */
  __pyx_t_1 = ((__pyx_v_num_entries > __pyx_v_self->disasm_text->max_lines) != 0);
  if (__pyx_t_1) {

    /* "libudis/libudis.pyx":330
 *     cdef parse_history_entries(self, history_entry_t *h, int num_entries):
 *         if num_entries > self.disasm_text.max_lines:
 *             num_entries = self.disasm_text.max_lines             # <<<<<<<<<<<<<<
 *         cdef int count
 *         cdef string_func_t stringifier
 */
    __pyx_t_2 = __pyx_v_self->disasm_text->max_lines;
    __pyx_v_num_entries = __pyx_t_2;

    /* "libudis/libudis.pyx":329
 * 
 *     cdef parse_history_entries(self, history_entry_t *h, int num_entries):
 *         if num_entries > self.disasm_text.max_lines:             # <<<<<<<<<<<<<<
 *             num_entries = self.disasm_text.max_lines
 *         cdef int count
 */
  }

  /* "libudis/libudis.pyx":334
 *         cdef string_func_t stringifier
 * 
 *         self.disasm_text.clear()             # <<<<<<<<<<<<<<
 *         while num_entries > 0:
 *             stringifier = stringifier_map[h.disassembler_type]
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->disasm_text->__pyx_vtab)->clear(__pyx_v_self->disasm_text); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "libudis/libudis.pyx":335
 * 
 *         self.disasm_text.clear()
 *         while num_entries > 0:             # <<<<<<<<<<<<<<
 *             stringifier = stringifier_map[h.disassembler_type]
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_num_entries > 0) != 0);
    if (!__pyx_t_1) break;

    /* "libudis/libudis.pyx":336
 *         self.disasm_text.clear()
 *         while num_entries > 0:
 *             stringifier = stringifier_map[h.disassembler_type]             # <<<<<<<<<<<<<<
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *             count = stringifier(h, self.disasm_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)
 */
    __pyx_v_stringifier = (stringifier_map[__pyx_v_h->disassembler_type]);

    /* "libudis/libudis.pyx":338
 *             stringifier = stringifier_map[h.disassembler_type]
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *             count = stringifier(h, self.disasm_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)             # <<<<<<<<<<<<<<
 *             self.disasm_text.store(count)
 *             num_entries -= 1
 */
    __pyx_v_count = __pyx_v_stringifier(__pyx_v_h, __pyx_v_self->disasm_text->text_ptr, __pyx_v_self->hex_case, __pyx_v_self->mnemonic_case, __pyx_v_self->jmp_targets_data);

    /* "libudis/libudis.pyx":339
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *             count = stringifier(h, self.disasm_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)
 *             self.disasm_text.store(count)             # <<<<<<<<<<<<<<
 *             num_entries -= 1
 *             h += 1
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->disasm_text->__pyx_vtab)->store(__pyx_v_self->disasm_text, __pyx_v_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":340
 *             count = stringifier(h, self.disasm_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)
 *             self.disasm_text.store(count)
 *             num_entries -= 1             # <<<<<<<<<<<<<<
 *             h += 1
 * 
 */
    __pyx_v_num_entries = (__pyx_v_num_entries - 1);

    /* "libudis/libudis.pyx":341
 *             self.disasm_text.store(count)
 *             num_entries -= 1
 *             h += 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_h = (__pyx_v_h + 1);
  }

  /* "libudis/libudis.pyx":328
 *         self.disasm_text.clear()
 * 
 *     cdef parse_history_entries(self, history_entry_t *h, int num_entries):             # <<<<<<<<<<<<<<
 *         if num_entries > self.disasm_text.max_lines:
 *             num_entries = self.disasm_text.max_lines
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.parse_history_entries", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":264
 * 
 * cdef class StringifiedDisassembly:
 *     cdef public int origin             # <<<<<<<<<<<<<<
 *     cdef public int last_pc
 *     cdef public int start_index
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->origin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 264, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.origin.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 264, __pyx_L1_error)
  __pyx_v_self->origin = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.origin.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":265
 * cdef class StringifiedDisassembly:
 *     cdef public int origin
 *     cdef public int last_pc             # <<<<<<<<<<<<<<
 *     cdef public int start_index
 *     cdef public np.ndarray jmp_targets
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->last_pc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.last_pc.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 265, __pyx_L1_error)
  __pyx_v_self->last_pc = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.last_pc.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":266
 *     cdef public int origin
 *     cdef public int last_pc
 *     cdef public int start_index             # <<<<<<<<<<<<<<
 *     cdef public np.ndarray jmp_targets
 *     cdef jmp_targets_t *jmp_targets_data
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->start_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.start_index.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 266, __pyx_L1_error)
  __pyx_v_self->start_index = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.start_index.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":267
 *     cdef public int last_pc
 *     cdef public int start_index
 *     cdef public np.ndarray jmp_targets             # <<<<<<<<<<<<<<
 *     cdef jmp_targets_t *jmp_targets_data
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_r = ((PyObject *)__pyx_v_self->jmp_targets);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 267, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.jmp_targets.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":270
 *     cdef jmp_targets_t *jmp_targets_data
 * 
 *     cdef public TextStorage disasm_text             # <<<<<<<<<<<<<<
 * 
 *     # internals
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->disasm_text));
  __pyx_r = ((PyObject *)__pyx_v_self->disasm_text);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage))))) __PYX_ERR(0, 270, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->disasm_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->disasm_text));
  __pyx_v_self->disasm_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.disasm_text.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->disasm_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->disasm_text));
  __pyx_v_self->disasm_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_10__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_10__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_9__reduce_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_9__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_12__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_12__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11__setstate_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedDisassembly.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":361
 *     cdef int max_text_lines
 * 
 *     def __init__(self, max_entries, origin, num_bytes):             # <<<<<<<<<<<<<<
 *         self.max_entries = max_entries
 *         self.entry_size = sizeof(history_entry_t)
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_max_entries = 0;
  PyObject *__pyx_v_origin = 0;
  PyObject *__pyx_v_num_bytes = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_max_entries,&__pyx_n_s_origin,&__pyx_n_s_num_bytes,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_entries)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_origin)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 1); __PYX_ERR(0, 361, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_bytes)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, 2); __PYX_ERR(0, 361, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 361, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_max_entries = values[0];
    __pyx_v_origin = values[1];
    __pyx_v_num_bytes = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 361, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly___init__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), __pyx_v_max_entries, __pyx_v_origin, __pyx_v_num_bytes);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_max_entries, PyObject *__pyx_v_origin, PyObject *__pyx_v_num_bytes) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "libudis/libudis.pyx":362
 * 
 *     def __init__(self, max_entries, origin, num_bytes):
 *         self.max_entries = max_entries             # <<<<<<<<<<<<<<
 *         self.entry_size = sizeof(history_entry_t)
 *         self.raw_entries = np.zeros((max_entries + 1) * self.entry_size, dtype=np.uint8)
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_max_entries); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 362, __pyx_L1_error)
  __pyx_v_self->max_entries = __pyx_t_1;

  /* "libudis/libudis.pyx":363
 *     def __init__(self, max_entries, origin, num_bytes):
 *         self.max_entries = max_entries
 *         self.entry_size = sizeof(history_entry_t)             # <<<<<<<<<<<<<<
 *         self.raw_entries = np.zeros((max_entries + 1) * self.entry_size, dtype=np.uint8)
 *         self.history_entries = <history_entry_t *>self.raw_entries.data
 */
  __pyx_v_self->entry_size = (sizeof(struct __pyx_t_7libudis_7libudis_history_entry_t));

  /* "libudis/libudis.pyx":364
 *         self.max_entries = max_entries
 *         self.entry_size = sizeof(history_entry_t)
 *         self.raw_entries = np.zeros((max_entries + 1) * self.entry_size, dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         self.history_entries = <history_entry_t *>self.raw_entries.data
 *         self.num_entries = 0
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_max_entries, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_self->entry_size); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyNumber_Multiply(__pyx_t_2, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_uint8); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 364, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF(__pyx_v_self->raw_entries);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->raw_entries));
  __pyx_v_self->raw_entries = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "libudis/libudis.pyx":365
 *         self.entry_size = sizeof(history_entry_t)
 *         self.raw_entries = np.zeros((max_entries + 1) * self.entry_size, dtype=np.uint8)
 *         self.history_entries = <history_entry_t *>self.raw_entries.data             # <<<<<<<<<<<<<<
 *         self.num_entries = 0
 *         self.origin = origin
 */
  __pyx_v_self->history_entries = ((struct __pyx_t_7libudis_7libudis_history_entry_t *)__pyx_v_self->raw_entries->data);

  /* "libudis/libudis.pyx":366
 *         self.raw_entries = np.zeros((max_entries + 1) * self.entry_size, dtype=np.uint8)
 *         self.history_entries = <history_entry_t *>self.raw_entries.data
 *         self.num_entries = 0             # <<<<<<<<<<<<<<
 *         self.origin = origin
 *         self.last_pc = origin
 */
  __pyx_v_self->num_entries = 0;

  /* "libudis/libudis.pyx":367
 *         self.history_entries = <history_entry_t *>self.raw_entries.data
 *         self.num_entries = 0
 *         self.origin = origin             # <<<<<<<<<<<<<<
 *         self.last_pc = origin
 *         self.current_pc = origin
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_origin); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 367, __pyx_L1_error)
  __pyx_v_self->origin = __pyx_t_1;

  /* "libudis/libudis.pyx":368
 *         self.num_entries = 0
 *         self.origin = origin
 *         self.last_pc = origin             # <<<<<<<<<<<<<<
 *         self.current_pc = origin
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_origin); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 368, __pyx_L1_error)
  __pyx_v_self->last_pc = __pyx_t_1;

  /* "libudis/libudis.pyx":369
 *         self.origin = origin
 *         self.last_pc = origin
 *         self.current_pc = origin             # <<<<<<<<<<<<<<
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_origin); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 369, __pyx_L1_error)
  __pyx_v_self->current_pc = __pyx_t_1;

  /* "libudis/libudis.pyx":370
 *         self.last_pc = origin
 *         self.current_pc = origin
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_zeros); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyInt_FromSize_t((sizeof(struct __pyx_t_7libudis_7libudis_jmp_targets_t))); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_uint8); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_2) < 0) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 370, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":371
 *         self.current_pc = origin
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data             # <<<<<<<<<<<<<<
 * 
 *         self.num_bytes = num_bytes
 */
  __pyx_v_self->jmp_targets_data = ((struct __pyx_t_7libudis_7libudis_jmp_targets_t *)__pyx_v_self->jmp_targets->data);

  /* "libudis/libudis.pyx":373
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 *         self.num_bytes = num_bytes             # <<<<<<<<<<<<<<
 *         self.index_to_row = np.zeros(num_bytes + 1, dtype=np.uint32)
 *         self.index_to_row_data = <np.uint32_t *>self.index_to_row.data
 */
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_num_bytes); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 373, __pyx_L1_error)
  __pyx_v_self->num_bytes = __pyx_t_1;

  /* "libudis/libudis.pyx":374
 * 
 *         self.num_bytes = num_bytes
 *         self.index_to_row = np.zeros(num_bytes + 1, dtype=np.uint32)             # <<<<<<<<<<<<<<
 *         self.index_to_row_data = <np.uint32_t *>self.index_to_row.data
 *         self.index_index = 0
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_num_bytes, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_uint32); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_3) < 0) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 374, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_3);
  __Pyx_GOTREF(__pyx_v_self->index_to_row);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->index_to_row));
  __pyx_v_self->index_to_row = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "libudis/libudis.pyx":375
 *         self.num_bytes = num_bytes
 *         self.index_to_row = np.zeros(num_bytes + 1, dtype=np.uint32)
 *         self.index_to_row_data = <np.uint32_t *>self.index_to_row.data             # <<<<<<<<<<<<<<
 *         self.index_index = 0
 * 
 */
  __pyx_v_self->index_to_row_data = ((__pyx_t_5numpy_uint32_t *)__pyx_v_self->index_to_row->data);

  /* "libudis/libudis.pyx":376
 *         self.index_to_row = np.zeros(num_bytes + 1, dtype=np.uint32)
 *         self.index_to_row_data = <np.uint32_t *>self.index_to_row.data
 *         self.index_index = 0             # <<<<<<<<<<<<<<
 * 
 *         self.max_text_lines = 256
 */
  __pyx_v_self->index_index = 0;

  /* "libudis/libudis.pyx":378
 *         self.index_index = 0
 * 
 *         self.max_text_lines = 256             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __pyx_v_self->max_text_lines = 0x100;

  /* "libudis/libudis.pyx":361
 *     cdef int max_text_lines
 * 
 *     def __init__(self, max_entries, origin, num_bytes):             # <<<<<<<<<<<<<<
 *         self.max_entries = max_entries
 *         self.entry_size = sizeof(history_entry_t)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":380
 *         self.max_text_lines = 256
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.num_entries
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_3__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_2__len__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "libudis/libudis.pyx":381
 * 
 *     def __len__(self):
 *         return self.num_entries             # <<<<<<<<<<<<<<
 * 
 *     cdef parse_next(self, parse_func_t processor, unsigned char *src, int num_bytes):
 */
  __pyx_r = __pyx_v_self->num_entries;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":380
 *         self.max_text_lines = 256
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.num_entries
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":383
 *         return self.num_entries
 * 
 *     cdef parse_next(self, parse_func_t processor, unsigned char *src, int num_bytes):             # <<<<<<<<<<<<<<
 *         cdef history_entry_t *h = &self.history_entries[self.num_entries]
 *         cdef int last_pc = self.current_pc + num_bytes
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_17ParsedDisassembly_parse_next(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, __pyx_t_7libudis_7libudis_parse_func_t __pyx_v_processor, unsigned char *__pyx_v_src, int __pyx_v_num_bytes) {
  struct __pyx_t_7libudis_7libudis_history_entry_t *__pyx_v_h;
  int __pyx_v_last_pc;
  __pyx_t_5numpy_uint32_t *__pyx_v_index_list;
  CYTHON_UNUSED int __pyx_v_i;
  PyObject *__pyx_v_count = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_uint32_t *__pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  long __pyx_t_8;
  long __pyx_t_9;
  int __pyx_t_10;
  Py_UCS4 __pyx_t_11;
  __Pyx_RefNannySetupContext("parse_next", 0);

  /* "libudis/libudis.pyx":384
 * 
 *     cdef parse_next(self, parse_func_t processor, unsigned char *src, int num_bytes):
 *         cdef history_entry_t *h = &self.history_entries[self.num_entries]             # <<<<<<<<<<<<<<
 *         cdef int last_pc = self.current_pc + num_bytes
 *         cdef np.uint32_t *index_list = self.index_to_row_data
 */
  __pyx_v_h = (&(__pyx_v_self->history_entries[__pyx_v_self->num_entries]));

  /* "libudis/libudis.pyx":385
 *     cdef parse_next(self, parse_func_t processor, unsigned char *src, int num_bytes):
 *         cdef history_entry_t *h = &self.history_entries[self.num_entries]
 *         cdef int last_pc = self.current_pc + num_bytes             # <<<<<<<<<<<<<<
 *         cdef np.uint32_t *index_list = self.index_to_row_data
 *         cdef int i
 */
  __pyx_v_last_pc = (__pyx_v_self->current_pc + __pyx_v_num_bytes);

  /* "libudis/libudis.pyx":386
 *         cdef history_entry_t *h = &self.history_entries[self.num_entries]
 *         cdef int last_pc = self.current_pc + num_bytes
 *         cdef np.uint32_t *index_list = self.index_to_row_data             # <<<<<<<<<<<<<<
 *         cdef int i
 *         while self.current_pc < last_pc and self.num_entries < self.max_entries:
 */
  __pyx_t_1 = __pyx_v_self->index_to_row_data;
  __pyx_v_index_list = __pyx_t_1;

  /* "libudis/libudis.pyx":388
 *         cdef np.uint32_t *index_list = self.index_to_row_data
 *         cdef int i
 *         while self.current_pc < last_pc and self.num_entries < self.max_entries:             # <<<<<<<<<<<<<<
 *             if num_bytes > 0:
 *                 count = processor(h, src, self.current_pc, last_pc, self.jmp_targets_data)
 */
  while (1) {
    __pyx_t_3 = ((__pyx_v_self->current_pc < __pyx_v_last_pc) != 0);
    if (__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_3 = ((__pyx_v_self->num_entries < __pyx_v_self->max_entries) != 0);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L5_bool_binop_done:;
    if (!__pyx_t_2) break;

    /* "libudis/libudis.pyx":389
 *         cdef int i
 *         while self.current_pc < last_pc and self.num_entries < self.max_entries:
 *             if num_bytes > 0:             # <<<<<<<<<<<<<<
 *                 count = processor(h, src, self.current_pc, last_pc, self.jmp_targets_data)
 *                 src += count
 */
    __pyx_t_2 = ((__pyx_v_num_bytes > 0) != 0);
    if (__pyx_t_2) {

      /* "libudis/libudis.pyx":390
 *         while self.current_pc < last_pc and self.num_entries < self.max_entries:
 *             if num_bytes > 0:
 *                 count = processor(h, src, self.current_pc, last_pc, self.jmp_targets_data)             # <<<<<<<<<<<<<<
 *                 src += count
 *                 num_bytes -= count
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_processor(__pyx_v_h, __pyx_v_src, __pyx_v_self->current_pc, __pyx_v_last_pc, __pyx_v_self->jmp_targets_data)); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 390, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_count, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "libudis/libudis.pyx":391
 *             if num_bytes > 0:
 *                 count = processor(h, src, self.current_pc, last_pc, self.jmp_targets_data)
 *                 src += count             # <<<<<<<<<<<<<<
 *                 num_bytes -= count
 *                 self.current_pc += count
 */
      __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_v_count); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 391, __pyx_L1_error)
      __pyx_v_src = (__pyx_v_src + __pyx_t_5);

      /* "libudis/libudis.pyx":392
 *                 count = processor(h, src, self.current_pc, last_pc, self.jmp_targets_data)
 *                 src += count
 *                 num_bytes -= count             # <<<<<<<<<<<<<<
 *                 self.current_pc += count
 *                 for i in range(count):
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_num_bytes); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_6 = PyNumber_InPlaceSubtract(__pyx_t_4, __pyx_v_count); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_6); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 392, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_v_num_bytes = __pyx_t_7;

      /* "libudis/libudis.pyx":393
 *                 src += count
 *                 num_bytes -= count
 *                 self.current_pc += count             # <<<<<<<<<<<<<<
 *                 for i in range(count):
 *                     index_list[self.index_index] = self.num_entries
 */
      __pyx_t_6 = __Pyx_PyInt_From_int(__pyx_v_self->current_pc); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_t_6, __pyx_v_count); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_7 = __Pyx_PyInt_As_int(__pyx_t_4); if (unlikely((__pyx_t_7 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 393, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_self->current_pc = __pyx_t_7;

      /* "libudis/libudis.pyx":394
 *                 num_bytes -= count
 *                 self.current_pc += count
 *                 for i in range(count):             # <<<<<<<<<<<<<<
 *                     index_list[self.index_index] = self.num_entries
 *                     self.index_index += 1
 */
      __pyx_t_8 = __Pyx_PyInt_As_long(__pyx_v_count); if (unlikely((__pyx_t_8 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 394, __pyx_L1_error)
      __pyx_t_9 = __pyx_t_8;
      for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_9; __pyx_t_7+=1) {
        __pyx_v_i = __pyx_t_7;

        /* "libudis/libudis.pyx":395
 *                 self.current_pc += count
 *                 for i in range(count):
 *                     index_list[self.index_index] = self.num_entries             # <<<<<<<<<<<<<<
 *                     self.index_index += 1
 *                 self.num_entries += 1
 */
        __pyx_t_10 = __pyx_v_self->num_entries;
        (__pyx_v_index_list[__pyx_v_self->index_index]) = __pyx_t_10;

        /* "libudis/libudis.pyx":396
 *                 for i in range(count):
 *                     index_list[self.index_index] = self.num_entries
 *                     self.index_index += 1             # <<<<<<<<<<<<<<
 *                 self.num_entries += 1
 *                 h += 1
 */
        __pyx_v_self->index_index = (__pyx_v_self->index_index + 1);
      }

      /* "libudis/libudis.pyx":397
 *                     index_list[self.index_index] = self.num_entries
 *                     self.index_index += 1
 *                 self.num_entries += 1             # <<<<<<<<<<<<<<
 *                 h += 1
 *             else:
 */
      __pyx_v_self->num_entries = (__pyx_v_self->num_entries + 1);

      /* "libudis/libudis.pyx":398
 *                     self.index_index += 1
 *                 self.num_entries += 1
 *                 h += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 break
 */
      __pyx_v_h = (__pyx_v_h + 1);

      /* "libudis/libudis.pyx":389
 *         cdef int i
 *         while self.current_pc < last_pc and self.num_entries < self.max_entries:
 *             if num_bytes > 0:             # <<<<<<<<<<<<<<
 *                 count = processor(h, src, self.current_pc, last_pc, self.jmp_targets_data)
 *                 src += count
 */
      goto __pyx_L7;
    }

    /* "libudis/libudis.pyx":400
 *                 h += 1
 *             else:
 *                 break             # <<<<<<<<<<<<<<
 *         if self.num_entries >= self.max_entries:
 *             print(f"CYTHON ERROR! ParsedDisassembly disassembly entries {self.max_entries} exceeded, attempted to save {self.num_entries}")
 */
    /*else*/ {
      goto __pyx_L4_break;
    }
    __pyx_L7:;
  }
  __pyx_L4_break:;

  /* "libudis/libudis.pyx":401
 *             else:
 *                 break
 *         if self.num_entries >= self.max_entries:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! ParsedDisassembly disassembly entries {self.max_entries} exceeded, attempted to save {self.num_entries}")
 *         if self.index_index > self.num_bytes:
 */
  __pyx_t_2 = ((__pyx_v_self->num_entries >= __pyx_v_self->max_entries) != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":402
 *                 break
 *         if self.num_entries >= self.max_entries:
 *             print(f"CYTHON ERROR! ParsedDisassembly disassembly entries {self.max_entries} exceeded, attempted to save {self.num_entries}")             # <<<<<<<<<<<<<<
 *         if self.index_index > self.num_bytes:
 *             print(f"CYTHON ERROR! ParsedDisassembly index_to_row entries {self.num_bytes} exceeded, attempted to save {self.index_index}")
 */
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    __pyx_t_11 = 127;
    __Pyx_INCREF(__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_d);
    __pyx_t_5 += 52;
    __Pyx_GIVEREF(__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_d);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_d);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_self->max_entries, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_exceeded_attempted_to_save);
    __pyx_t_5 += 29;
    __Pyx_GIVEREF(__pyx_kp_u_exceeded_attempted_to_save);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u_exceeded_attempted_to_save);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_self->num_entries, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_5, __pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 402, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "libudis/libudis.pyx":401
 *             else:
 *                 break
 *         if self.num_entries >= self.max_entries:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! ParsedDisassembly disassembly entries {self.max_entries} exceeded, attempted to save {self.num_entries}")
 *         if self.index_index > self.num_bytes:
 */
  }

  /* "libudis/libudis.pyx":403
 *         if self.num_entries >= self.max_entries:
 *             print(f"CYTHON ERROR! ParsedDisassembly disassembly entries {self.max_entries} exceeded, attempted to save {self.num_entries}")
 *         if self.index_index > self.num_bytes:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! ParsedDisassembly index_to_row entries {self.num_bytes} exceeded, attempted to save {self.index_index}")
 * 
 */
  __pyx_t_2 = ((__pyx_v_self->index_index > __pyx_v_self->num_bytes) != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":404
 *             print(f"CYTHON ERROR! ParsedDisassembly disassembly entries {self.max_entries} exceeded, attempted to save {self.num_entries}")
 *         if self.index_index > self.num_bytes:
 *             print(f"CYTHON ERROR! ParsedDisassembly index_to_row entries {self.num_bytes} exceeded, attempted to save {self.index_index}")             # <<<<<<<<<<<<<<
 * 
 *     cdef fix_offset_labels(self):
 */
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    __pyx_t_11 = 127;
    __Pyx_INCREF(__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_i);
    __pyx_t_5 += 53;
    __Pyx_GIVEREF(__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_i);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_i);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_self->num_bytes, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_6);
    __pyx_t_6 = 0;
    __Pyx_INCREF(__pyx_kp_u_exceeded_attempted_to_save);
    __pyx_t_5 += 29;
    __Pyx_GIVEREF(__pyx_kp_u_exceeded_attempted_to_save);
    PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_kp_u_exceeded_attempted_to_save);
    __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_self->index_index, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_6);
    PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_t_6);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_4, 4, __pyx_t_5, __pyx_t_11); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_6); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 404, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "libudis/libudis.pyx":403
 *         if self.num_entries >= self.max_entries:
 *             print(f"CYTHON ERROR! ParsedDisassembly disassembly entries {self.max_entries} exceeded, attempted to save {self.num_entries}")
 *         if self.index_index > self.num_bytes:             # <<<<<<<<<<<<<<
 *             print(f"CYTHON ERROR! ParsedDisassembly index_to_row entries {self.num_bytes} exceeded, attempted to save {self.index_index}")
 * 
 */
  }

  /* "libudis/libudis.pyx":383
 *         return self.num_entries
 * 
 *     cdef parse_next(self, parse_func_t processor, unsigned char *src, int num_bytes):             # <<<<<<<<<<<<<<
 *         cdef history_entry_t *h = &self.history_entries[self.num_entries]
 *         cdef int last_pc = self.current_pc + num_bytes
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.parse_next", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_count);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":406
 *             print(f"CYTHON ERROR! ParsedDisassembly index_to_row entries {self.num_bytes} exceeded, attempted to save {self.index_index}")
 * 
 *     cdef fix_offset_labels(self):             # <<<<<<<<<<<<<<
 *         # fast loop in C to check for references to addresses that are in the
 *         # middle of an instruction. If found, a discovered address is generated
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_17ParsedDisassembly_fix_offset_labels(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  int __pyx_v_pc;
  int __pyx_v_i;
  __pyx_t_5numpy_uint8_t *__pyx_v_jmp_target;
  __pyx_t_5numpy_uint32_t *__pyx_v_index_to_row;
  __pyx_t_5numpy_uint8_t __pyx_v_old_label;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_uint32_t *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("fix_offset_labels", 0);

  /* "libudis/libudis.pyx":410
 *         # middle of an instruction. If found, a discovered address is generated
 *         # at the first byte of the instruction
 *         cdef int pc = self.origin             # <<<<<<<<<<<<<<
 *         cdef int i = self.num_bytes
 *         cdef np.uint8_t *jmp_target = <np.uint8_t *>self.jmp_targets_data
 */
  __pyx_t_1 = __pyx_v_self->origin;
  __pyx_v_pc = __pyx_t_1;

  /* "libudis/libudis.pyx":411
 *         # at the first byte of the instruction
 *         cdef int pc = self.origin
 *         cdef int i = self.num_bytes             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t *jmp_target = <np.uint8_t *>self.jmp_targets_data
 *         cdef np.uint32_t *index_to_row = self.index_to_row_data
 */
  __pyx_t_1 = __pyx_v_self->num_bytes;
  __pyx_v_i = __pyx_t_1;

  /* "libudis/libudis.pyx":412
 *         cdef int pc = self.origin
 *         cdef int i = self.num_bytes
 *         cdef np.uint8_t *jmp_target = <np.uint8_t *>self.jmp_targets_data             # <<<<<<<<<<<<<<
 *         cdef np.uint32_t *index_to_row = self.index_to_row_data
 *         cdef np.uint8_t disassembler_type
 */
  __pyx_v_jmp_target = ((__pyx_t_5numpy_uint8_t *)__pyx_v_self->jmp_targets_data);

  /* "libudis/libudis.pyx":413
 *         cdef int i = self.num_bytes
 *         cdef np.uint8_t *jmp_target = <np.uint8_t *>self.jmp_targets_data
 *         cdef np.uint32_t *index_to_row = self.index_to_row_data             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t disassembler_type
 * 
 */
  __pyx_t_2 = __pyx_v_self->index_to_row_data;
  __pyx_v_index_to_row = __pyx_t_2;

  /* "libudis/libudis.pyx":417
 * 
 *         #print "pc=%04x, last=%04x, i=%04x" % (pc, pc + i, i)
 *         while i > 0:             # <<<<<<<<<<<<<<
 *             i -= 1
 *             old_label = jmp_target[(pc + i) & 0xffff]
 */
  while (1) {
    __pyx_t_3 = ((__pyx_v_i > 0) != 0);
    if (!__pyx_t_3) break;

    /* "libudis/libudis.pyx":418
 *         #print "pc=%04x, last=%04x, i=%04x" % (pc, pc + i, i)
 *         while i > 0:
 *             i -= 1             # <<<<<<<<<<<<<<
 *             old_label = jmp_target[(pc + i) & 0xffff]
 *             if old_label:
 */
    __pyx_v_i = (__pyx_v_i - 1);

    /* "libudis/libudis.pyx":419
 *         while i > 0:
 *             i -= 1
 *             old_label = jmp_target[(pc + i) & 0xffff]             # <<<<<<<<<<<<<<
 *             if old_label:
 *                 #print "disasm_info: found label %04x, index_to_row[%04x]=%04x" % (pc + i, i, index_to_row[i])
 */
    __pyx_v_old_label = (__pyx_v_jmp_target[((__pyx_v_pc + __pyx_v_i) & 0xffff)]);

    /* "libudis/libudis.pyx":420
 *             i -= 1
 *             old_label = jmp_target[(pc + i) & 0xffff]
 *             if old_label:             # <<<<<<<<<<<<<<
 *                 #print "disasm_info: found label %04x, index_to_row[%04x]=%04x" % (pc + i, i, index_to_row[i])
 *                 while index_to_row[i - 1] == index_to_row[i] and i > 1:
 */
    __pyx_t_3 = (__pyx_v_old_label != 0);
    if (__pyx_t_3) {

      /* "libudis/libudis.pyx":422
 *             if old_label:
 *                 #print "disasm_info: found label %04x, index_to_row[%04x]=%04x" % (pc + i, i, index_to_row[i])
 *                 while index_to_row[i - 1] == index_to_row[i] and i > 1:             # <<<<<<<<<<<<<<
 *                     i -= 1
 *                 #if labels[pc + i] == 0:
 */
      while (1) {
        __pyx_t_4 = (((__pyx_v_index_to_row[(__pyx_v_i - 1)]) == (__pyx_v_index_to_row[__pyx_v_i])) != 0);
        if (__pyx_t_4) {
        } else {
          __pyx_t_3 = __pyx_t_4;
          goto __pyx_L8_bool_binop_done;
        }
        __pyx_t_4 = ((__pyx_v_i > 1) != 0);
        __pyx_t_3 = __pyx_t_4;
        __pyx_L8_bool_binop_done:;
        if (!__pyx_t_3) break;

        /* "libudis/libudis.pyx":423
 *                 #print "disasm_info: found label %04x, index_to_row[%04x]=%04x" % (pc + i, i, index_to_row[i])
 *                 while index_to_row[i - 1] == index_to_row[i] and i > 1:
 *                     i -= 1             # <<<<<<<<<<<<<<
 *                 #if labels[pc + i] == 0:
 *                 #    print "  disasm_info: added label at %04x" % (pc + i)
 */
        __pyx_v_i = (__pyx_v_i - 1);
      }

      /* "libudis/libudis.pyx":426
 *                 #if labels[pc + i] == 0:
 *                 #    print "  disasm_info: added label at %04x" % (pc + i)
 *                 jmp_target[(pc + i) & 0xffff] = old_label             # <<<<<<<<<<<<<<
 * 
 *     def parse_test(self, np.uint8_t disasm_type, np.ndarray[np.uint8_t, ndim=1] src):
 */
      (__pyx_v_jmp_target[((__pyx_v_pc + __pyx_v_i) & 0xffff)]) = __pyx_v_old_label;

      /* "libudis/libudis.pyx":420
 *             i -= 1
 *             old_label = jmp_target[(pc + i) & 0xffff]
 *             if old_label:             # <<<<<<<<<<<<<<
 *                 #print "disasm_info: found label %04x, index_to_row[%04x]=%04x" % (pc + i, i, index_to_row[i])
 *                 while index_to_row[i - 1] == index_to_row[i] and i > 1:
 */
    }
  }

  /* "libudis/libudis.pyx":406
 *             print(f"CYTHON ERROR! ParsedDisassembly index_to_row entries {self.num_bytes} exceeded, attempted to save {self.index_index}")
 * 
 *     cdef fix_offset_labels(self):             # <<<<<<<<<<<<<<
 *         # fast loop in C to check for references to addresses that are in the
 *         # middle of an instruction. If found, a discovered address is generated
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":428
 *                 jmp_target[(pc + i) & 0xffff] = old_label
 * 
 *     def parse_test(self, np.uint8_t disasm_type, np.ndarray[np.uint8_t, ndim=1] src):             # <<<<<<<<<<<<<<
 *         cdef parse_func_t processor
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_5parse_test(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_5parse_test(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_uint8_t __pyx_v_disasm_type;
  PyArrayObject *__pyx_v_src = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse_test (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_disasm_type,&__pyx_n_s_src,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_disasm_type)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_src)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse_test", 1, 2, 2, 1); __PYX_ERR(0, 428, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse_test") < 0)) __PYX_ERR(0, 428, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_disasm_type = __Pyx_PyInt_As_npy_uint8(values[0]); if (unlikely((__pyx_v_disasm_type == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 428, __pyx_L3_error)
    __pyx_v_src = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse_test", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 428, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.parse_test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_src), __pyx_ptype_5numpy_ndarray, 1, "src", 0))) __PYX_ERR(0, 428, __pyx_L1_error)
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_4parse_test(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), __pyx_v_disasm_type, __pyx_v_src);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_4parse_test(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_disasm_type, PyArrayObject *__pyx_v_src) {
  __pyx_t_7libudis_7libudis_parse_func_t __pyx_v_processor;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_src;
  __Pyx_Buffer __pyx_pybuffer_src;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("parse_test", 0);
  __pyx_pybuffer_src.pybuffer.buf = NULL;
  __pyx_pybuffer_src.refcount = 0;
  __pyx_pybuffernd_src.data = NULL;
  __pyx_pybuffernd_src.rcbuffer = &__pyx_pybuffer_src;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_src.rcbuffer->pybuffer, (PyObject*)__pyx_v_src, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 428, __pyx_L1_error)
  }
  __pyx_pybuffernd_src.diminfo[0].strides = __pyx_pybuffernd_src.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_src.diminfo[0].shape = __pyx_pybuffernd_src.rcbuffer->pybuffer.shape[0];

  /* "libudis/libudis.pyx":431
 *         cdef parse_func_t processor
 * 
 *         processor = parser_map[disasm_type]             # <<<<<<<<<<<<<<
 *         # printf("processor = %lx\n", processor)
 *         self.parse_next(processor, <unsigned char *>src.data, len(src))
 */
  __pyx_v_processor = (parser_map[__pyx_v_disasm_type]);

  /* "libudis/libudis.pyx":433
 *         processor = parser_map[disasm_type]
 *         # printf("processor = %lx\n", processor)
 *         self.parse_next(processor, <unsigned char *>src.data, len(src))             # <<<<<<<<<<<<<<
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_src)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 433, __pyx_L1_error)
  __pyx_t_2 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self->__pyx_vtab)->parse_next(__pyx_v_self, __pyx_v_processor, ((unsigned char *)__pyx_v_src->data), __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":428
 *                 jmp_target[(pc + i) & 0xffff] = old_label
 * 
 *     def parse_test(self, np.uint8_t disasm_type, np.ndarray[np.uint8_t, ndim=1] src):             # <<<<<<<<<<<<<<
 *         cdef parse_func_t processor
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_src.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.parse_test", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_src.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":435
 *         self.parse_next(processor, <unsigned char *>src.data, len(src))
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         cdef history_entry_t *h = &self.history_entries[index]
 *         output = StringifiedDisassembly(index, num_lines_requested, self.jmp_targets, labels, mnemonic_lower, hex_lower)
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_7stringify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_7stringify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_index;
  int __pyx_v_num_lines_requested;
  PyObject *__pyx_v_labels = 0;
  PyObject *__pyx_v_mnemonic_lower = 0;
  PyObject *__pyx_v_hex_lower = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stringify (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_index,&__pyx_n_s_num_lines_requested,&__pyx_n_s_labels,&__pyx_n_s_mnemonic_lower,&__pyx_n_s_hex_lower,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_True);
    values[4] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_index)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_lines_requested)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("stringify", 0, 2, 5, 1); __PYX_ERR(0, 435, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_mnemonic_lower);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_hex_lower);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "stringify") < 0)) __PYX_ERR(0, 435, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_index = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 435, __pyx_L3_error)
    __pyx_v_num_lines_requested = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_num_lines_requested == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 435, __pyx_L3_error)
    __pyx_v_labels = values[2];
    __pyx_v_mnemonic_lower = values[3];
    __pyx_v_hex_lower = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stringify", 0, 2, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 435, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.stringify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6stringify(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), __pyx_v_index, __pyx_v_num_lines_requested, __pyx_v_labels, __pyx_v_mnemonic_lower, __pyx_v_hex_lower);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6stringify(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, int __pyx_v_index, int __pyx_v_num_lines_requested, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower) {
  struct __pyx_t_7libudis_7libudis_history_entry_t *__pyx_v_h;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *__pyx_v_output = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("stringify", 0);

  /* "libudis/libudis.pyx":436
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):
 *         cdef history_entry_t *h = &self.history_entries[index]             # <<<<<<<<<<<<<<
 *         output = StringifiedDisassembly(index, num_lines_requested, self.jmp_targets, labels, mnemonic_lower, hex_lower)
 *         output.parse_history_entries(h, num_lines_requested)
 */
  __pyx_v_h = (&(__pyx_v_self->history_entries[__pyx_v_index]));

  /* "libudis/libudis.pyx":437
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):
 *         cdef history_entry_t *h = &self.history_entries[index]
 *         output = StringifiedDisassembly(index, num_lines_requested, self.jmp_targets, labels, mnemonic_lower, hex_lower)             # <<<<<<<<<<<<<<
 *         output.parse_history_entries(h, num_lines_requested)
 *         return output
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_num_lines_requested); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(6); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->jmp_targets));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->jmp_targets));
  PyTuple_SET_ITEM(__pyx_t_3, 2, ((PyObject *)__pyx_v_self->jmp_targets));
  __Pyx_INCREF(__pyx_v_labels);
  __Pyx_GIVEREF(__pyx_v_labels);
  PyTuple_SET_ITEM(__pyx_t_3, 3, __pyx_v_labels);
  __Pyx_INCREF(__pyx_v_mnemonic_lower);
  __Pyx_GIVEREF(__pyx_v_mnemonic_lower);
  PyTuple_SET_ITEM(__pyx_t_3, 4, __pyx_v_mnemonic_lower);
  __Pyx_INCREF(__pyx_v_hex_lower);
  __Pyx_GIVEREF(__pyx_v_hex_lower);
  PyTuple_SET_ITEM(__pyx_t_3, 5, __pyx_v_hex_lower);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_8omnivore_12disassembler_7libudis_StringifiedDisassembly), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 437, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_output = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":438
 *         cdef history_entry_t *h = &self.history_entries[index]
 *         output = StringifiedDisassembly(index, num_lines_requested, self.jmp_targets, labels, mnemonic_lower, hex_lower)
 *         output.parse_history_entries(h, num_lines_requested)             # <<<<<<<<<<<<<<
 *         return output
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)__pyx_v_output->__pyx_vtab)->parse_history_entries(__pyx_v_output, __pyx_v_h, __pyx_v_num_lines_requested); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":439
 *         output = StringifiedDisassembly(index, num_lines_requested, self.jmp_targets, labels, mnemonic_lower, hex_lower)
 *         output.parse_history_entries(h, num_lines_requested)
 *         return output             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_output));
  __pyx_r = ((PyObject *)__pyx_v_output);
  goto __pyx_L0;

  /* "libudis/libudis.pyx":435
 *         self.parse_next(processor, <unsigned char *>src.data, len(src))
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         cdef history_entry_t *h = &self.history_entries[index]
 *         output = StringifiedDisassembly(index, num_lines_requested, self.jmp_targets, labels, mnemonic_lower, hex_lower)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.stringify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_output);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":346
 * cdef class ParsedDisassembly:
 *     cdef history_entry_t *history_entries
 *     cdef public int max_entries             # <<<<<<<<<<<<<<
 *     cdef int entry_size
 *     cdef public np.ndarray raw_entries
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->max_entries); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.max_entries.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 346, __pyx_L1_error)
  __pyx_v_self->max_entries = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.max_entries.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":348
 *     cdef public int max_entries
 *     cdef int entry_size
 *     cdef public np.ndarray raw_entries             # <<<<<<<<<<<<<<
 *     cdef int num_entries
 *     cdef public int origin
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->raw_entries));
  __pyx_r = ((PyObject *)__pyx_v_self->raw_entries);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 348, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->raw_entries);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->raw_entries));
  __pyx_v_self->raw_entries = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.raw_entries.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->raw_entries);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->raw_entries));
  __pyx_v_self->raw_entries = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":350
 *     cdef public np.ndarray raw_entries
 *     cdef int num_entries
 *     cdef public int origin             # <<<<<<<<<<<<<<
 *     cdef int last_pc
 *     cdef int current_pc
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->origin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.origin.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 350, __pyx_L1_error)
  __pyx_v_self->origin = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.origin.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":353
 *     cdef int last_pc
 *     cdef int current_pc
 *     cdef public np.ndarray jmp_targets             # <<<<<<<<<<<<<<
 *     cdef jmp_targets_t *jmp_targets_data
 *     cdef public int num_bytes
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_r = ((PyObject *)__pyx_v_self->jmp_targets);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 353, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.jmp_targets.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":355
 *     cdef public np.ndarray jmp_targets
 *     cdef jmp_targets_t *jmp_targets_data
 *     cdef public int num_bytes             # <<<<<<<<<<<<<<
 *     cdef np.uint32_t *index_to_row_data
 *     cdef public np.ndarray index_to_row
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->num_bytes); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.num_bytes.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 355, __pyx_L1_error)
  __pyx_v_self->num_bytes = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.num_bytes.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":357
 *     cdef public int num_bytes
 *     cdef np.uint32_t *index_to_row_data
 *     cdef public np.ndarray index_to_row             # <<<<<<<<<<<<<<
 *     cdef int index_index
 *     cdef int max_text_lines
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->index_to_row));
  __pyx_r = ((PyObject *)__pyx_v_self->index_to_row);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 357, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->index_to_row);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->index_to_row));
  __pyx_v_self->index_to_row = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.index_to_row.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->index_to_row);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->index_to_row));
  __pyx_v_self->index_to_row = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_8__reduce_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_10__setstate_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17ParsedDisassembly_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.ParsedDisassembly.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":449
 *     cdef np.uint8_t default_disasm_type
 * 
 *     def __init__(self, def_disasm_type=0, split_comments=[data_style]):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         for i in range(256):
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_def_disasm_type = 0;
  PyObject *__pyx_v_split_comments = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_def_disasm_type,&__pyx_n_s_split_comments,0};
    PyObject* values[2] = {0,0};
    values[0] = ((PyObject *)__pyx_int_0);
    values[1] = __pyx_k__13;
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_def_disasm_type);
          if (value) { values[0] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_split_comments);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 449, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_def_disasm_type = values[0];
    __pyx_v_split_comments = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 449, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig___init__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *)__pyx_v_self), __pyx_v_def_disasm_type, __pyx_v_split_comments);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, PyObject *__pyx_v_def_disasm_type, PyObject *__pyx_v_split_comments) {
  int __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_uint8_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "libudis/libudis.pyx":451
 *     def __init__(self, def_disasm_type=0, split_comments=[data_style]):
 *         cdef int i
 *         for i in range(256):             # <<<<<<<<<<<<<<
 *             self.c_split_comments[i] = 1 if i in split_comments else 0
 *         self.default_disasm_type = def_disasm_type
 */
  for (__pyx_t_1 = 0; __pyx_t_1 < 0x100; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "libudis/libudis.pyx":452
 *         cdef int i
 *         for i in range(256):
 *             self.c_split_comments[i] = 1 if i in split_comments else 0             # <<<<<<<<<<<<<<
 *         self.default_disasm_type = def_disasm_type
 * 
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_3, __pyx_v_split_comments, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 452, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if ((__pyx_t_4 != 0)) {
      __pyx_t_2 = 1;
    } else {
      __pyx_t_2 = 0;
    }
    (__pyx_v_self->c_split_comments[__pyx_v_i]) = __pyx_t_2;
  }

  /* "libudis/libudis.pyx":453
 *         for i in range(256):
 *             self.c_split_comments[i] = 1 if i in split_comments else 0
 *         self.default_disasm_type = def_disasm_type             # <<<<<<<<<<<<<<
 * 
 *     def get_parser(self, num_entries, origin, num_bytes):
 */
  __pyx_t_2 = __Pyx_PyInt_As_npy_uint8(__pyx_v_def_disasm_type); if (unlikely((__pyx_t_2 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(0, 453, __pyx_L1_error)
  __pyx_v_self->default_disasm_type = __pyx_t_2;

  /* "libudis/libudis.pyx":449
 *     cdef np.uint8_t default_disasm_type
 * 
 *     def __init__(self, def_disasm_type=0, split_comments=[data_style]):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         for i in range(256):
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":455
 *         self.default_disasm_type = def_disasm_type
 * 
 *     def get_parser(self, num_entries, origin, num_bytes):             # <<<<<<<<<<<<<<
 *         # has to be a python function because it can be overridden in
 *         # subclasses
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_3get_parser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_3get_parser(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_num_entries = 0;
  PyObject *__pyx_v_origin = 0;
  PyObject *__pyx_v_num_bytes = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_parser (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_num_entries,&__pyx_n_s_origin,&__pyx_n_s_num_bytes,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_entries)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_origin)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_parser", 1, 3, 3, 1); __PYX_ERR(0, 455, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_bytes)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_parser", 1, 3, 3, 2); __PYX_ERR(0, 455, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_parser") < 0)) __PYX_ERR(0, 455, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_num_entries = values[0];
    __pyx_v_origin = values[1];
    __pyx_v_num_bytes = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_parser", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 455, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.get_parser", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_2get_parser(((struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *)__pyx_v_self), __pyx_v_num_entries, __pyx_v_origin, __pyx_v_num_bytes);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_2get_parser(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, PyObject *__pyx_v_num_entries, PyObject *__pyx_v_origin, PyObject *__pyx_v_num_bytes) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannySetupContext("get_parser", 0);

  /* "libudis/libudis.pyx":458
 *         # has to be a python function because it can be overridden in
 *         # subclasses
 *         return ParsedDisassembly(num_entries, origin, num_bytes)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_num_entries);
  __Pyx_GIVEREF(__pyx_v_num_entries);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_num_entries);
  __Pyx_INCREF(__pyx_v_origin);
  __Pyx_GIVEREF(__pyx_v_origin);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_origin);
  __Pyx_INCREF(__pyx_v_num_bytes);
  __Pyx_GIVEREF(__pyx_v_num_bytes);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_num_bytes);
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_8omnivore_12disassembler_7libudis_ParsedDisassembly), __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":455
 *         self.default_disasm_type = def_disasm_type
 * 
 *     def get_parser(self, num_entries, origin, num_bytes):             # <<<<<<<<<<<<<<
 *         # has to be a python function because it can be overridden in
 *         # subclasses
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.get_parser", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":462
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def parse(self, segment, num_entries):             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t s, t
 *         cdef int comment_bit_mask = 0x40
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_5parse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_5parse(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_segment = 0;
  PyObject *__pyx_v_num_entries = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_segment,&__pyx_n_s_num_entries,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_segment)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_entries)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse", 1, 2, 2, 1); __PYX_ERR(0, 462, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse") < 0)) __PYX_ERR(0, 462, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_segment = values[0];
    __pyx_v_num_entries = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 462, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_4parse(((struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *)__pyx_v_self), __pyx_v_segment, __pyx_v_num_entries);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_4parse(struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, PyObject *__pyx_v_segment, PyObject *__pyx_v_num_entries) {
  __pyx_t_5numpy_uint8_t __pyx_v_s;
  __pyx_t_5numpy_uint8_t __pyx_v_t;
  int __pyx_v_comment_bit_mask;
  PyObject *__pyx_v_src_copy = NULL;
  __pyx_t_5numpy_uint8_t *__pyx_v_src;
  PyObject *__pyx_v_style_copy = NULL;
  __pyx_t_5numpy_uint8_t *__pyx_v_c_style;
  PyObject *__pyx_v_disasm_type_copy = NULL;
  __pyx_t_5numpy_uint8_t *__pyx_v_c_disasm_type;
  int __pyx_v_num_bytes;
  int __pyx_v_origin;
  CYTHON_UNUSED int __pyx_v_end_addr;
  CYTHON_UNUSED int __pyx_v_pc;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *__pyx_v_parsed = 0;
  int __pyx_v_first_index;
  __pyx_t_5numpy_uint8_t __pyx_v_current_disasm_type;
  int __pyx_v_start_index;
  int __pyx_v_end_index;
  int __pyx_v_count;
  __pyx_t_7libudis_7libudis_parse_func_t __pyx_v_processor;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __pyx_t_5numpy_uint8_t *__pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  __pyx_t_5numpy_uint8_t __pyx_t_13;
  int __pyx_t_14;
  __Pyx_RefNannySetupContext("parse", 0);

  /* "libudis/libudis.pyx":464
 *     def parse(self, segment, num_entries):
 *         cdef np.uint8_t s, t
 *         cdef int comment_bit_mask = 0x40             # <<<<<<<<<<<<<<
 * 
 *         src_copy = segment.data.tobytes()
 */
  __pyx_v_comment_bit_mask = 0x40;

  /* "libudis/libudis.pyx":466
 *         cdef int comment_bit_mask = 0x40
 * 
 *         src_copy = segment.data.tobytes()             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t *src = <np.uint8_t *>src_copy
 *         style_copy = segment.style.tobytes()
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_segment, __pyx_n_s_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tobytes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_src_copy = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":467
 * 
 *         src_copy = segment.data.tobytes()
 *         cdef np.uint8_t *src = <np.uint8_t *>src_copy             # <<<<<<<<<<<<<<
 *         style_copy = segment.style.tobytes()
 *         cdef np.uint8_t *c_style = <np.uint8_t *>style_copy
 */
  __pyx_t_4 = __Pyx_PyObject_AsWritableUString(__pyx_v_src_copy); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 467, __pyx_L1_error)
  __pyx_v_src = ((__pyx_t_5numpy_uint8_t *)__pyx_t_4);

  /* "libudis/libudis.pyx":468
 *         src_copy = segment.data.tobytes()
 *         cdef np.uint8_t *src = <np.uint8_t *>src_copy
 *         style_copy = segment.style.tobytes()             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t *c_style = <np.uint8_t *>style_copy
 *         disasm_type_copy = segment.disasm_type.tobytes()
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_segment, __pyx_n_s_style); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_tobytes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_style_copy = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":469
 *         cdef np.uint8_t *src = <np.uint8_t *>src_copy
 *         style_copy = segment.style.tobytes()
 *         cdef np.uint8_t *c_style = <np.uint8_t *>style_copy             # <<<<<<<<<<<<<<
 *         disasm_type_copy = segment.disasm_type.tobytes()
 *         cdef np.uint8_t *c_disasm_type = <np.uint8_t *>disasm_type_copy
 */
  __pyx_t_4 = __Pyx_PyObject_AsWritableUString(__pyx_v_style_copy); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 469, __pyx_L1_error)
  __pyx_v_c_style = ((__pyx_t_5numpy_uint8_t *)__pyx_t_4);

  /* "libudis/libudis.pyx":470
 *         style_copy = segment.style.tobytes()
 *         cdef np.uint8_t *c_style = <np.uint8_t *>style_copy
 *         disasm_type_copy = segment.disasm_type.tobytes()             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t *c_disasm_type = <np.uint8_t *>disasm_type_copy
 *         cdef int num_bytes = len(src_copy)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_segment, __pyx_n_s_disasm_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_tobytes); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_disasm_type_copy = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":471
 *         cdef np.uint8_t *c_style = <np.uint8_t *>style_copy
 *         disasm_type_copy = segment.disasm_type.tobytes()
 *         cdef np.uint8_t *c_disasm_type = <np.uint8_t *>disasm_type_copy             # <<<<<<<<<<<<<<
 *         cdef int num_bytes = len(src_copy)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_AsWritableUString(__pyx_v_disasm_type_copy); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) __PYX_ERR(0, 471, __pyx_L1_error)
  __pyx_v_c_disasm_type = ((__pyx_t_5numpy_uint8_t *)__pyx_t_4);

  /* "libudis/libudis.pyx":472
 *         disasm_type_copy = segment.disasm_type.tobytes()
 *         cdef np.uint8_t *c_disasm_type = <np.uint8_t *>disasm_type_copy
 *         cdef int num_bytes = len(src_copy)             # <<<<<<<<<<<<<<
 * 
 *         cdef int origin = segment.origin
 */
  __pyx_t_5 = PyObject_Length(__pyx_v_src_copy); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 472, __pyx_L1_error)
  __pyx_v_num_bytes = __pyx_t_5;

  /* "libudis/libudis.pyx":474
 *         cdef int num_bytes = len(src_copy)
 * 
 *         cdef int origin = segment.origin             # <<<<<<<<<<<<<<
 *         cdef int end_addr = origin + len(segment)
 *         cdef int pc = origin
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_segment, __pyx_n_s_origin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_t_1); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_origin = __pyx_t_6;

  /* "libudis/libudis.pyx":475
 * 
 *         cdef int origin = segment.origin
 *         cdef int end_addr = origin + len(segment)             # <<<<<<<<<<<<<<
 *         cdef int pc = origin
 * 
 */
  __pyx_t_5 = PyObject_Length(__pyx_v_segment); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 475, __pyx_L1_error)
  __pyx_v_end_addr = (__pyx_v_origin + __pyx_t_5);

  /* "libudis/libudis.pyx":476
 *         cdef int origin = segment.origin
 *         cdef int end_addr = origin + len(segment)
 *         cdef int pc = origin             # <<<<<<<<<<<<<<
 * 
 *         if num_bytes < 1:
 */
  __pyx_v_pc = __pyx_v_origin;

  /* "libudis/libudis.pyx":478
 *         cdef int pc = origin
 * 
 *         if num_bytes < 1:             # <<<<<<<<<<<<<<
 *             return self.get_parser(0, origin, 0)
 *         cdef ParsedDisassembly parsed = self.get_parser(num_entries, origin, num_bytes)
 */
  __pyx_t_7 = ((__pyx_v_num_bytes < 1) != 0);
  if (__pyx_t_7) {

    /* "libudis/libudis.pyx":479
 * 
 *         if num_bytes < 1:
 *             return self.get_parser(0, origin, 0)             # <<<<<<<<<<<<<<
 *         cdef ParsedDisassembly parsed = self.get_parser(num_entries, origin, num_bytes)
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_parser); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_origin); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 479, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = NULL;
    __pyx_t_6 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_6 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_int_0, __pyx_t_2, __pyx_int_0};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
      PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_int_0, __pyx_t_2, __pyx_int_0};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    } else
    #endif
    {
      __pyx_t_9 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      if (__pyx_t_8) {
        __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_8); __pyx_t_8 = NULL;
      }
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_9, 0+__pyx_t_6, __pyx_int_0);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_9, 1+__pyx_t_6, __pyx_t_2);
      __Pyx_INCREF(__pyx_int_0);
      __Pyx_GIVEREF(__pyx_int_0);
      PyTuple_SET_ITEM(__pyx_t_9, 2+__pyx_t_6, __pyx_int_0);
      __pyx_t_2 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_9, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":478
 *         cdef int pc = origin
 * 
 *         if num_bytes < 1:             # <<<<<<<<<<<<<<
 *             return self.get_parser(0, origin, 0)
 *         cdef ParsedDisassembly parsed = self.get_parser(num_entries, origin, num_bytes)
 */
  }

  /* "libudis/libudis.pyx":480
 *         if num_bytes < 1:
 *             return self.get_parser(0, origin, 0)
 *         cdef ParsedDisassembly parsed = self.get_parser(num_entries, origin, num_bytes)             # <<<<<<<<<<<<<<
 * 
 *         cdef int first_index = 0
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_parser); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_9 = __Pyx_PyInt_From_int(__pyx_v_origin); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_num_bytes); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = NULL;
  __pyx_t_6 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_6 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_v_num_entries, __pyx_t_9, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_v_num_entries, __pyx_t_9, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_6, 3+__pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_10 = PyTuple_New(3+__pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (__pyx_t_8) {
      __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_8); __pyx_t_8 = NULL;
    }
    __Pyx_INCREF(__pyx_v_num_entries);
    __Pyx_GIVEREF(__pyx_v_num_entries);
    PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_6, __pyx_v_num_entries);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_6, __pyx_t_9);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_6, __pyx_t_2);
    __pyx_t_9 = 0;
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_8omnivore_12disassembler_7libudis_ParsedDisassembly))))) __PYX_ERR(0, 480, __pyx_L1_error)
  __pyx_v_parsed = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":482
 *         cdef ParsedDisassembly parsed = self.get_parser(num_entries, origin, num_bytes)
 * 
 *         cdef int first_index = 0             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t current_disasm_type = c_disasm_type[0]
 *         cdef int start_index
 */
  __pyx_v_first_index = 0;

  /* "libudis/libudis.pyx":483
 * 
 *         cdef int first_index = 0
 *         cdef np.uint8_t current_disasm_type = c_disasm_type[0]             # <<<<<<<<<<<<<<
 *         cdef int start_index
 *         cdef int end_index = 0
 */
  __pyx_v_current_disasm_type = (__pyx_v_c_disasm_type[0]);

  /* "libudis/libudis.pyx":485
 *         cdef np.uint8_t current_disasm_type = c_disasm_type[0]
 *         cdef int start_index
 *         cdef int end_index = 0             # <<<<<<<<<<<<<<
 *         cdef int count
 *         # print "CYTHON FAST_GET_ENTIRE", style_copy
 */
  __pyx_v_end_index = 0;

  /* "libudis/libudis.pyx":488
 *         cdef int count
 *         # print "CYTHON FAST_GET_ENTIRE", style_copy
 *         for end_index in range(1, num_bytes):             # <<<<<<<<<<<<<<
 *             s = c_style[end_index]
 *             t = c_disasm_type[end_index]
 */
  __pyx_t_6 = __pyx_v_num_bytes;
  __pyx_t_11 = __pyx_t_6;
  for (__pyx_t_12 = 1; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
    __pyx_v_end_index = __pyx_t_12;

    /* "libudis/libudis.pyx":489
 *         # print "CYTHON FAST_GET_ENTIRE", style_copy
 *         for end_index in range(1, num_bytes):
 *             s = c_style[end_index]             # <<<<<<<<<<<<<<
 *             t = c_disasm_type[end_index]
 *             if t > 127:
 */
    __pyx_v_s = (__pyx_v_c_style[__pyx_v_end_index]);

    /* "libudis/libudis.pyx":490
 *         for end_index in range(1, num_bytes):
 *             s = c_style[end_index]
 *             t = c_disasm_type[end_index]             # <<<<<<<<<<<<<<
 *             if t > 127:
 *                 t = self.default_disasm_type
 */
    __pyx_v_t = (__pyx_v_c_disasm_type[__pyx_v_end_index]);

    /* "libudis/libudis.pyx":491
 *             s = c_style[end_index]
 *             t = c_disasm_type[end_index]
 *             if t > 127:             # <<<<<<<<<<<<<<
 *                 t = self.default_disasm_type
 *             # print "%04x" % i, s, s2,
 */
    __pyx_t_7 = ((__pyx_v_t > 0x7F) != 0);
    if (__pyx_t_7) {

      /* "libudis/libudis.pyx":492
 *             t = c_disasm_type[end_index]
 *             if t > 127:
 *                 t = self.default_disasm_type             # <<<<<<<<<<<<<<
 *             # print "%04x" % i, s, s2,
 *             if s & comment_bit_mask:
 */
      __pyx_t_13 = __pyx_v_self->default_disasm_type;
      __pyx_v_t = __pyx_t_13;

      /* "libudis/libudis.pyx":491
 *             s = c_style[end_index]
 *             t = c_disasm_type[end_index]
 *             if t > 127:             # <<<<<<<<<<<<<<
 *                 t = self.default_disasm_type
 *             # print "%04x" % i, s, s2,
 */
    }

    /* "libudis/libudis.pyx":494
 *                 t = self.default_disasm_type
 *             # print "%04x" % i, s, s2,
 *             if s & comment_bit_mask:             # <<<<<<<<<<<<<<
 *                 if t == current_disasm_type and not self.c_split_comments[t]:
 *                     # print("same w/skippable comment")
 */
    __pyx_t_7 = ((__pyx_v_s & __pyx_v_comment_bit_mask) != 0);
    if (__pyx_t_7) {

      /* "libudis/libudis.pyx":495
 *             # print "%04x" % i, s, s2,
 *             if s & comment_bit_mask:
 *                 if t == current_disasm_type and not self.c_split_comments[t]:             # <<<<<<<<<<<<<<
 *                     # print("same w/skippable comment")
 *                     continue
 */
      __pyx_t_14 = ((__pyx_v_t == __pyx_v_current_disasm_type) != 0);
      if (__pyx_t_14) {
      } else {
        __pyx_t_7 = __pyx_t_14;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_14 = ((!((__pyx_v_self->c_split_comments[__pyx_v_t]) != 0)) != 0);
      __pyx_t_7 = __pyx_t_14;
      __pyx_L9_bool_binop_done:;
      if (__pyx_t_7) {

        /* "libudis/libudis.pyx":497
 *                 if t == current_disasm_type and not self.c_split_comments[t]:
 *                     # print("same w/skippable comment")
 *                     continue             # <<<<<<<<<<<<<<
 *             elif t == current_disasm_type:
 *                 # print "same"
 */
        goto __pyx_L4_continue;

        /* "libudis/libudis.pyx":495
 *             # print "%04x" % i, s, s2,
 *             if s & comment_bit_mask:
 *                 if t == current_disasm_type and not self.c_split_comments[t]:             # <<<<<<<<<<<<<<
 *                     # print("same w/skippable comment")
 *                     continue
 */
      }

      /* "libudis/libudis.pyx":494
 *                 t = self.default_disasm_type
 *             # print "%04x" % i, s, s2,
 *             if s & comment_bit_mask:             # <<<<<<<<<<<<<<
 *                 if t == current_disasm_type and not self.c_split_comments[t]:
 *                     # print("same w/skippable comment")
 */
      goto __pyx_L7;
    }

    /* "libudis/libudis.pyx":498
 *                     # print("same w/skippable comment")
 *                     continue
 *             elif t == current_disasm_type:             # <<<<<<<<<<<<<<
 *                 # print "same"
 *                 continue
 */
    __pyx_t_7 = ((__pyx_v_t == __pyx_v_current_disasm_type) != 0);
    if (__pyx_t_7) {

      /* "libudis/libudis.pyx":500
 *             elif t == current_disasm_type:
 *                 # print "same"
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             # process chuck here:
 */
      goto __pyx_L4_continue;

      /* "libudis/libudis.pyx":498
 *                     # print("same w/skippable comment")
 *                     continue
 *             elif t == current_disasm_type:             # <<<<<<<<<<<<<<
 *                 # print "same"
 *                 continue
 */
    }
    __pyx_L7:;

    /* "libudis/libudis.pyx":503
 * 
 *             # process chuck here:
 *             start_index = first_index             # <<<<<<<<<<<<<<
 *             count = end_index - start_index
 *             # print("break here -> %x:%x = %s" % (start_index, end_index, current_disasm_type))
 */
    __pyx_v_start_index = __pyx_v_first_index;

    /* "libudis/libudis.pyx":504
 *             # process chuck here:
 *             start_index = first_index
 *             count = end_index - start_index             # <<<<<<<<<<<<<<
 *             # print("break here -> %x:%x = %s" % (start_index, end_index, current_disasm_type))
 *             processor = parser_map[current_disasm_type]
 */
    __pyx_v_count = (__pyx_v_end_index - __pyx_v_start_index);

    /* "libudis/libudis.pyx":506
 *             count = end_index - start_index
 *             # print("break here -> %x:%x = %s" % (start_index, end_index, current_disasm_type))
 *             processor = parser_map[current_disasm_type]             # <<<<<<<<<<<<<<
 *             parsed.parse_next(processor, src, count)
 *             src += count
 */
    __pyx_v_processor = (parser_map[__pyx_v_current_disasm_type]);

    /* "libudis/libudis.pyx":507
 *             # print("break here -> %x:%x = %s" % (start_index, end_index, current_disasm_type))
 *             processor = parser_map[current_disasm_type]
 *             parsed.parse_next(processor, src, count)             # <<<<<<<<<<<<<<
 *             src += count
 *             first_index = end_index
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_parsed->__pyx_vtab)->parse_next(__pyx_v_parsed, __pyx_v_processor, __pyx_v_src, __pyx_v_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 507, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "libudis/libudis.pyx":508
 *             processor = parser_map[current_disasm_type]
 *             parsed.parse_next(processor, src, count)
 *             src += count             # <<<<<<<<<<<<<<
 *             first_index = end_index
 *             current_disasm_type = t
 */
    __pyx_v_src = (__pyx_v_src + __pyx_v_count);

    /* "libudis/libudis.pyx":509
 *             parsed.parse_next(processor, src, count)
 *             src += count
 *             first_index = end_index             # <<<<<<<<<<<<<<
 *             current_disasm_type = t
 * 
 */
    __pyx_v_first_index = __pyx_v_end_index;

    /* "libudis/libudis.pyx":510
 *             src += count
 *             first_index = end_index
 *             current_disasm_type = t             # <<<<<<<<<<<<<<
 * 
 *         # process last chunk
 */
    __pyx_v_current_disasm_type = __pyx_v_t;
    __pyx_L4_continue:;
  }

  /* "libudis/libudis.pyx":513
 * 
 *         # process last chunk
 *         start_index = first_index             # <<<<<<<<<<<<<<
 *         end_index += 1  # i is last byte tested, need +1 to include it in the range
 *         count = end_index - start_index
 */
  __pyx_v_start_index = __pyx_v_first_index;

  /* "libudis/libudis.pyx":514
 *         # process last chunk
 *         start_index = first_index
 *         end_index += 1  # i is last byte tested, need +1 to include it in the range             # <<<<<<<<<<<<<<
 *         count = end_index - start_index
 *         # print("final break here -> %x:%x = %s, count=%x" % (start_index, end_index, current_disasm_type, num_bytes))
 */
  __pyx_v_end_index = (__pyx_v_end_index + 1);

  /* "libudis/libudis.pyx":515
 *         start_index = first_index
 *         end_index += 1  # i is last byte tested, need +1 to include it in the range
 *         count = end_index - start_index             # <<<<<<<<<<<<<<
 *         # print("final break here -> %x:%x = %s, count=%x" % (start_index, end_index, current_disasm_type, num_bytes))
 *         processor = parser_map[current_disasm_type]
 */
  __pyx_v_count = (__pyx_v_end_index - __pyx_v_start_index);

  /* "libudis/libudis.pyx":517
 *         count = end_index - start_index
 *         # print("final break here -> %x:%x = %s, count=%x" % (start_index, end_index, current_disasm_type, num_bytes))
 *         processor = parser_map[current_disasm_type]             # <<<<<<<<<<<<<<
 *         parsed.parse_next(processor, src, count)
 * 
 */
  __pyx_v_processor = (parser_map[__pyx_v_current_disasm_type]);

  /* "libudis/libudis.pyx":518
 *         # print("final break here -> %x:%x = %s, count=%x" % (start_index, end_index, current_disasm_type, num_bytes))
 *         processor = parser_map[current_disasm_type]
 *         parsed.parse_next(processor, src, count)             # <<<<<<<<<<<<<<
 * 
 *         parsed.fix_offset_labels()
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_parsed->__pyx_vtab)->parse_next(__pyx_v_parsed, __pyx_v_processor, __pyx_v_src, __pyx_v_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":520
 *         parsed.parse_next(processor, src, count)
 * 
 *         parsed.fix_offset_labels()             # <<<<<<<<<<<<<<
 *         # print("finished offset label generation")
 *         return parsed
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly *)__pyx_v_parsed->__pyx_vtab)->fix_offset_labels(__pyx_v_parsed); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":522
 *         parsed.fix_offset_labels()
 *         # print("finished offset label generation")
 *         return parsed             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_parsed));
  __pyx_r = ((PyObject *)__pyx_v_parsed);
  goto __pyx_L0;

  /* "libudis/libudis.pyx":462
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def parse(self, segment, num_entries):             # <<<<<<<<<<<<<<
 *         cdef np.uint8_t s, t
 *         cdef int comment_bit_mask = 0x40
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_src_copy);
  __Pyx_XDECREF(__pyx_v_style_copy);
  __Pyx_XDECREF(__pyx_v_disasm_type_copy);
  __Pyx_XDECREF((PyObject *)__pyx_v_parsed);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_7__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_6__reduce_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_9__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_8__setstate_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_17DisassemblyConfig_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.DisassemblyConfig.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":539
 *     cdef char *hex_case
 * 
 *     def __init__(self, max_lines, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         cdef long addr
 * 
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_max_lines = 0;
  PyObject *__pyx_v_labels = 0;
  PyObject *__pyx_v_mnemonic_lower = 0;
  PyObject *__pyx_v_hex_lower = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_max_lines,&__pyx_n_s_labels,&__pyx_n_s_mnemonic_lower,&__pyx_n_s_hex_lower,0};
    PyObject* values[4] = {0,0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_True);
    values[3] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_max_lines)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[1] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_mnemonic_lower);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_hex_lower);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 539, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_max_lines = values[0];
    __pyx_v_labels = values[1];
    __pyx_v_mnemonic_lower = values[2];
    __pyx_v_hex_lower = values[3];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 4, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 539, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory___init__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), __pyx_v_max_lines, __pyx_v_labels, __pyx_v_mnemonic_lower, __pyx_v_hex_lower);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_max_lines, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower) {
  long __pyx_v_addr;
  char *__pyx_v_text;
  struct __pyx_t_7libudis_7libudis_label_info_t *__pyx_v_info;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  char *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  long __pyx_t_10;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "libudis/libudis.pyx":542
 *         cdef long addr
 * 
 *         self.history_text = TextStorage(max_lines)             # <<<<<<<<<<<<<<
 *         self.result_text = TextStorage(max_lines)
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage), __pyx_v_max_lines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->history_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->history_text));
  __pyx_v_self->history_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":543
 * 
 *         self.history_text = TextStorage(max_lines)
 *         self.result_text = TextStorage(max_lines)             # <<<<<<<<<<<<<<
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage), __pyx_v_max_lines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->result_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->result_text));
  __pyx_v_self->result_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":544
 *         self.history_text = TextStorage(max_lines)
 *         self.result_text = TextStorage(max_lines)
 *         self.mnemonic_case = 1 if mnemonic_lower else 0             # <<<<<<<<<<<<<<
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 *         self.clear()
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_mnemonic_lower); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 544, __pyx_L1_error)
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_self->mnemonic_case = __pyx_t_2;

  /* "libudis/libudis.pyx":545
 *         self.result_text = TextStorage(max_lines)
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper             # <<<<<<<<<<<<<<
 *         self.clear()
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)
 */
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_hex_lower); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 545, __pyx_L1_error)
  if (__pyx_t_3) {
    __pyx_t_4 = __pyx_v_8omnivore_12disassembler_7libudis_hexdigits_lower;
  } else {
    __pyx_t_4 = __pyx_v_8omnivore_12disassembler_7libudis_hexdigits_upper;
  }
  __pyx_v_self->hex_case = __pyx_t_4;

  /* "libudis/libudis.pyx":546
 *         self.mnemonic_case = 1 if mnemonic_lower else 0
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 *         self.clear()             # <<<<<<<<<<<<<<
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self->__pyx_vtab)->clear(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":547
 *         self.hex_case = hexdigits_lower if hex_lower else hexdigits_upper
 *         self.clear()
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((sizeof(struct __pyx_t_7libudis_7libudis_jmp_targets_t))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_uint8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_8) < 0) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_6, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_8) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_8, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 547, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_8);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "libudis/libudis.pyx":548
 *         self.clear()
 *         self.jmp_targets = np.zeros(sizeof(jmp_targets_t), dtype=np.uint8)
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data             # <<<<<<<<<<<<<<
 * 
 *         if labels is not None:
 */
  __pyx_v_self->jmp_targets_data = ((struct __pyx_t_7libudis_7libudis_jmp_targets_t *)__pyx_v_self->jmp_targets->data);

  /* "libudis/libudis.pyx":550
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 *         if labels is not None:             # <<<<<<<<<<<<<<
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr
 */
  __pyx_t_3 = (__pyx_v_labels != Py_None);
  __pyx_t_9 = (__pyx_t_3 != 0);
  if (__pyx_t_9) {

    /* "libudis/libudis.pyx":551
 * 
 *         if labels is not None:
 *             addr = labels.get_text_storage_addr()             # <<<<<<<<<<<<<<
 *             text = <char *>addr
 *             self.jmp_targets_data.text_storage = text
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_labels, __pyx_n_s_get_text_storage_addr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 551, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_8 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 551, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_10 = __Pyx_PyInt_As_long(__pyx_t_8); if (unlikely((__pyx_t_10 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 551, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_addr = __pyx_t_10;

    /* "libudis/libudis.pyx":552
 *         if labels is not None:
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr             # <<<<<<<<<<<<<<
 *             self.jmp_targets_data.text_storage = text
 * 
 */
    __pyx_v_text = ((char *)__pyx_v_addr);

    /* "libudis/libudis.pyx":553
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr
 *             self.jmp_targets_data.text_storage = text             # <<<<<<<<<<<<<<
 * 
 *             addr = labels.get_label_data_addr()
 */
    __pyx_v_self->jmp_targets_data->text_storage = __pyx_v_text;

    /* "libudis/libudis.pyx":555
 *             self.jmp_targets_data.text_storage = text
 * 
 *             addr = labels.get_label_data_addr()             # <<<<<<<<<<<<<<
 *             info = <label_info_t *>addr
 *             self.jmp_targets_data.labels = info
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_labels, __pyx_n_s_get_label_data_addr); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_8 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_10 = __Pyx_PyInt_As_long(__pyx_t_8); if (unlikely((__pyx_t_10 == (long)-1) && PyErr_Occurred())) __PYX_ERR(0, 555, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_addr = __pyx_t_10;

    /* "libudis/libudis.pyx":556
 * 
 *             addr = labels.get_label_data_addr()
 *             info = <label_info_t *>addr             # <<<<<<<<<<<<<<
 *             self.jmp_targets_data.labels = info
 *         else:
 */
    __pyx_v_info = ((struct __pyx_t_7libudis_7libudis_label_info_t *)__pyx_v_addr);

    /* "libudis/libudis.pyx":557
 *             addr = labels.get_label_data_addr()
 *             info = <label_info_t *>addr
 *             self.jmp_targets_data.labels = info             # <<<<<<<<<<<<<<
 *         else:
 *             self.jmp_targets_data.text_storage = <char *>0
 */
    __pyx_v_self->jmp_targets_data->labels = __pyx_v_info;

    /* "libudis/libudis.pyx":550
 *         self.jmp_targets_data = <jmp_targets_t *>self.jmp_targets.data
 * 
 *         if labels is not None:             # <<<<<<<<<<<<<<
 *             addr = labels.get_text_storage_addr()
 *             text = <char *>addr
 */
    goto __pyx_L3;
  }

  /* "libudis/libudis.pyx":559
 *             self.jmp_targets_data.labels = info
 *         else:
 *             self.jmp_targets_data.text_storage = <char *>0             # <<<<<<<<<<<<<<
 *             self.jmp_targets_data.labels = <label_info_t *>0
 * 
 */
  /*else*/ {
    __pyx_v_self->jmp_targets_data->text_storage = ((char *)0);

    /* "libudis/libudis.pyx":560
 *         else:
 *             self.jmp_targets_data.text_storage = <char *>0
 *             self.jmp_targets_data.labels = <label_info_t *>0             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
    __pyx_v_self->jmp_targets_data->labels = ((struct __pyx_t_7libudis_7libudis_label_info_t *)0);
  }
  __pyx_L3:;

  /* "libudis/libudis.pyx":539
 *     cdef char *hex_case
 * 
 *     def __init__(self, max_lines, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         cdef long addr
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":562
 *             self.jmp_targets_data.labels = <label_info_t *>0
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.history_text.num_lines
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_3__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_2__len__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "libudis/libudis.pyx":563
 * 
 *     def __len__(self):
 *         return self.history_text.num_lines             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, index):
 */
  __pyx_r = __pyx_v_self->history_text->num_lines;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":562
 *             self.jmp_targets_data.labels = <label_info_t *>0
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.history_text.num_lines
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":565
 *         return self.history_text.num_lines
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         if isinstance(index, slice):
 *             lines = []
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_4__getitem__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_v_lines = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "libudis/libudis.pyx":566
 * 
 *     def __getitem__(self, index):
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  __pyx_t_1 = PySlice_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":567
 *     def __getitem__(self, index):
 *         if isinstance(index, slice):
 *             lines = []             # <<<<<<<<<<<<<<
 *             for i in range(*index.indices(len(self))):
 *                 lines.append((self.history_text[i], self.result_text[i]
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_lines = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":568
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 lines.append((self.history_text[i], self.result_text[i]
 * ))
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_indices); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_Length(((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 568, __pyx_L1_error)
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 568, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 568, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 568, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_8(__pyx_t_4);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 568, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "libudis/libudis.pyx":569
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 *                 lines.append((self.history_text[i], self.result_text[i]             # <<<<<<<<<<<<<<
 * ))
 *             return lines
 */
      __pyx_t_3 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->history_text), __pyx_v_i); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->result_text), __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_6);
      __pyx_t_3 = 0;
      __pyx_t_6 = 0;
      __pyx_t_9 = __Pyx_PyList_Append(__pyx_v_lines, __pyx_t_7); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "libudis/libudis.pyx":568
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 lines.append((self.history_text[i], self.result_text[i]
 * ))
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "libudis/libudis.pyx":571
 *                 lines.append((self.history_text[i], self.result_text[i]
 * ))
 *             return lines             # <<<<<<<<<<<<<<
 *         elif isinstance(index, int):
 *             return self.history_text[index], self.result_text[index]
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_lines);
    __pyx_r = __pyx_v_lines;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":566
 * 
 *     def __getitem__(self, index):
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  }

  /* "libudis/libudis.pyx":572
 * ))
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             return self.history_text[index], self.result_text[index]
 * 
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_index); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (likely(__pyx_t_1)) {

    /* "libudis/libudis.pyx":573
 *             return lines
 *         elif isinstance(index, int):
 *             return self.history_text[index], self.result_text[index]             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->history_text), __pyx_v_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->result_text), __pyx_v_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 573, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_7);
    __pyx_t_4 = 0;
    __pyx_t_7 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":572
 * ))
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             return self.history_text[index], self.result_text[index]
 * 
 */
  }

  /* "libudis/libudis.pyx":576
 * 
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  /*else*/ {
    __pyx_t_6 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_index)), __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 576, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyUnicode_Concat(__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 576, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 576, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(0, 576, __pyx_L1_error)
  }

  /* "libudis/libudis.pyx":565
 *         return self.history_text.num_lines
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         if isinstance(index, slice):
 *             lines = []
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lines);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_18StringifiedHistory_8generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "libudis/libudis.pyx":578
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(len(self)):
 *             yield self.history_text[i], self.result_text[i]
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7__iter__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6__iter__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *)__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__(__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 578, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8omnivore_12disassembler_7libudis_18StringifiedHistory_8generator3, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_StringifiedHistory___iter, __pyx_n_s_omnivore_disassembler_libudis); if (unlikely(!gen)) __PYX_ERR(0, 578, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_18StringifiedHistory_8generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *__pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 578, __pyx_L1_error)

  /* "libudis/libudis.pyx":579
 * 
 *     def __iter__(self):
 *         for i in range(len(self)):             # <<<<<<<<<<<<<<
 *             yield self.history_text[i], self.result_text[i]
 * 
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_cur_scope->__pyx_v_self)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(0, 579, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_cur_scope->__pyx_v_i = __pyx_t_3;

    /* "libudis/libudis.pyx":580
 *     def __iter__(self):
 *         for i in range(len(self)):
 *             yield self.history_text[i], self.result_text[i]             # <<<<<<<<<<<<<<
 * 
 *     cdef clear(self):
 */
    __pyx_t_4 = __Pyx_GetItemInt(((PyObject *)__pyx_cur_scope->__pyx_v_self->history_text), __pyx_cur_scope->__pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_GetItemInt(((PyObject *)__pyx_cur_scope->__pyx_v_self->result_text), __pyx_cur_scope->__pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_5);
    __pyx_t_4 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_2;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_3;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_t_2 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 580, __pyx_L1_error)
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "libudis/libudis.pyx":578
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(len(self)):
 *             yield self.history_text[i], self.result_text[i]
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":582
 *             yield self.history_text[i], self.result_text[i]
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.history_text.clear()
 *         self.result_text.clear()
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_18StringifiedHistory_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("clear", 0);

  /* "libudis/libudis.pyx":583
 * 
 *     cdef clear(self):
 *         self.history_text.clear()             # <<<<<<<<<<<<<<
 *         self.result_text.clear()
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->history_text->__pyx_vtab)->clear(__pyx_v_self->history_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":584
 *     cdef clear(self):
 *         self.history_text.clear()
 *         self.result_text.clear()             # <<<<<<<<<<<<<<
 * 
 *     cdef parse_history_entries(self, emulator_history_t *history, int index, int num_entries):
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->result_text->__pyx_vtab)->clear(__pyx_v_self->result_text); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":582
 *             yield self.history_text[i], self.result_text[i]
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.history_text.clear()
 *         self.result_text.clear()
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.clear", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":586
 *         self.result_text.clear()
 * 
 *     cdef parse_history_entries(self, emulator_history_t *history, int index, int num_entries):             # <<<<<<<<<<<<<<
 *         if num_entries > self.history_text.max_lines:
 *             num_entries = self.history_text.max_lines
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_18StringifiedHistory_parse_history_entries(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, struct __pyx_t_7libudis_7libudis_emulator_history_t *__pyx_v_history, int __pyx_v_index, int __pyx_v_num_entries) {
  int __pyx_v_count;
  int __pyx_v_disassembler_type;
  __pyx_t_7libudis_7libudis_string_func_t __pyx_v_stringifier;
  struct __pyx_t_7libudis_7libudis_history_entry_t *__pyx_v_h;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __pyx_t_5numpy_uint8_t __pyx_t_4;
  __Pyx_RefNannySetupContext("parse_history_entries", 0);

  /* "libudis/libudis.pyx":587
 * 
 *     cdef parse_history_entries(self, emulator_history_t *history, int index, int num_entries):
 *         if num_entries > self.history_text.max_lines:             # <<<<<<<<<<<<<<
 *             num_entries = self.history_text.max_lines
 *         cdef int count
 */
  __pyx_t_1 = ((__pyx_v_num_entries > __pyx_v_self->history_text->max_lines) != 0);
  if (__pyx_t_1) {

    /* "libudis/libudis.pyx":588
 *     cdef parse_history_entries(self, emulator_history_t *history, int index, int num_entries):
 *         if num_entries > self.history_text.max_lines:
 *             num_entries = self.history_text.max_lines             # <<<<<<<<<<<<<<
 *         cdef int count
 *         cdef int disassembler_type
 */
    __pyx_t_2 = __pyx_v_self->history_text->max_lines;
    __pyx_v_num_entries = __pyx_t_2;

    /* "libudis/libudis.pyx":587
 * 
 *     cdef parse_history_entries(self, emulator_history_t *history, int index, int num_entries):
 *         if num_entries > self.history_text.max_lines:             # <<<<<<<<<<<<<<
 *             num_entries = self.history_text.max_lines
 *         cdef int count
 */
  }

  /* "libudis/libudis.pyx":594
 *         cdef history_entry_t *h
 * 
 *         self.clear()             # <<<<<<<<<<<<<<
 *         while num_entries > 0:
 *             h = &history.entries[index]
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self->__pyx_vtab)->clear(__pyx_v_self); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "libudis/libudis.pyx":595
 * 
 *         self.clear()
 *         while num_entries > 0:             # <<<<<<<<<<<<<<
 *             h = &history.entries[index]
 *             disassembler_type = h.disassembler_type
 */
  while (1) {
    __pyx_t_1 = ((__pyx_v_num_entries > 0) != 0);
    if (!__pyx_t_1) break;

    /* "libudis/libudis.pyx":596
 *         self.clear()
 *         while num_entries > 0:
 *             h = &history.entries[index]             # <<<<<<<<<<<<<<
 *             disassembler_type = h.disassembler_type
 *             stringifier = stringifier_map[disassembler_type]
 */
    __pyx_v_h = (&(__pyx_v_history->entries[__pyx_v_index]));

    /* "libudis/libudis.pyx":597
 *         while num_entries > 0:
 *             h = &history.entries[index]
 *             disassembler_type = h.disassembler_type             # <<<<<<<<<<<<<<
 *             stringifier = stringifier_map[disassembler_type]
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 */
    __pyx_t_4 = __pyx_v_h->disassembler_type;
    __pyx_v_disassembler_type = __pyx_t_4;

    /* "libudis/libudis.pyx":598
 *             h = &history.entries[index]
 *             disassembler_type = h.disassembler_type
 *             stringifier = stringifier_map[disassembler_type]             # <<<<<<<<<<<<<<
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *             count = stringifier(h, self.history_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)
 */
    __pyx_v_stringifier = (stringifier_map[__pyx_v_disassembler_type]);

    /* "libudis/libudis.pyx":600
 *             stringifier = stringifier_map[disassembler_type]
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *             count = stringifier(h, self.history_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)             # <<<<<<<<<<<<<<
 *             self.history_text.store(count)
 * 
 */
    __pyx_v_count = __pyx_v_stringifier(__pyx_v_h, __pyx_v_self->history_text->text_ptr, __pyx_v_self->hex_case, __pyx_v_self->mnemonic_case, __pyx_v_self->jmp_targets_data);

    /* "libudis/libudis.pyx":601
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *             count = stringifier(h, self.history_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)
 *             self.history_text.store(count)             # <<<<<<<<<<<<<<
 * 
 *             if disassembler_type < 192:
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->history_text->__pyx_vtab)->store(__pyx_v_self->history_text, __pyx_v_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 601, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":603
 *             self.history_text.store(count)
 * 
 *             if disassembler_type < 192:             # <<<<<<<<<<<<<<
 *                 stringifier = stringifier_map[h.disassembler_type + 1]
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 */
    __pyx_t_1 = ((__pyx_v_disassembler_type < 0xC0) != 0);
    if (__pyx_t_1) {

      /* "libudis/libudis.pyx":604
 * 
 *             if disassembler_type < 192:
 *                 stringifier = stringifier_map[h.disassembler_type + 1]             # <<<<<<<<<<<<<<
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *                 count = stringifier(h, self.result_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)
 */
      __pyx_v_stringifier = (stringifier_map[(__pyx_v_h->disassembler_type + 1)]);

      /* "libudis/libudis.pyx":606
 *                 stringifier = stringifier_map[h.disassembler_type + 1]
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 *                 count = stringifier(h, self.result_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)             # <<<<<<<<<<<<<<
 *             else:
 *                 count = 0
 */
      __pyx_v_count = __pyx_v_stringifier(__pyx_v_h, __pyx_v_self->result_text->text_ptr, __pyx_v_self->hex_case, __pyx_v_self->mnemonic_case, __pyx_v_self->jmp_targets_data);

      /* "libudis/libudis.pyx":603
 *             self.history_text.store(count)
 * 
 *             if disassembler_type < 192:             # <<<<<<<<<<<<<<
 *                 stringifier = stringifier_map[h.disassembler_type + 1]
 *             # printf("disassembler: %d, stringifier: %lx\n", h.disassembler_type, stringifier)
 */
      goto __pyx_L6;
    }

    /* "libudis/libudis.pyx":608
 *                 count = stringifier(h, self.result_text.text_ptr, self.hex_case, self.mnemonic_case, self.jmp_targets_data)
 *             else:
 *                 count = 0             # <<<<<<<<<<<<<<
 *             self.result_text.store(count)
 * 
 */
    /*else*/ {
      __pyx_v_count = 0;
    }
    __pyx_L6:;

    /* "libudis/libudis.pyx":609
 *             else:
 *                 count = 0
 *             self.result_text.store(count)             # <<<<<<<<<<<<<<
 * 
 *             num_entries -= 1
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_v_self->result_text->__pyx_vtab)->store(__pyx_v_self->result_text, __pyx_v_count); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 609, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":611
 *             self.result_text.store(count)
 * 
 *             num_entries -= 1             # <<<<<<<<<<<<<<
 *             index += 1
 *             if index >= history.num_allocated_entries:
 */
    __pyx_v_num_entries = (__pyx_v_num_entries - 1);

    /* "libudis/libudis.pyx":612
 * 
 *             num_entries -= 1
 *             index += 1             # <<<<<<<<<<<<<<
 *             if index >= history.num_allocated_entries:
 *                 index = 0
 */
    __pyx_v_index = (__pyx_v_index + 1);

    /* "libudis/libudis.pyx":613
 *             num_entries -= 1
 *             index += 1
 *             if index >= history.num_allocated_entries:             # <<<<<<<<<<<<<<
 *                 index = 0
 * 
 */
    __pyx_t_1 = ((__pyx_v_index >= __pyx_v_history->num_allocated_entries) != 0);
    if (__pyx_t_1) {

      /* "libudis/libudis.pyx":614
 *             index += 1
 *             if index >= history.num_allocated_entries:
 *                 index = 0             # <<<<<<<<<<<<<<
 * 
 * cdef class HistoryStorage:
 */
      __pyx_v_index = 0;

      /* "libudis/libudis.pyx":613
 *             num_entries -= 1
 *             index += 1
 *             if index >= history.num_allocated_entries:             # <<<<<<<<<<<<<<
 *                 index = 0
 * 
 */
    }
  }

  /* "libudis/libudis.pyx":586
 *         self.result_text.clear()
 * 
 *     cdef parse_history_entries(self, emulator_history_t *history, int index, int num_entries):             # <<<<<<<<<<<<<<
 *         if num_entries > self.history_text.max_lines:
 *             num_entries = self.history_text.max_lines
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.parse_history_entries", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":526
 * 
 * cdef class StringifiedHistory:
 *     cdef public int origin             # <<<<<<<<<<<<<<
 *     cdef public int last_pc
 *     cdef public int start_index
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->origin); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.origin.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 526, __pyx_L1_error)
  __pyx_v_self->origin = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.origin.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":527
 * cdef class StringifiedHistory:
 *     cdef public int origin
 *     cdef public int last_pc             # <<<<<<<<<<<<<<
 *     cdef public int start_index
 *     cdef public np.ndarray jmp_targets
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->last_pc); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.last_pc.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 527, __pyx_L1_error)
  __pyx_v_self->last_pc = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.last_pc.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":528
 *     cdef public int origin
 *     cdef public int last_pc
 *     cdef public int start_index             # <<<<<<<<<<<<<<
 *     cdef public np.ndarray jmp_targets
 *     cdef jmp_targets_t *jmp_targets_data
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->start_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.start_index.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__set__", 0);
  __pyx_t_1 = __Pyx_PyInt_As_int(__pyx_v_value); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 528, __pyx_L1_error)
  __pyx_v_self->start_index = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.start_index.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":529
 *     cdef public int last_pc
 *     cdef public int start_index
 *     cdef public np.ndarray jmp_targets             # <<<<<<<<<<<<<<
 *     cdef jmp_targets_t *jmp_targets_data
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_r = ((PyObject *)__pyx_v_self->jmp_targets);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 529, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.jmp_targets.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->jmp_targets);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->jmp_targets));
  __pyx_v_self->jmp_targets = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":532
 *     cdef jmp_targets_t *jmp_targets_data
 * 
 *     cdef public TextStorage history_text             # <<<<<<<<<<<<<<
 *     cdef public TextStorage result_text
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->history_text));
  __pyx_r = ((PyObject *)__pyx_v_self->history_text);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage))))) __PYX_ERR(0, 532, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->history_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->history_text));
  __pyx_v_self->history_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.history_text.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->history_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->history_text));
  __pyx_v_self->history_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":533
 * 
 *     cdef public TextStorage history_text
 *     cdef public TextStorage result_text             # <<<<<<<<<<<<<<
 * 
 *     # internals
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->result_text));
  __pyx_r = ((PyObject *)__pyx_v_self->result_text);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage))))) __PYX_ERR(0, 533, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->result_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->result_text));
  __pyx_v_self->result_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.result_text.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->result_text);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->result_text));
  __pyx_v_self->result_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_10__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_10__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_9__reduce_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_9__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11__setstate_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_18StringifiedHistory_11__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.StringifiedHistory.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":621
 *     cdef public np.ndarray entries
 * 
 *     def __init__(self, num_entries):             # <<<<<<<<<<<<<<
 *         self.history_array = np.zeros(sizeof(emulator_history_t), dtype=np.uint8)
 *         self.history = <emulator_history_t *>self.history_array.data
 */

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_num_entries = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_num_entries,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_entries)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 621, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_num_entries = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 621, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage___init__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self), __pyx_v_num_entries);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage___init__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_num_entries) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  __pyx_t_5numpy_int32_t __pyx_t_6;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "libudis/libudis.pyx":622
 * 
 *     def __init__(self, num_entries):
 *         self.history_array = np.zeros(sizeof(emulator_history_t), dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         self.history = <emulator_history_t *>self.history_array.data
 *         # printf("libudis: __init__: history_storage: %lx\n", <int>self.history)
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_zeros); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((sizeof(struct __pyx_t_7libudis_7libudis_emulator_history_t))); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_uint8); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 622, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->history_array);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->history_array));
  __pyx_v_self->history_array = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "libudis/libudis.pyx":623
 *     def __init__(self, num_entries):
 *         self.history_array = np.zeros(sizeof(emulator_history_t), dtype=np.uint8)
 *         self.history = <emulator_history_t *>self.history_array.data             # <<<<<<<<<<<<<<
 *         # printf("libudis: __init__: history_storage: %lx\n", <int>self.history)
 *         self.history.num_allocated_entries = num_entries
 */
  __pyx_v_self->history = ((struct __pyx_t_7libudis_7libudis_emulator_history_t *)__pyx_v_self->history_array->data);

  /* "libudis/libudis.pyx":625
 *         self.history = <emulator_history_t *>self.history_array.data
 *         # printf("libudis: __init__: history_storage: %lx\n", <int>self.history)
 *         self.history.num_allocated_entries = num_entries             # <<<<<<<<<<<<<<
 *         self.entries = np.zeros(num_entries, dtype=HISTORY_ENTRY_DTYPE)
 *         self.history.entries = <history_entry_t *>self.entries.data
 */
  __pyx_t_6 = __Pyx_PyInt_As_npy_int32(__pyx_v_num_entries); if (unlikely((__pyx_t_6 == ((npy_int32)-1)) && PyErr_Occurred())) __PYX_ERR(0, 625, __pyx_L1_error)
  __pyx_v_self->history->num_allocated_entries = __pyx_t_6;

  /* "libudis/libudis.pyx":626
 *         # printf("libudis: __init__: history_storage: %lx\n", <int>self.history)
 *         self.history.num_allocated_entries = num_entries
 *         self.entries = np.zeros(num_entries, dtype=HISTORY_ENTRY_DTYPE)             # <<<<<<<<<<<<<<
 *         self.history.entries = <history_entry_t *>self.entries.data
 *         self.clear()
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_zeros); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_num_entries);
  __Pyx_GIVEREF(__pyx_v_num_entries);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_num_entries);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_HISTORY_ENTRY_DTYPE); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dtype, __pyx_t_2) < 0) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 626, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->entries));
  __pyx_v_self->entries = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":627
 *         self.history.num_allocated_entries = num_entries
 *         self.entries = np.zeros(num_entries, dtype=HISTORY_ENTRY_DTYPE)
 *         self.history.entries = <history_entry_t *>self.entries.data             # <<<<<<<<<<<<<<
 *         self.clear()
 * 
 */
  __pyx_v_self->history->entries = ((struct __pyx_t_7libudis_7libudis_history_entry_t *)__pyx_v_self->entries->data);

  /* "libudis/libudis.pyx":628
 *         self.entries = np.zeros(num_entries, dtype=HISTORY_ENTRY_DTYPE)
 *         self.history.entries = <history_entry_t *>self.entries.data
 *         self.clear()             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self->__pyx_vtab)->clear(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":621
 *     cdef public np.ndarray entries
 * 
 *     def __init__(self, num_entries):             # <<<<<<<<<<<<<<
 *         self.history_array = np.zeros(sizeof(emulator_history_t), dtype=np.uint8)
 *         self.history = <emulator_history_t *>self.history_array.data
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":630
 *         self.clear()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.history.num_entries
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_3__len__(PyObject *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_2__len__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_2__len__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__", 0);

  /* "libudis/libudis.pyx":631
 * 
 *     def __len__(self):
 *         return self.history.num_entries             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, index):
 */
  __pyx_r = __pyx_v_self->history->num_entries;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":630
 *         self.clear()
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self.history.num_entries
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":633
 *         return self.history.num_entries
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef int wrapped
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_5__getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_4__getitem__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_4__getitem__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_index) {
  int __pyx_v_wrapped;
  PyObject *__pyx_v_lines = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  int __pyx_t_10;
  __Pyx_RefNannySetupContext("__getitem__", 0);

  /* "libudis/libudis.pyx":636
 *         cdef int wrapped
 * 
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  __pyx_t_1 = PySlice_Check(__pyx_v_index); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "libudis/libudis.pyx":637
 * 
 *         if isinstance(index, slice):
 *             lines = []             # <<<<<<<<<<<<<<
 *             for i in range(*index.indices(len(self))):
 *                 wrapped = (i + self.history.first_entry_index) % self.history.num_allocated_entries
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 637, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_lines = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "libudis/libudis.pyx":638
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 wrapped = (i + self.history.first_entry_index) % self.history.num_allocated_entries
 *                 lines.append(self.entries[wrapped])
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_indices); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_Length(((PyObject *)__pyx_v_self)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 638, __pyx_L1_error)
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PySequence_Tuple(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4); __pyx_t_5 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 638, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 638, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 638, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 638, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_5); __Pyx_INCREF(__pyx_t_3); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 638, __pyx_L1_error)
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 638, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_8(__pyx_t_4);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 638, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "libudis/libudis.pyx":639
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 *                 wrapped = (i + self.history.first_entry_index) % self.history.num_allocated_entries             # <<<<<<<<<<<<<<
 *                 lines.append(self.entries[wrapped])
 *             return lines
 */
      __pyx_t_3 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->first_entry_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyNumber_Add(__pyx_v_i, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->num_allocated_entries); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_7 = PyNumber_Remainder(__pyx_t_6, __pyx_t_3); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_7); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 639, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_v_wrapped = __pyx_t_9;

      /* "libudis/libudis.pyx":640
 *             for i in range(*index.indices(len(self))):
 *                 wrapped = (i + self.history.first_entry_index) % self.history.num_allocated_entries
 *                 lines.append(self.entries[wrapped])             # <<<<<<<<<<<<<<
 *             return lines
 *         elif isinstance(index, int):
 */
      __pyx_t_7 = __Pyx_GetItemInt(((PyObject *)__pyx_v_self->entries), __pyx_v_wrapped, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10 = __Pyx_PyList_Append(__pyx_v_lines, __pyx_t_7); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(0, 640, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

      /* "libudis/libudis.pyx":638
 *         if isinstance(index, slice):
 *             lines = []
 *             for i in range(*index.indices(len(self))):             # <<<<<<<<<<<<<<
 *                 wrapped = (i + self.history.first_entry_index) % self.history.num_allocated_entries
 *                 lines.append(self.entries[wrapped])
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "libudis/libudis.pyx":641
 *                 wrapped = (i + self.history.first_entry_index) % self.history.num_allocated_entries
 *                 lines.append(self.entries[wrapped])
 *             return lines             # <<<<<<<<<<<<<<
 *         elif isinstance(index, int):
 *             wrapped = (index + self.history.first_entry_index) % self.history.num_allocated_entries
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_lines);
    __pyx_r = __pyx_v_lines;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":636
 *         cdef int wrapped
 * 
 *         if isinstance(index, slice):             # <<<<<<<<<<<<<<
 *             lines = []
 *             for i in range(*index.indices(len(self))):
 */
  }

  /* "libudis/libudis.pyx":642
 *                 lines.append(self.entries[wrapped])
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             wrapped = (index + self.history.first_entry_index) % self.history.num_allocated_entries
 *             return self.entries[wrapped]
 */
  __pyx_t_2 = PyInt_Check(__pyx_v_index); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (likely(__pyx_t_1)) {

    /* "libudis/libudis.pyx":643
 *             return lines
 *         elif isinstance(index, int):
 *             wrapped = (index + self.history.first_entry_index) % self.history.num_allocated_entries             # <<<<<<<<<<<<<<
 *             return self.entries[wrapped]
 *         else:
 */
    __pyx_t_4 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->first_entry_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = PyNumber_Add(__pyx_v_index, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->num_allocated_entries); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Remainder(__pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 643, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_wrapped = __pyx_t_9;

    /* "libudis/libudis.pyx":644
 *         elif isinstance(index, int):
 *             wrapped = (index + self.history.first_entry_index) % self.history.num_allocated_entries
 *             return self.entries[wrapped]             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = __Pyx_GetItemInt(((PyObject *)__pyx_v_self->entries), __pyx_v_wrapped, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "libudis/libudis.pyx":642
 *                 lines.append(self.entries[wrapped])
 *             return lines
 *         elif isinstance(index, int):             # <<<<<<<<<<<<<<
 *             wrapped = (index + self.history.first_entry_index) % self.history.num_allocated_entries
 *             return self.entries[wrapped]
 */
  }

  /* "libudis/libudis.pyx":646
 *             return self.entries[wrapped]
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")             # <<<<<<<<<<<<<<
 * 
 *     def __iter__(self):
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_index)), __pyx_empty_unicode); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 646, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(0, 646, __pyx_L1_error)
  }

  /* "libudis/libudis.pyx":633
 *         return self.history.num_entries
 * 
 *     def __getitem__(self, index):             # <<<<<<<<<<<<<<
 *         cdef int wrapped
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_lines);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_14HistoryStorage_8generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "libudis/libudis.pyx":648
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(self.num_lines):
 *             yield self.entries[i]
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7__iter__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7__iter__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_6__iter__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_6__iter__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  __pyx_cur_scope = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *)__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__(__pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(0, 648, __pyx_L1_error)
  } else {
    __Pyx_GOTREF(__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_self = __pyx_v_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_self);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_8omnivore_12disassembler_7libudis_14HistoryStorage_8generator4, NULL, (PyObject *) __pyx_cur_scope, __pyx_n_s_iter, __pyx_n_s_HistoryStorage___iter, __pyx_n_s_omnivore_disassembler_libudis); if (unlikely(!gen)) __PYX_ERR(0, 648, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_8omnivore_12disassembler_7libudis_14HistoryStorage_8generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *__pyx_cur_scope = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__iter__", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L6_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 648, __pyx_L1_error)

  /* "libudis/libudis.pyx":649
 * 
 *     def __iter__(self):
 *         for i in range(self.num_lines):             # <<<<<<<<<<<<<<
 *             yield self.entries[i]
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_self), __pyx_n_s_num_lines); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_range, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 649, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 649, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 649, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 649, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 649, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 649, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 649, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_i);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_i, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;

    /* "libudis/libudis.pyx":650
 *     def __iter__(self):
 *         for i in range(self.num_lines):
 *             yield self.entries[i]             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
    __pyx_t_2 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_cur_scope->__pyx_v_self->entries), __pyx_cur_scope->__pyx_v_i); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 650, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    __Pyx_XGIVEREF(__pyx_t_1);
    __pyx_cur_scope->__pyx_t_0 = __pyx_t_1;
    __pyx_cur_scope->__pyx_t_1 = __pyx_t_3;
    __pyx_cur_scope->__pyx_t_2 = __pyx_t_4;
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L6_resume_from_yield:;
    __pyx_t_1 = __pyx_cur_scope->__pyx_t_0;
    __pyx_cur_scope->__pyx_t_0 = 0;
    __Pyx_XGOTREF(__pyx_t_1);
    __pyx_t_3 = __pyx_cur_scope->__pyx_t_1;
    __pyx_t_4 = __pyx_cur_scope->__pyx_t_2;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(0, 650, __pyx_L1_error)

    /* "libudis/libudis.pyx":649
 * 
 *     def __iter__(self):
 *         for i in range(self.num_lines):             # <<<<<<<<<<<<<<
 *             yield self.entries[i]
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "libudis/libudis.pyx":648
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 * 
 *     def __iter__(self):             # <<<<<<<<<<<<<<
 *         for i in range(self.num_lines):
 *             yield self.entries[i]
 */

  /* function exit code */
  PyErr_SetNone(PyExc_StopIteration);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("__iter__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_r); __pyx_r = 0;
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":653
 * 
 *     @property
 *     def first_entry_index(self):             # <<<<<<<<<<<<<<
 *         return self.history.first_entry_index
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_17first_entry_index_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_17first_entry_index_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_17first_entry_index___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_17first_entry_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "libudis/libudis.pyx":654
 *     @property
 *     def first_entry_index(self):
 *         return self.history.first_entry_index             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->first_entry_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":653
 * 
 *     @property
 *     def first_entry_index(self):             # <<<<<<<<<<<<<<
 *         return self.history.first_entry_index
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.first_entry_index.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":657
 * 
 *     @property
 *     def latest_entry_index(self):             # <<<<<<<<<<<<<<
 *         return self.history.latest_entry_index
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_18latest_entry_index_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_18latest_entry_index_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_18latest_entry_index___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_18latest_entry_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "libudis/libudis.pyx":658
 *     @property
 *     def latest_entry_index(self):
 *         return self.history.latest_entry_index             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->latest_entry_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":657
 * 
 *     @property
 *     def latest_entry_index(self):             # <<<<<<<<<<<<<<
 *         return self.history.latest_entry_index
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.latest_entry_index.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":661
 * 
 *     @property
 *     def next_entry_index(self):             # <<<<<<<<<<<<<<
 *         cdef np.int32_t last = self.history.latest_entry_index
 *         cdef np.int32_t mod = self.history.num_allocated_entries
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16next_entry_index_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16next_entry_index_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_16next_entry_index___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_16next_entry_index___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  __pyx_t_5numpy_int32_t __pyx_v_last;
  __pyx_t_5numpy_int32_t __pyx_v_mod;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_int32_t __pyx_t_1;
  long __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "libudis/libudis.pyx":662
 *     @property
 *     def next_entry_index(self):
 *         cdef np.int32_t last = self.history.latest_entry_index             # <<<<<<<<<<<<<<
 *         cdef np.int32_t mod = self.history.num_allocated_entries
 *         return ((last + 1) % mod)
 */
  __pyx_t_1 = __pyx_v_self->history->latest_entry_index;
  __pyx_v_last = __pyx_t_1;

  /* "libudis/libudis.pyx":663
 *     def next_entry_index(self):
 *         cdef np.int32_t last = self.history.latest_entry_index
 *         cdef np.int32_t mod = self.history.num_allocated_entries             # <<<<<<<<<<<<<<
 *         return ((last + 1) % mod)
 * 
 */
  __pyx_t_1 = __pyx_v_self->history->num_allocated_entries;
  __pyx_v_mod = __pyx_t_1;

  /* "libudis/libudis.pyx":664
 *         cdef np.int32_t last = self.history.latest_entry_index
 *         cdef np.int32_t mod = self.history.num_allocated_entries
 *         return ((last + 1) % mod)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = (__pyx_v_last + 1);
  if (unlikely(__pyx_v_mod == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 664, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyInt_From_long(__Pyx_mod_long(__pyx_t_2, __pyx_v_mod)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":661
 * 
 *     @property
 *     def next_entry_index(self):             # <<<<<<<<<<<<<<
 *         cdef np.int32_t last = self.history.latest_entry_index
 *         cdef np.int32_t mod = self.history.num_allocated_entries
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.next_entry_index.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":667
 * 
 *     @property
 *     def cumulative_count(self):             # <<<<<<<<<<<<<<
 *         return self.history.cumulative_count
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16cumulative_count_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16cumulative_count_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_16cumulative_count___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_16cumulative_count___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "libudis/libudis.pyx":668
 *     @property
 *     def cumulative_count(self):
 *         return self.history.cumulative_count             # <<<<<<<<<<<<<<
 * 
 *     cdef clear(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->history->cumulative_count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "libudis/libudis.pyx":667
 * 
 *     @property
 *     def cumulative_count(self):             # <<<<<<<<<<<<<<
 *         return self.history.cumulative_count
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.cumulative_count.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":670
 *         return self.history.cumulative_count
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.history.first_entry_index = 0
 *         self.history.latest_entry_index = -1
 */

static PyObject *__pyx_f_8omnivore_12disassembler_7libudis_14HistoryStorage_clear(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("clear", 0);

  /* "libudis/libudis.pyx":671
 * 
 *     cdef clear(self):
 *         self.history.first_entry_index = 0             # <<<<<<<<<<<<<<
 *         self.history.latest_entry_index = -1
 *         self.history.num_entries = 0
 */
  __pyx_v_self->history->first_entry_index = 0;

  /* "libudis/libudis.pyx":672
 *     cdef clear(self):
 *         self.history.first_entry_index = 0
 *         self.history.latest_entry_index = -1             # <<<<<<<<<<<<<<
 *         self.history.num_entries = 0
 *         self.history.cumulative_count = 0
 */
  __pyx_v_self->history->latest_entry_index = -1;

  /* "libudis/libudis.pyx":673
 *         self.history.first_entry_index = 0
 *         self.history.latest_entry_index = -1
 *         self.history.num_entries = 0             # <<<<<<<<<<<<<<
 *         self.history.cumulative_count = 0
 * 
 */
  __pyx_v_self->history->num_entries = 0;

  /* "libudis/libudis.pyx":674
 *         self.history.latest_entry_index = -1
 *         self.history.num_entries = 0
 *         self.history.cumulative_count = 0             # <<<<<<<<<<<<<<
 * 
 *     def summary(self):
 */
  __pyx_v_self->history->cumulative_count = 0;

  /* "libudis/libudis.pyx":670
 *         return self.history.cumulative_count
 * 
 *     cdef clear(self):             # <<<<<<<<<<<<<<
 *         self.history.first_entry_index = 0
 *         self.history.latest_entry_index = -1
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":676
 *         self.history.cumulative_count = 0
 * 
 *     def summary(self):             # <<<<<<<<<<<<<<
 *         start = self.history.first_entry_index
 *         last = self.history.latest_entry_index
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_10summary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_10summary(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("summary (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_9summary(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_9summary(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  __pyx_t_5numpy_int32_t __pyx_v_start;
  __pyx_t_5numpy_int32_t __pyx_v_last;
  __pyx_t_5numpy_int32_t __pyx_v_mod;
  __pyx_t_5numpy_int32_t __pyx_v_num;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_int32_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("summary", 0);

  /* "libudis/libudis.pyx":677
 * 
 *     def summary(self):
 *         start = self.history.first_entry_index             # <<<<<<<<<<<<<<
 *         last = self.history.latest_entry_index
 *         mod = self.history.num_allocated_entries
 */
  __pyx_t_1 = __pyx_v_self->history->first_entry_index;
  __pyx_v_start = __pyx_t_1;

  /* "libudis/libudis.pyx":678
 *     def summary(self):
 *         start = self.history.first_entry_index
 *         last = self.history.latest_entry_index             # <<<<<<<<<<<<<<
 *         mod = self.history.num_allocated_entries
 *         num = self.history.num_entries
 */
  __pyx_t_1 = __pyx_v_self->history->latest_entry_index;
  __pyx_v_last = __pyx_t_1;

  /* "libudis/libudis.pyx":679
 *         start = self.history.first_entry_index
 *         last = self.history.latest_entry_index
 *         mod = self.history.num_allocated_entries             # <<<<<<<<<<<<<<
 *         num = self.history.num_entries
 *         print(f"number of entries: {mod}, used: {num}, cumulative {self.history.cumulative_count}")
 */
  __pyx_t_1 = __pyx_v_self->history->num_allocated_entries;
  __pyx_v_mod = __pyx_t_1;

  /* "libudis/libudis.pyx":680
 *         last = self.history.latest_entry_index
 *         mod = self.history.num_allocated_entries
 *         num = self.history.num_entries             # <<<<<<<<<<<<<<
 *         print(f"number of entries: {mod}, used: {num}, cumulative {self.history.cumulative_count}")
 *         print(f"start of ring: {start}, latest: {last}")
 */
  __pyx_t_1 = __pyx_v_self->history->num_entries;
  __pyx_v_num = __pyx_t_1;

  /* "libudis/libudis.pyx":681
 *         mod = self.history.num_allocated_entries
 *         num = self.history.num_entries
 *         print(f"number of entries: {mod}, used: {num}, cumulative {self.history.cumulative_count}")             # <<<<<<<<<<<<<<
 *         print(f"start of ring: {start}, latest: {last}")
 *         print("summary:", self)
 */
  __pyx_t_2 = PyTuple_New(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_number_of_entries);
  __pyx_t_3 += 19;
  __Pyx_GIVEREF(__pyx_kp_u_number_of_entries);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_number_of_entries);
  __pyx_t_5 = __Pyx_PyInt_From_npy_int32(__pyx_v_mod); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_6);
  __pyx_t_6 = 0;
  __Pyx_INCREF(__pyx_kp_u_used);
  __pyx_t_3 += 8;
  __Pyx_GIVEREF(__pyx_kp_u_used);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_used);
  __pyx_t_6 = __Pyx_PyInt_From_npy_int32(__pyx_v_num); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_cumulative);
  __pyx_t_3 += 13;
  __Pyx_GIVEREF(__pyx_kp_u_cumulative);
  PyTuple_SET_ITEM(__pyx_t_2, 4, __pyx_kp_u_cumulative);
  __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->history->cumulative_count); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_2, 5, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_2, 6, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":682
 *         num = self.history.num_entries
 *         print(f"number of entries: {mod}, used: {num}, cumulative {self.history.cumulative_count}")
 *         print(f"start of ring: {start}, latest: {last}")             # <<<<<<<<<<<<<<
 *         print("summary:", self)
 *         printf("libudis: history_storage: %lx\n", <long int>self.history)
 */
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __Pyx_INCREF(__pyx_kp_u_start_of_ring);
  __pyx_t_3 += 15;
  __Pyx_GIVEREF(__pyx_kp_u_start_of_ring);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_start_of_ring);
  __pyx_t_6 = __Pyx_PyInt_From_npy_int32(__pyx_v_start); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_latest);
  __pyx_t_3 += 10;
  __Pyx_GIVEREF(__pyx_kp_u_latest);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_kp_u_latest);
  __pyx_t_5 = __Pyx_PyInt_From_npy_int32(__pyx_v_last); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_2, 4, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":683
 *         print(f"number of entries: {mod}, used: {num}, cumulative {self.history.cumulative_count}")
 *         print(f"start of ring: {start}, latest: {last}")
 *         print("summary:", self)             # <<<<<<<<<<<<<<
 *         printf("libudis: history_storage: %lx\n", <long int>self.history)
 * 
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_kp_u_summary);
  __Pyx_GIVEREF(__pyx_kp_u_summary);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_kp_u_summary);
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self));
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_t_2, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "libudis/libudis.pyx":684
 *         print(f"start of ring: {start}, latest: {last}")
 *         print("summary:", self)
 *         printf("libudis: history_storage: %lx\n", <long int>self.history)             # <<<<<<<<<<<<<<
 * 
 *     def debug_range(self, from_index):
 */
  (void)(printf(((char const *)"libudis: history_storage: %lx\n"), ((long)__pyx_v_self->history)));

  /* "libudis/libudis.pyx":676
 *         self.history.cumulative_count = 0
 * 
 *     def summary(self):             # <<<<<<<<<<<<<<
 *         start = self.history.first_entry_index
 *         last = self.history.latest_entry_index
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.summary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":686
 *         printf("libudis: history_storage: %lx\n", <long int>self.history)
 * 
 *     def debug_range(self, from_index):             # <<<<<<<<<<<<<<
 *         last = self.history.latest_entry_index
 *         mod = self.history.num_allocated_entries
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_12debug_range(PyObject *__pyx_v_self, PyObject *__pyx_v_from_index); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_12debug_range(PyObject *__pyx_v_self, PyObject *__pyx_v_from_index) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("debug_range (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_11debug_range(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self), ((PyObject *)__pyx_v_from_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_11debug_range(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_from_index) {
  PyObject *__pyx_v_last = NULL;
  PyObject *__pyx_v_mod = NULL;
  CYTHON_UNUSED __pyx_t_5numpy_int32_t __pyx_v_num;
  PyObject *__pyx_v_i = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __pyx_t_5numpy_int32_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_RefNannySetupContext("debug_range", 0);

  /* "libudis/libudis.pyx":687
 * 
 *     def debug_range(self, from_index):
 *         last = self.history.latest_entry_index             # <<<<<<<<<<<<<<
 *         mod = self.history.num_allocated_entries
 *         num = self.history.num_entries
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->latest_entry_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_last = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":688
 *     def debug_range(self, from_index):
 *         last = self.history.latest_entry_index
 *         mod = self.history.num_allocated_entries             # <<<<<<<<<<<<<<
 *         num = self.history.num_entries
 *         print(f"{mod} entries; {from_index} -> {last % mod}")
 */
  __pyx_t_1 = __Pyx_PyInt_From_npy_int32(__pyx_v_self->history->num_allocated_entries); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_mod = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":689
 *         last = self.history.latest_entry_index
 *         mod = self.history.num_allocated_entries
 *         num = self.history.num_entries             # <<<<<<<<<<<<<<
 *         print(f"{mod} entries; {from_index} -> {last % mod}")
 *         cdef i = from_index % mod
 */
  __pyx_t_2 = __pyx_v_self->history->num_entries;
  __pyx_v_num = __pyx_t_2;

  /* "libudis/libudis.pyx":690
 *         mod = self.history.num_allocated_entries
 *         num = self.history.num_entries
 *         print(f"{mod} entries; {from_index} -> {last % mod}")             # <<<<<<<<<<<<<<
 *         cdef i = from_index % mod
 *         print(f"{i}: {self.entries[i]}")
 */
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_mod, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u_entries);
  __pyx_t_3 += 10;
  __Pyx_GIVEREF(__pyx_kp_u_entries);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u_entries);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_from_index, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__18);
  __pyx_t_3 += 4;
  __Pyx_GIVEREF(__pyx_kp_u__18);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u__18);
  __pyx_t_5 = PyNumber_Remainder(__pyx_v_last, __pyx_v_mod); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_1, 5, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 690, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":691
 *         num = self.history.num_entries
 *         print(f"{mod} entries; {from_index} -> {last % mod}")
 *         cdef i = from_index % mod             # <<<<<<<<<<<<<<
 *         print(f"{i}: {self.entries[i]}")
 *         i = (from_index+1) % mod
 */
  __pyx_t_1 = PyNumber_Remainder(__pyx_v_from_index, __pyx_v_mod); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 691, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_i = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":692
 *         print(f"{mod} entries; {from_index} -> {last % mod}")
 *         cdef i = from_index % mod
 *         print(f"{i}: {self.entries[i]}")             # <<<<<<<<<<<<<<
 *         i = (from_index+1) % mod
 *         print(f"{i}: {self.entries[i]}")
 */
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_v_i, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_6);
  __pyx_t_6 = 0;
  __Pyx_INCREF(__pyx_kp_u__19);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__19);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u__19);
  __pyx_t_6 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->entries), __pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_1, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":693
 *         cdef i = from_index % mod
 *         print(f"{i}: {self.entries[i]}")
 *         i = (from_index+1) % mod             # <<<<<<<<<<<<<<
 *         print(f"{i}: {self.entries[i]}")
 *         print("  ...")
 */
  __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_v_from_index, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyNumber_Remainder(__pyx_t_1, __pyx_v_mod); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_5);
  __pyx_t_5 = 0;

  /* "libudis/libudis.pyx":694
 *         print(f"{i}: {self.entries[i]}")
 *         i = (from_index+1) % mod
 *         print(f"{i}: {self.entries[i]}")             # <<<<<<<<<<<<<<
 *         print("  ...")
 *         i = (last - 1) % mod
 */
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_v_i, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_INCREF(__pyx_kp_u__19);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__19);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_kp_u__19);
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->entries), __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_6);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_5, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "libudis/libudis.pyx":695
 *         i = (from_index+1) % mod
 *         print(f"{i}: {self.entries[i]}")
 *         print("  ...")             # <<<<<<<<<<<<<<
 *         i = (last - 1) % mod
 *         print(f"{i}: {self.entries[i]}")
 */
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_builtin_print, __pyx_tuple__21, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "libudis/libudis.pyx":696
 *         print(f"{i}: {self.entries[i]}")
 *         print("  ...")
 *         i = (last - 1) % mod             # <<<<<<<<<<<<<<
 *         print(f"{i}: {self.entries[i]}")
 *         i = last % mod
 */
  __pyx_t_5 = __Pyx_PyInt_SubtractObjC(__pyx_v_last, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyNumber_Remainder(__pyx_t_5, __pyx_v_mod); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 696, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "libudis/libudis.pyx":697
 *         print("  ...")
 *         i = (last - 1) % mod
 *         print(f"{i}: {self.entries[i]}")             # <<<<<<<<<<<<<<
 *         i = last % mod
 *         print(f"{i}: {self.entries[i]}")
 */
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_v_i, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __Pyx_INCREF(__pyx_kp_u__19);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__19);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_kp_u__19);
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->entries), __pyx_v_i); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyUnicode_Join(__pyx_t_6, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 697, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "libudis/libudis.pyx":698
 *         i = (last - 1) % mod
 *         print(f"{i}: {self.entries[i]}")
 *         i = last % mod             # <<<<<<<<<<<<<<
 *         print(f"{i}: {self.entries[i]}")
 * 
 */
  __pyx_t_6 = PyNumber_Remainder(__pyx_v_last, __pyx_v_mod); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF_SET(__pyx_v_i, __pyx_t_6);
  __pyx_t_6 = 0;

  /* "libudis/libudis.pyx":699
 *         print(f"{i}: {self.entries[i]}")
 *         i = last % mod
 *         print(f"{i}: {self.entries[i]}")             # <<<<<<<<<<<<<<
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):
 */
  __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_3 = 0;
  __pyx_t_4 = 127;
  __pyx_t_1 = __Pyx_PyObject_FormatSimple(__pyx_v_i, __pyx_empty_unicode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_1) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __Pyx_INCREF(__pyx_kp_u__19);
  __pyx_t_3 += 2;
  __Pyx_GIVEREF(__pyx_kp_u__19);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_kp_u__19);
  __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self->entries), __pyx_v_i); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_1, __pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) > __pyx_t_4) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_5) : __pyx_t_4;
  __pyx_t_3 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_6, 3, __pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_print, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "libudis/libudis.pyx":686
 *         printf("libudis: history_storage: %lx\n", <long int>self.history)
 * 
 *     def debug_range(self, from_index):             # <<<<<<<<<<<<<<
 *         last = self.history.latest_entry_index
 *         mod = self.history.num_allocated_entries
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.debug_range", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_last);
  __Pyx_XDECREF(__pyx_v_mod);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":701
 *         print(f"{i}: {self.entries[i]}")
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         output = StringifiedHistory(num_lines_requested, labels, mnemonic_lower, hex_lower)
 *         index = (self.history.first_entry_index + index) % self.history.num_allocated_entries
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_14stringify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_14stringify(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_v_index;
  int __pyx_v_num_lines_requested;
  PyObject *__pyx_v_labels = 0;
  PyObject *__pyx_v_mnemonic_lower = 0;
  PyObject *__pyx_v_hex_lower = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("stringify (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_index,&__pyx_n_s_num_lines_requested,&__pyx_n_s_labels,&__pyx_n_s_mnemonic_lower,&__pyx_n_s_hex_lower,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)Py_None);
    values[3] = ((PyObject *)Py_True);
    values[4] = ((PyObject *)Py_True);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_index)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_num_lines_requested)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("stringify", 0, 2, 5, 1); __PYX_ERR(0, 701, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_labels);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_mnemonic_lower);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_hex_lower);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "stringify") < 0)) __PYX_ERR(0, 701, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_index = __Pyx_PyInt_As_int(values[0]); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 701, __pyx_L3_error)
    __pyx_v_num_lines_requested = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_num_lines_requested == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 701, __pyx_L3_error)
    __pyx_v_labels = values[2];
    __pyx_v_mnemonic_lower = values[3];
    __pyx_v_hex_lower = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("stringify", 0, 2, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 701, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.stringify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13stringify(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self), __pyx_v_index, __pyx_v_num_lines_requested, __pyx_v_labels, __pyx_v_mnemonic_lower, __pyx_v_hex_lower);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13stringify(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, int __pyx_v_index, int __pyx_v_num_lines_requested, PyObject *__pyx_v_labels, PyObject *__pyx_v_mnemonic_lower, PyObject *__pyx_v_hex_lower) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *__pyx_v_output = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __pyx_t_5numpy_int32_t __pyx_t_3;
  __Pyx_RefNannySetupContext("stringify", 0);

  /* "libudis/libudis.pyx":702
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):
 *         output = StringifiedHistory(num_lines_requested, labels, mnemonic_lower, hex_lower)             # <<<<<<<<<<<<<<
 *         index = (self.history.first_entry_index + index) % self.history.num_allocated_entries
 *         output.parse_history_entries(self.history, index, num_lines_requested)
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_num_lines_requested); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_labels);
  __Pyx_GIVEREF(__pyx_v_labels);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_labels);
  __Pyx_INCREF(__pyx_v_mnemonic_lower);
  __Pyx_GIVEREF(__pyx_v_mnemonic_lower);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_mnemonic_lower);
  __Pyx_INCREF(__pyx_v_hex_lower);
  __Pyx_GIVEREF(__pyx_v_hex_lower);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_hex_lower);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_8omnivore_12disassembler_7libudis_StringifiedHistory), __pyx_t_2, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 702, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_output = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":703
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):
 *         output = StringifiedHistory(num_lines_requested, labels, mnemonic_lower, hex_lower)
 *         index = (self.history.first_entry_index + index) % self.history.num_allocated_entries             # <<<<<<<<<<<<<<
 *         output.parse_history_entries(self.history, index, num_lines_requested)
 *         return output
 */
  __pyx_t_3 = (__pyx_v_self->history->first_entry_index + __pyx_v_index);
  if (unlikely(__pyx_v_self->history->num_allocated_entries == 0)) {
    PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
    __PYX_ERR(0, 703, __pyx_L1_error)
  }
  __pyx_v_index = __Pyx_mod___pyx_t_5numpy_int32_t(__pyx_t_3, __pyx_v_self->history->num_allocated_entries);

  /* "libudis/libudis.pyx":704
 *         output = StringifiedHistory(num_lines_requested, labels, mnemonic_lower, hex_lower)
 *         index = (self.history.first_entry_index + index) % self.history.num_allocated_entries
 *         output.parse_history_entries(self.history, index, num_lines_requested)             # <<<<<<<<<<<<<<
 *         return output
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedHistory *)__pyx_v_output->__pyx_vtab)->parse_history_entries(__pyx_v_output, __pyx_v_self->history, __pyx_v_index, __pyx_v_num_lines_requested); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":705
 *         index = (self.history.first_entry_index + index) % self.history.num_allocated_entries
 *         output.parse_history_entries(self.history, index, num_lines_requested)
 *         return output             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_output));
  __pyx_r = ((PyObject *)__pyx_v_output);
  goto __pyx_L0;

  /* "libudis/libudis.pyx":701
 *         print(f"{i}: {self.entries[i]}")
 * 
 *     def stringify(self, int index, int num_lines_requested, labels=None, mnemonic_lower=True, hex_lower=True):             # <<<<<<<<<<<<<<
 *         output = StringifiedHistory(num_lines_requested, labels, mnemonic_lower, hex_lower)
 *         index = (self.history.first_entry_index + index) % self.history.num_allocated_entries
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.stringify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_output);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":617
 * 
 * cdef class HistoryStorage:
 *     cdef public np.ndarray history_array             # <<<<<<<<<<<<<<
 *     cdef emulator_history_t *history
 *     cdef public np.ndarray entries
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->history_array));
  __pyx_r = ((PyObject *)__pyx_v_self->history_array);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 617, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->history_array);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->history_array));
  __pyx_v_self->history_array = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.history_array.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->history_array);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->history_array));
  __pyx_v_self->history_array = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "libudis/libudis.pyx":619
 *     cdef public np.ndarray history_array
 *     cdef emulator_history_t *history
 *     cdef public np.ndarray entries             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, num_entries):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries___get__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries___get__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->entries));
  __pyx_r = ((PyObject *)__pyx_v_self->entries);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_2__set__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_2__set__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__set__", 0);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 619, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->entries));
  __pyx_v_self->entries = ((PyArrayObject *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.entries.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_5__del__(PyObject *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_4__del__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_4__del__(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 0);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->entries);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->entries));
  __pyx_v_self->entries = ((PyArrayObject *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_15__reduce_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_15__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__22, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 */

/* Python wrapper */
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_18__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_18__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_r = __pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_17__setstate_cython__(((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_8omnivore_12disassembler_7libudis_14HistoryStorage_17__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__23, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("omnivore.disassembler.libudis.HistoryStorage.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":258
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5numpy_7ndarray___getbuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_i;
  int __pyx_v_ndim;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  int __pyx_v_t;
  char *__pyx_v_f;
  PyArray_Descr *__pyx_v_descr = 0;
  int __pyx_v_offset;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyArray_Descr *__pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  if (__pyx_v_info == NULL) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":265
 * 
 *             cdef int i, ndim
 *             cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 */
  __pyx_v_endian_detector = 1;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":266
 *             cdef int i, ndim
 *             cdef int endian_detector = 1
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 * 
 *             ndim = PyArray_NDIM(self)
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":268
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 *             ndim = PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 */
  __pyx_v_ndim = PyArray_NDIM(__pyx_v_self);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":270
 *             ndim = PyArray_NDIM(self)
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_C_CONTIGUOUS) == PyBUF_C_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":271
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_C_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_ARRAY_C_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":270
 *             ndim = PyArray_NDIM(self)
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  if (unlikely(__pyx_t_1)) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":272
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__24, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 272, __pyx_L1_error)

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":270
 *             ndim = PyArray_NDIM(self)
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_F_CONTIGUOUS) == PyBUF_F_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":275
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_F_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_ARRAY_F_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L7_bool_binop_done:;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  if (unlikely(__pyx_t_1)) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":276
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__25, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(2, 276, __pyx_L1_error)

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":278
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 *             info.buf = PyArray_DATA(self)             # <<<<<<<<<<<<<<
 *             info.ndim = ndim
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_v_info->buf = PyArray_DATA(__pyx_v_self);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":279
 * 
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 # Allocate new buffer for strides and shape info.
 */
  __pyx_v_info->ndim = __pyx_v_ndim;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":280
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":283
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>PyObject_Malloc(sizeof(Py_ssize_t) * 2 * <size_t>ndim)             # <<<<<<<<<<<<<<
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 */
    __pyx_v_info->strides = ((Py_ssize_t *)PyObject_Malloc((((sizeof(Py_ssize_t)) * 2) * ((size_t)__pyx_v_ndim))));

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":284
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>PyObject_Malloc(sizeof(Py_ssize_t) * 2 * <size_t>ndim)
 *                 info.shape = info.strides + ndim             # <<<<<<<<<<<<<<
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 */
    __pyx_v_info->shape = (__pyx_v_info->strides + __pyx_v_ndim);

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":285
 *                 info.strides = <Py_ssize_t*>PyObject_Malloc(sizeof(Py_ssize_t) * 2 * <size_t>ndim)
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):             # <<<<<<<<<<<<<<
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 */
    __pyx_t_4 = __pyx_v_ndim;
    __pyx_t_5 = __pyx_t_4;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":286
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]             # <<<<<<<<<<<<<<
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 */
      (__pyx_v_info->strides[__pyx_v_i]) = (PyArray_STRIDES(__pyx_v_self)[__pyx_v_i]);

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":287
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 */
      (__pyx_v_info->shape[__pyx_v_i]) = (PyArray_DIMS(__pyx_v_self)[__pyx_v_i]);
    }

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":280
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
    goto __pyx_L9;
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":289
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 */
  /*else*/ {
    __pyx_v_info->strides = ((Py_ssize_t *)PyArray_STRIDES(__pyx_v_self));

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":290
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 */
    __pyx_v_info->shape = ((Py_ssize_t *)PyArray_DIMS(__pyx_v_self));
  }
  __pyx_L9:;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":291
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 */
  __pyx_v_info->suboffsets = NULL;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":292
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)             # <<<<<<<<<<<<<<
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 * 
 */
  __pyx_v_info->itemsize = PyArray_ITEMSIZE(__pyx_v_self);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":293
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)             # <<<<<<<<<<<<<<
 * 
 *             cdef int t
 */
  __pyx_v_info->readonly = (!(PyArray_ISWRITEABLE(__pyx_v_self) != 0));

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":296
 * 
 *             cdef int t
 *             cdef char* f = NULL             # <<<<<<<<<<<<<<
 *             cdef dtype descr = <dtype>PyArray_DESCR(self)
 *             cdef int offset
 */
  __pyx_v_f = NULL;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":297
 *             cdef int t
 *             cdef char* f = NULL
 *             cdef dtype descr = <dtype>PyArray_DESCR(self)             # <<<<<<<<<<<<<<
 *             cdef int offset
 * 
 */
  __pyx_t_7 = PyArray_DESCR(__pyx_v_self);
  __pyx_t_3 = ((PyObject *)__pyx_t_7);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_descr = ((PyArray_Descr *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":300
 *             cdef int offset
 * 
 *             info.obj = self             # <<<<<<<<<<<<<<
 * 
 *             if not PyDataType_HASFIELDS(descr):
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":302
 *             info.obj = self
 * 
 *             if not PyDataType_HASFIELDS(descr):             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  __pyx_t_1 = ((!(PyDataType_HASFIELDS(__pyx_v_descr) != 0)) != 0);
  if (__pyx_t_1) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":303
 * 
 *             if not PyDataType_HASFIELDS(descr):
 *                 t = descr.type_num             # <<<<<<<<<<<<<<
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 */
    __pyx_t_4 = __pyx_v_descr->type_num;
    __pyx_v_t = __pyx_t_4;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":304
 *             if not PyDataType_HASFIELDS(descr):
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '>') != 0);
    if (!__pyx_t_2) {
      goto __pyx_L15_next_or;
    } else {
    }
    __pyx_t_2 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_L15_next_or:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":305
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '<') != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_2 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L14_bool_binop_done:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":304
 *             if not PyDataType_HASFIELDS(descr):
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    if (unlikely(__pyx_t_1)) {

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":306
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 306, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 306, __pyx_L1_error)

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":304
 *             if not PyDataType_HASFIELDS(descr):
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":307
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 */
    switch (__pyx_v_t) {
      case NPY_BYTE:
      __pyx_v_f = ((char *)"b");
      break;
      case NPY_UBYTE:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":308
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 */
      __pyx_v_f = ((char *)"B");
      break;
      case NPY_SHORT:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":309
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 */
      __pyx_v_f = ((char *)"h");
      break;
      case NPY_USHORT:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":310
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 */
      __pyx_v_f = ((char *)"H");
      break;
      case NPY_INT:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":311
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 */
      __pyx_v_f = ((char *)"i");
      break;
      case NPY_UINT:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":312
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 */
      __pyx_v_f = ((char *)"I");
      break;
      case NPY_LONG:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":313
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 */
      __pyx_v_f = ((char *)"l");
      break;
      case NPY_ULONG:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":314
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 */
      __pyx_v_f = ((char *)"L");
      break;
      case NPY_LONGLONG:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":315
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 */
      __pyx_v_f = ((char *)"q");
      break;
      case NPY_ULONGLONG:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":316
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 */
      __pyx_v_f = ((char *)"Q");
      break;
      case NPY_FLOAT:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":317
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 */
      __pyx_v_f = ((char *)"f");
      break;
      case NPY_DOUBLE:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":318
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 */
      __pyx_v_f = ((char *)"d");
      break;
      case NPY_LONGDOUBLE:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":319
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 */
      __pyx_v_f = ((char *)"g");
      break;
      case NPY_CFLOAT:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":320
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 */
      __pyx_v_f = ((char *)"Zf");
      break;
      case NPY_CDOUBLE:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":321
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"
 */
      __pyx_v_f = ((char *)"Zd");
      break;
      case NPY_CLONGDOUBLE:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":322
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 */
      __pyx_v_f = ((char *)"Zg");
      break;
      case NPY_OBJECT:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":323
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_v_f = ((char *)"O");
      break;
      default:

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":325
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *                 info.format = f
 *                 return
 */
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 325, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_8 = PyUnicode_Format(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 325, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_8); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 325, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 325, __pyx_L1_error)
      break;
    }

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":326
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
    __pyx_v_info->format = __pyx_v_f;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":327
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":302
 *             info.obj = self
 * 
 *             if not PyDataType_HASFIELDS(descr):             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":329
 *                 return
 *             else:
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)             # <<<<<<<<<<<<<<
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 */
  /*else*/ {
    __pyx_v_info->format = ((char *)PyObject_Malloc(0xFF));

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":330
 *             else:
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment             # <<<<<<<<<<<<<<
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,
 */
    (__pyx_v_info->format[0]) = '^';

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":331
 *                 info.format = <char*>PyObject_Malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0             # <<<<<<<<<<<<<<
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 */
    __pyx_v_offset = 0;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":332
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,             # <<<<<<<<<<<<<<
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 */
    __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_descr, (__pyx_v_info->format + 1), (__pyx_v_info->format + 0xFF), (&__pyx_v_offset)); if (unlikely(__pyx_t_9 == ((char *)NULL))) __PYX_ERR(2, 332, __pyx_L1_error)
    __pyx_v_f = __pyx_t_9;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":335
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 *                 f[0] = c'\0' # Terminate format string             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 */
    (__pyx_v_f[0]) = '\x00';
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":258
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fulfill the PEP.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.ndarray.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_descr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":337
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 */

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_5numpy_7ndarray_2__releasebuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":338
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_t_1 = (PyArray_HASFIELDS(__pyx_v_self) != 0);
  if (__pyx_t_1) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":339
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 PyObject_Free(info.strides)
 */
    PyObject_Free(__pyx_v_info->format);

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":338
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":340
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":341
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 PyObject_Free(info.strides)             # <<<<<<<<<<<<<<
 *                 # info.shape was stored after info.strides in the same block
 * 
 */
    PyObject_Free(__pyx_v_info->strides);

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":340
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 PyObject_Free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":337
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 PyObject_Free(info.format)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":821
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":822
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 822, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":821
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":824
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":825
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":824
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":827
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":828
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 828, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":827
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":830
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":831
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":830
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":833
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":834
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":833
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":836
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":837
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = (PyDataType_HASSUBARRAY(__pyx_v_d) != 0);
  if (__pyx_t_1) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":838
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":837
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":840
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":836
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":842
 *         return ()
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *__pyx_v_descr, char *__pyx_v_f, char *__pyx_v_end, int *__pyx_v_offset) {
  PyArray_Descr *__pyx_v_child = 0;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_childname = NULL;
  PyObject *__pyx_v_new_offset = NULL;
  PyObject *__pyx_v_t = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  long __pyx_t_8;
  char *__pyx_t_9;
  __Pyx_RefNannySetupContext("_util_dtypestring", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":847
 * 
 *     cdef dtype child
 *     cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 *     cdef tuple fields
 */
  __pyx_v_endian_detector = 1;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":848
 *     cdef dtype child
 *     cdef int endian_detector = 1
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 *     cdef tuple fields
 * 
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":851
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  if (unlikely(__pyx_v_descr->names == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(2, 851, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_descr->names; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(2, 851, __pyx_L1_error)
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 851, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_childname, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":852
 * 
 *     for childname in descr.names:
 *         fields = descr.fields[childname]             # <<<<<<<<<<<<<<
 *         child, new_offset = fields
 * 
 */
    if (unlikely(__pyx_v_descr->fields == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(2, 852, __pyx_L1_error)
    }
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_descr->fields, __pyx_v_childname); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 852, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(2, 852, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_fields, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":853
 *     for childname in descr.names:
 *         fields = descr.fields[childname]
 *         child, new_offset = fields             # <<<<<<<<<<<<<<
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 */
    if (likely(__pyx_v_fields != Py_None)) {
      PyObject* sequence = __pyx_v_fields;
      Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        __PYX_ERR(2, 853, __pyx_L1_error)
      }
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 853, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      #endif
    } else {
      __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(2, 853, __pyx_L1_error)
    }
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) __PYX_ERR(2, 853, __pyx_L1_error)
    __Pyx_XDECREF_SET(__pyx_v_child, ((PyArray_Descr *)__pyx_t_3));
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_new_offset, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":855
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 855, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_new_offset, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 855, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 855, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = ((((__pyx_v_end - __pyx_v_f) - ((int)__pyx_t_5)) < 15) != 0);
    if (unlikely(__pyx_t_6)) {

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":856
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__27, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 856, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 856, __pyx_L1_error)

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":855
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    }

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":858
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '>') != 0);
    if (!__pyx_t_7) {
      goto __pyx_L8_next_or;
    } else {
    }
    __pyx_t_7 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_L8_next_or:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":859
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *             raise ValueError(u"Non-native byte order not supported")
 *             # One could encode it in the format string and have Cython
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '<') != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_6 = __pyx_t_7;
    __pyx_L7_bool_binop_done:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":858
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    if (unlikely(__pyx_t_6)) {

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":860
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__26, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 860, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(2, 860, __pyx_L1_error)

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":858
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":870
 * 
 *         # Output padding bytes
 *         while offset[0] < new_offset:             # <<<<<<<<<<<<<<
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 */
    while (1) {
      __pyx_t_3 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 870, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_v_new_offset, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 870, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 870, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_6) break;

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":871
 *         # Output padding bytes
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte             # <<<<<<<<<<<<<<
 *             f += 1
 *             offset[0] += 1
 */
      (__pyx_v_f[0]) = 0x78;

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":872
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte
 *             f += 1             # <<<<<<<<<<<<<<
 *             offset[0] += 1
 * 
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":873
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 *             offset[0] += 1             # <<<<<<<<<<<<<<
 * 
 *         offset[0] += child.itemsize
 */
      __pyx_t_8 = 0;
      (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + 1);
    }

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":875
 *             offset[0] += 1
 * 
 *         offset[0] += child.itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not PyDataType_HASFIELDS(child):
 */
    __pyx_t_8 = 0;
    (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + __pyx_v_child->elsize);

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":877
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
    __pyx_t_6 = ((!(PyDataType_HASFIELDS(__pyx_v_child) != 0)) != 0);
    if (__pyx_t_6) {

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":878
 * 
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num             # <<<<<<<<<<<<<<
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_child->type_num); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 878, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":879
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      __pyx_t_6 = (((__pyx_v_end - __pyx_v_f) < 5) != 0);
      if (unlikely(__pyx_t_6)) {

        /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":880
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__28, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 880, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(2, 880, __pyx_L1_error)

        /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":879
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":883
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_BYTE); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 883, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 883, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 883, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 98;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":884
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"             # <<<<<<<<<<<<<<
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UBYTE); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 884, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 884, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 884, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 66;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":885
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"             # <<<<<<<<<<<<<<
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_SHORT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 885, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 885, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 885, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x68;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":886
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"             # <<<<<<<<<<<<<<
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_USHORT); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 886, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 886, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 886, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 72;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":887
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_INT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 887, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 887, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x69;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":888
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UINT); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 888, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 888, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 888, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 73;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":889
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONG); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 889, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 889, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x6C;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":890
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONG); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 890, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 890, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 890, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 76;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":891
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGLONG); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 891, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 891, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 891, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x71;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":892
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONGLONG); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 892, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 892, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 892, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 81;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":893
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"             # <<<<<<<<<<<<<<
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_FLOAT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 893, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 893, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 893, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x66;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":894
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_DOUBLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 894, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 894, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 894, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x64;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":895
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"             # <<<<<<<<<<<<<<
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGDOUBLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 895, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 895, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 895, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x67;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":896
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf             # <<<<<<<<<<<<<<
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CFLOAT); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 896, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 896, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 896, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x66;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":897
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd             # <<<<<<<<<<<<<<
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CDOUBLE); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 897, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 897, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 897, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x64;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":898
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg             # <<<<<<<<<<<<<<
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CLONGDOUBLE); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 898, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 898, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 898, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x67;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":899
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_OBJECT); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 899, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 899, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(2, 899, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (likely(__pyx_t_6)) {
        (__pyx_v_f[0]) = 79;
        goto __pyx_L15;
      }

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":901
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *             f += 1
 *         else:
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_PyUnicode_FormatSafe(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 901, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(2, 901, __pyx_L1_error)
      }
      __pyx_L15:;

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":902
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *             f += 1             # <<<<<<<<<<<<<<
 *         else:
 *             # Cython ignores struct boundary information ("T{...}"),
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":877
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
      goto __pyx_L13;
    }

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":906
 *             # Cython ignores struct boundary information ("T{...}"),
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
    /*else*/ {
      __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_child, __pyx_v_f, __pyx_v_end, __pyx_v_offset); if (unlikely(__pyx_t_9 == ((char *)NULL))) __PYX_ERR(2, 906, __pyx_L1_error)
      __pyx_v_f = __pyx_t_9;
    }
    __pyx_L13:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":851
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":907
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":842
 *         return ()
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("numpy._util_dtypestring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_childname);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1022
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1023
 * 
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1024
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  (void)(PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base));

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1022
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1026
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1027
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1028
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = ((__pyx_v_base == NULL) != 0);
  if (__pyx_t_1) {

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1029
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1028
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1030
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1026
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1034
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_array", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1035
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1036
 * cdef inline int import_array() except -1:
 *     try:
 *         _import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1036, __pyx_L3_error)

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1035
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1037
 *     try:
 *         _import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1037, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1038
 *         _import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__29, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1038, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1038, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1035
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_array()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1034
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1040
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_umath", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1041
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1042
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1042, __pyx_L3_error)

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1041
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1043
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1043, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1044
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1044, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1044, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1041
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1040
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1046
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("import_ufunc", 0);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1047
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1048
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(2, 1048, __pyx_L3_error)

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1047
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1049
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(2, 1049, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_GOTREF(__pyx_t_7);

      /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1050
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__30, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1050, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(2, 1050, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;
    __pyx_L5_except_error:;

    /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1047
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1046
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage __pyx_vtable_8omnivore_12disassembler_7libudis_TextStorage;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_TextStorage(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)o);
  p->__pyx_vtab = __pyx_vtabptr_8omnivore_12disassembler_7libudis_TextStorage;
  p->label_info = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->text_buffer = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_TextStorage(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->label_info);
  Py_CLEAR(p->text_buffer);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis_TextStorage(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)o;
  if (p->label_info) {
    e = (*v)(((PyObject *)p->label_info), a); if (e) return e;
  }
  if (p->text_buffer) {
    e = (*v)(((PyObject *)p->text_buffer), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8omnivore_12disassembler_7libudis_TextStorage(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)o;
  tmp = ((PyObject*)p->label_info);
  p->label_info = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->text_buffer);
  p->text_buffer = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_8omnivore_12disassembler_7libudis_TextStorage(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_11TextStorage_num_lines(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_11TextStorage_num_lines(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9num_lines_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_11TextStorage_label_info(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_11TextStorage_label_info(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_10label_info_5__del__(o);
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_11TextStorage_text_buffer(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_11TextStorage_text_buffer(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11text_buffer_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_8omnivore_12disassembler_7libudis_TextStorage[] = {
  {"alloc_arrays", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_3alloc_arrays, METH_VARARGS|METH_KEYWORDS, 0},
  {"get_label_data_addr", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_14get_label_data_addr, METH_NOARGS, 0},
  {"get_text_storage_addr", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_16get_text_storage_addr, METH_NOARGS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_18__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_20__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_8omnivore_12disassembler_7libudis_TextStorage[] = {
  {(char *)"num_lines", __pyx_getprop_8omnivore_12disassembler_7libudis_11TextStorage_num_lines, __pyx_setprop_8omnivore_12disassembler_7libudis_11TextStorage_num_lines, (char *)0, 0},
  {(char *)"label_info", __pyx_getprop_8omnivore_12disassembler_7libudis_11TextStorage_label_info, __pyx_setprop_8omnivore_12disassembler_7libudis_11TextStorage_label_info, (char *)0, 0},
  {(char *)"text_buffer", __pyx_getprop_8omnivore_12disassembler_7libudis_11TextStorage_text_buffer, __pyx_setprop_8omnivore_12disassembler_7libudis_11TextStorage_text_buffer, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_TextStorage = {
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_8omnivore_12disassembler_7libudis_TextStorage, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_TextStorage = {
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_5__len__, /*mp_length*/
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_9__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis_TextStorage = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.TextStorage", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_TextStorage, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_TextStorage, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_TextStorage, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis_TextStorage, /*tp_traverse*/
  __pyx_tp_clear_8omnivore_12disassembler_7libudis_TextStorage, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_11__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8omnivore_12disassembler_7libudis_TextStorage, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_8omnivore_12disassembler_7libudis_TextStorage, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis_TextStorage, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_LabelStorage __pyx_vtable_8omnivore_12disassembler_7libudis_LabelStorage;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_LabelStorage(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *p;
  PyObject *o = __pyx_tp_new_8omnivore_12disassembler_7libudis_TextStorage(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_TextStorage*)__pyx_vtabptr_8omnivore_12disassembler_7libudis_LabelStorage;
  return o;
}
static PyObject *__pyx_sq_item_8omnivore_12disassembler_7libudis_LabelStorage(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_8omnivore_12disassembler_7libudis_LabelStorage(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_10__setitem__(o, i, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_12__delitem__(o, i);
  }
}

static PyMethodDef __pyx_methods_8omnivore_12disassembler_7libudis_LabelStorage[] = {
  {"print_all", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_14print_all, METH_NOARGS, 0},
  {"keys", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_16keys, METH_NOARGS, 0},
  {"update", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_18update, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_20__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_22__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_LabelStorage = {
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_5__len__, /*sq_length*/
  #else
  0, /*sq_length*/
  #endif
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_8omnivore_12disassembler_7libudis_LabelStorage, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_3__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_LabelStorage = {
  #if CYTHON_COMPILING_IN_PYPY
  __pyx_pw_8omnivore_12disassembler_7libudis_11TextStorage_5__len__, /*mp_length*/
  #else
  0, /*mp_length*/
  #endif
  __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_5__getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_8omnivore_12disassembler_7libudis_LabelStorage, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis_LabelStorage = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.LabelStorage", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis_LabelStorage), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_TextStorage, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_LabelStorage, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_LabelStorage, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis_TextStorage, /*tp_traverse*/
  __pyx_tp_clear_8omnivore_12disassembler_7libudis_TextStorage, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_7__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8omnivore_12disassembler_7libudis_LabelStorage, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_12LabelStorage_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis_LabelStorage, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedDisassembly __pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedDisassembly;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_StringifiedDisassembly(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)o);
  p->__pyx_vtab = __pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedDisassembly;
  p->jmp_targets = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->disasm_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_StringifiedDisassembly(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->jmp_targets);
  Py_CLEAR(p->disasm_text);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis_StringifiedDisassembly(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)o;
  if (p->jmp_targets) {
    e = (*v)(((PyObject *)p->jmp_targets), a); if (e) return e;
  }
  if (p->disasm_text) {
    e = (*v)(((PyObject *)p->disasm_text), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8omnivore_12disassembler_7libudis_StringifiedDisassembly(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *)o;
  tmp = ((PyObject*)p->jmp_targets);
  p->jmp_targets = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->disasm_text);
  p->disasm_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_8omnivore_12disassembler_7libudis_StringifiedDisassembly(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_origin(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_origin(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_6origin_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_last_pc(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_last_pc(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7last_pc_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_start_index(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_start_index(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11start_index_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_jmp_targets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_jmp_targets(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11jmp_targets_5__del__(o);
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_disasm_text(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_disasm_text(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_11disasm_text_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_8omnivore_12disassembler_7libudis_StringifiedDisassembly[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_10__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_12__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_8omnivore_12disassembler_7libudis_StringifiedDisassembly[] = {
  {(char *)"origin", __pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_origin, __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_origin, (char *)0, 0},
  {(char *)"last_pc", __pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_last_pc, __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_last_pc, (char *)0, 0},
  {(char *)"start_index", __pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_start_index, __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_start_index, (char *)0, 0},
  {(char *)"jmp_targets", __pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_jmp_targets, __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_jmp_targets, (char *)0, 0},
  {(char *)"disasm_text", __pyx_getprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_disasm_text, __pyx_setprop_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_disasm_text, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_StringifiedDisassembly = {
  __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_8omnivore_12disassembler_7libudis_StringifiedDisassembly, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_StringifiedDisassembly = {
  __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_3__len__, /*mp_length*/
  __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_5__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.StringifiedDisassembly", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_StringifiedDisassembly, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_StringifiedDisassembly, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_StringifiedDisassembly, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis_StringifiedDisassembly, /*tp_traverse*/
  __pyx_tp_clear_8omnivore_12disassembler_7libudis_StringifiedDisassembly, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_7__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8omnivore_12disassembler_7libudis_StringifiedDisassembly, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_8omnivore_12disassembler_7libudis_StringifiedDisassembly, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis_StringifiedDisassembly, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_ParsedDisassembly __pyx_vtable_8omnivore_12disassembler_7libudis_ParsedDisassembly;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_ParsedDisassembly(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)o);
  p->__pyx_vtab = __pyx_vtabptr_8omnivore_12disassembler_7libudis_ParsedDisassembly;
  p->raw_entries = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->jmp_targets = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->index_to_row = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_ParsedDisassembly(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->raw_entries);
  Py_CLEAR(p->jmp_targets);
  Py_CLEAR(p->index_to_row);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis_ParsedDisassembly(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)o;
  if (p->raw_entries) {
    e = (*v)(((PyObject *)p->raw_entries), a); if (e) return e;
  }
  if (p->jmp_targets) {
    e = (*v)(((PyObject *)p->jmp_targets), a); if (e) return e;
  }
  if (p->index_to_row) {
    e = (*v)(((PyObject *)p->index_to_row), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8omnivore_12disassembler_7libudis_ParsedDisassembly(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *)o;
  tmp = ((PyObject*)p->raw_entries);
  p->raw_entries = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->jmp_targets);
  p->jmp_targets = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->index_to_row);
  p->index_to_row = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_max_entries(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_max_entries(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11max_entries_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_raw_entries(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_raw_entries(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11raw_entries_5__del__(o);
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_origin(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_origin(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_6origin_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_jmp_targets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_jmp_targets(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11jmp_targets_5__del__(o);
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_num_bytes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_num_bytes(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9num_bytes_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_index_to_row(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_index_to_row(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_12index_to_row_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_8omnivore_12disassembler_7libudis_ParsedDisassembly[] = {
  {"parse_test", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_5parse_test, METH_VARARGS|METH_KEYWORDS, 0},
  {"stringify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_7stringify, METH_VARARGS|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_9__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_11__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_8omnivore_12disassembler_7libudis_ParsedDisassembly[] = {
  {(char *)"max_entries", __pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_max_entries, __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_max_entries, (char *)0, 0},
  {(char *)"raw_entries", __pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_raw_entries, __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_raw_entries, (char *)0, 0},
  {(char *)"origin", __pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_origin, __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_origin, (char *)0, 0},
  {(char *)"jmp_targets", __pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_jmp_targets, __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_jmp_targets, (char *)0, 0},
  {(char *)"num_bytes", __pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_num_bytes, __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_num_bytes, (char *)0, 0},
  {(char *)"index_to_row", __pyx_getprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_index_to_row, __pyx_setprop_8omnivore_12disassembler_7libudis_17ParsedDisassembly_index_to_row, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_ParsedDisassembly = {
  __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_ParsedDisassembly = {
  __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.ParsedDisassembly", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_ParsedDisassembly, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_ParsedDisassembly, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_ParsedDisassembly, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis_ParsedDisassembly, /*tp_traverse*/
  __pyx_tp_clear_8omnivore_12disassembler_7libudis_ParsedDisassembly, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8omnivore_12disassembler_7libudis_ParsedDisassembly, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_8omnivore_12disassembler_7libudis_ParsedDisassembly, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_17ParsedDisassembly_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis_ParsedDisassembly, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_DisassemblyConfig(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_DisassemblyConfig(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_8omnivore_12disassembler_7libudis_DisassemblyConfig[] = {
  {"get_parser", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_3get_parser, METH_VARARGS|METH_KEYWORDS, 0},
  {"parse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_5parse, METH_VARARGS|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_7__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_9__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.DisassemblyConfig", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis_DisassemblyConfig), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_DisassemblyConfig, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8omnivore_12disassembler_7libudis_DisassemblyConfig, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_17DisassemblyConfig_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis_DisassemblyConfig, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_StringifiedHistory __pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedHistory;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_StringifiedHistory(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)o);
  p->__pyx_vtab = __pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedHistory;
  p->jmp_targets = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->history_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None); Py_INCREF(Py_None);
  p->result_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_StringifiedHistory(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->jmp_targets);
  Py_CLEAR(p->history_text);
  Py_CLEAR(p->result_text);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis_StringifiedHistory(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)o;
  if (p->jmp_targets) {
    e = (*v)(((PyObject *)p->jmp_targets), a); if (e) return e;
  }
  if (p->history_text) {
    e = (*v)(((PyObject *)p->history_text), a); if (e) return e;
  }
  if (p->result_text) {
    e = (*v)(((PyObject *)p->result_text), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8omnivore_12disassembler_7libudis_StringifiedHistory(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *)o;
  tmp = ((PyObject*)p->jmp_targets);
  p->jmp_targets = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->history_text);
  p->history_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->result_text);
  p->result_text = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_8omnivore_12disassembler_7libudis_StringifiedHistory(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_origin(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_origin(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_6origin_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_last_pc(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_last_pc(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7last_pc_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_start_index(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_start_index(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11start_index_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_jmp_targets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_jmp_targets(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11jmp_targets_5__del__(o);
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_history_text(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_history_text(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12history_text_5__del__(o);
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_result_text(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_result_text(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_11result_text_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_8omnivore_12disassembler_7libudis_StringifiedHistory[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_10__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_12__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_8omnivore_12disassembler_7libudis_StringifiedHistory[] = {
  {(char *)"origin", __pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_origin, __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_origin, (char *)0, 0},
  {(char *)"last_pc", __pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_last_pc, __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_last_pc, (char *)0, 0},
  {(char *)"start_index", __pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_start_index, __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_start_index, (char *)0, 0},
  {(char *)"jmp_targets", __pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_jmp_targets, __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_jmp_targets, (char *)0, 0},
  {(char *)"history_text", __pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_history_text, __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_history_text, (char *)0, 0},
  {(char *)"result_text", __pyx_getprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_result_text, __pyx_setprop_8omnivore_12disassembler_7libudis_18StringifiedHistory_result_text, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_StringifiedHistory = {
  __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_8omnivore_12disassembler_7libudis_StringifiedHistory, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_StringifiedHistory = {
  __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_3__len__, /*mp_length*/
  __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_5__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.StringifiedHistory", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_StringifiedHistory, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_StringifiedHistory, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_StringifiedHistory, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis_StringifiedHistory, /*tp_traverse*/
  __pyx_tp_clear_8omnivore_12disassembler_7libudis_StringifiedHistory, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_7__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8omnivore_12disassembler_7libudis_StringifiedHistory, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_8omnivore_12disassembler_7libudis_StringifiedHistory, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_18StringifiedHistory_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis_StringifiedHistory, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_8omnivore_12disassembler_7libudis_HistoryStorage __pyx_vtable_8omnivore_12disassembler_7libudis_HistoryStorage;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis_HistoryStorage(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)o);
  p->__pyx_vtab = __pyx_vtabptr_8omnivore_12disassembler_7libudis_HistoryStorage;
  p->history_array = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->entries = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_HistoryStorage(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->history_array);
  Py_CLEAR(p->entries);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis_HistoryStorage(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)o;
  if (p->history_array) {
    e = (*v)(((PyObject *)p->history_array), a); if (e) return e;
  }
  if (p->entries) {
    e = (*v)(((PyObject *)p->entries), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_8omnivore_12disassembler_7libudis_HistoryStorage(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *)o;
  tmp = ((PyObject*)p->history_array);
  p->history_array = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->entries);
  p->entries = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
static PyObject *__pyx_sq_item_8omnivore_12disassembler_7libudis_HistoryStorage(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_first_entry_index(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_17first_entry_index_1__get__(o);
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_latest_entry_index(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_18latest_entry_index_1__get__(o);
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_next_entry_index(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16next_entry_index_1__get__(o);
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_cumulative_count(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16cumulative_count_1__get__(o);
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_history_array(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_14HistoryStorage_history_array(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_13history_array_5__del__(o);
  }
}

static PyObject *__pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_entries(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_1__get__(o);
}

static int __pyx_setprop_8omnivore_12disassembler_7libudis_14HistoryStorage_entries(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_3__set__(o, v);
  }
  else {
    return __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7entries_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_8omnivore_12disassembler_7libudis_HistoryStorage[] = {
  {"summary", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_10summary, METH_NOARGS, 0},
  {"debug_range", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_12debug_range, METH_O, 0},
  {"stringify", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_14stringify, METH_VARARGS|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_16__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_18__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_8omnivore_12disassembler_7libudis_HistoryStorage[] = {
  {(char *)"first_entry_index", __pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_first_entry_index, 0, (char *)0, 0},
  {(char *)"latest_entry_index", __pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_latest_entry_index, 0, (char *)0, 0},
  {(char *)"next_entry_index", __pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_next_entry_index, 0, (char *)0, 0},
  {(char *)"cumulative_count", __pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_cumulative_count, 0, (char *)0, 0},
  {(char *)"history_array", __pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_history_array, __pyx_setprop_8omnivore_12disassembler_7libudis_14HistoryStorage_history_array, (char *)0, 0},
  {(char *)"entries", __pyx_getprop_8omnivore_12disassembler_7libudis_14HistoryStorage_entries, __pyx_setprop_8omnivore_12disassembler_7libudis_14HistoryStorage_entries, (char *)0, 0},
  {0, 0, 0, 0, 0}
};

static PySequenceMethods __pyx_tp_as_sequence_HistoryStorage = {
  __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_8omnivore_12disassembler_7libudis_HistoryStorage, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_HistoryStorage = {
  __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_3__len__, /*mp_length*/
  __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_5__getitem__, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.HistoryStorage", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis_HistoryStorage, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_HistoryStorage, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_HistoryStorage, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis_HistoryStorage, /*tp_traverse*/
  __pyx_tp_clear_8omnivore_12disassembler_7libudis_HistoryStorage, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_7__iter__, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_8omnivore_12disassembler_7libudis_HistoryStorage, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_8omnivore_12disassembler_7libudis_HistoryStorage, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_8omnivore_12disassembler_7libudis_14HistoryStorage_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis_HistoryStorage, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__[8];
static int __pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ = 0;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__)))) {
    o = (PyObject*)__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__[--__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__];
    memset(o, 0, sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__)))) {
    __pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__[__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__++] = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.__pyx_scope_struct____iter__", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__[8];
static int __pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ = 0;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__)))) {
    o = (PyObject*)__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__[--__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__];
    memset(o, 0, sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__)))) {
    __pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__[__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__++] = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.__pyx_scope_struct_1___iter__", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__[8];
static int __pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ = 0;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__)))) {
    o = (PyObject*)__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__[--__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__];
    memset(o, 0, sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__)))) {
    __pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__[__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__++] = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.__pyx_scope_struct_2___iter__", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__[8];
static int __pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ = 0;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__)))) {
    o = (PyObject*)__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__[--__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__];
    memset(o, 0, sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_self);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__)))) {
    __pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__[__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__++] = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ *)o;
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.__pyx_scope_struct_3___iter__", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__[8];
static int __pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ = 0;

static PyObject *__pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__)))) {
    o = (PyObject*)__pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__[--__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__];
    memset(o, 0, sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__));
    (void) PyObject_INIT(o, t);
    PyObject_GC_Track(o);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__(PyObject *o) {
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_i);
  Py_CLEAR(p->__pyx_v_self);
  Py_CLEAR(p->__pyx_t_0);
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__)))) {
    __pyx_freelist_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__[__pyx_freecount_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__++] = ((struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static int __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *p = (struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ *)o;
  if (p->__pyx_v_i) {
    e = (*v)(p->__pyx_v_i, a); if (e) return e;
  }
  if (p->__pyx_v_self) {
    e = (*v)(((PyObject *)p->__pyx_v_self), a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  return 0;
}

static PyTypeObject __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ = {
  PyVarObject_HEAD_INIT(0, 0)
  "omnivore.disassembler.libudis.__pyx_scope_struct_4___iter__", /*tp_name*/
  sizeof(struct __pyx_obj_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_libudis(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_libudis},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "libudis",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_d, __pyx_k_CYTHON_ERROR_ParsedDisassembly_d, sizeof(__pyx_k_CYTHON_ERROR_ParsedDisassembly_d), 0, 1, 0, 0},
  {&__pyx_kp_u_CYTHON_ERROR_ParsedDisassembly_i, __pyx_k_CYTHON_ERROR_ParsedDisassembly_i, sizeof(__pyx_k_CYTHON_ERROR_ParsedDisassembly_i), 0, 1, 0, 0},
  {&__pyx_kp_u_CYTHON_ERROR_Text_buffer_line_co, __pyx_k_CYTHON_ERROR_Text_buffer_line_co, sizeof(__pyx_k_CYTHON_ERROR_Text_buffer_line_co), 0, 1, 0, 0},
  {&__pyx_kp_u_CYTHON_ERROR_Text_buffer_size, __pyx_k_CYTHON_ERROR_Text_buffer_size, sizeof(__pyx_k_CYTHON_ERROR_Text_buffer_size), 0, 1, 0, 0},
  {&__pyx_n_s_DisassemblyConfig, __pyx_k_DisassemblyConfig, sizeof(__pyx_k_DisassemblyConfig), 0, 0, 1, 1},
  {&__pyx_kp_u_Format_string_allocated_too_shor, __pyx_k_Format_string_allocated_too_shor, sizeof(__pyx_k_Format_string_allocated_too_shor), 0, 1, 0, 0},
  {&__pyx_kp_u_Format_string_allocated_too_shor_2, __pyx_k_Format_string_allocated_too_shor_2, sizeof(__pyx_k_Format_string_allocated_too_shor_2), 0, 1, 0, 0},
  {&__pyx_n_s_HISTORY_ENTRY_DTYPE, __pyx_k_HISTORY_ENTRY_DTYPE, sizeof(__pyx_k_HISTORY_ENTRY_DTYPE), 0, 0, 1, 1},
  {&__pyx_n_s_HistoryStorage, __pyx_k_HistoryStorage, sizeof(__pyx_k_HistoryStorage), 0, 0, 1, 1},
  {&__pyx_n_s_HistoryStorage___iter, __pyx_k_HistoryStorage___iter, sizeof(__pyx_k_HistoryStorage___iter), 0, 0, 1, 1},
  {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
  {&__pyx_n_s_LabelStorage, __pyx_k_LabelStorage, sizeof(__pyx_k_LabelStorage), 0, 0, 1, 1},
  {&__pyx_n_s_LabelStorage___iter, __pyx_k_LabelStorage___iter, sizeof(__pyx_k_LabelStorage___iter), 0, 0, 1, 1},
  {&__pyx_kp_u_Non_native_byte_order_not_suppor, __pyx_k_Non_native_byte_order_not_suppor, sizeof(__pyx_k_Non_native_byte_order_not_suppor), 0, 1, 0, 0},
  {&__pyx_n_s_ParsedDisassembly, __pyx_k_ParsedDisassembly, sizeof(__pyx_k_ParsedDisassembly), 0, 0, 1, 1},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s_StringifiedDisassembly, __pyx_k_StringifiedDisassembly, sizeof(__pyx_k_StringifiedDisassembly), 0, 0, 1, 1},
  {&__pyx_n_s_StringifiedDisassembly___iter, __pyx_k_StringifiedDisassembly___iter, sizeof(__pyx_k_StringifiedDisassembly___iter), 0, 0, 1, 1},
  {&__pyx_n_s_StringifiedHistory, __pyx_k_StringifiedHistory, sizeof(__pyx_k_StringifiedHistory), 0, 0, 1, 1},
  {&__pyx_n_s_StringifiedHistory___iter, __pyx_k_StringifiedHistory___iter, sizeof(__pyx_k_StringifiedHistory___iter), 0, 0, 1, 1},
  {&__pyx_n_s_TextStorage, __pyx_k_TextStorage, sizeof(__pyx_k_TextStorage), 0, 0, 1, 1},
  {&__pyx_n_s_TextStorage___iter, __pyx_k_TextStorage___iter, sizeof(__pyx_k_TextStorage___iter), 0, 0, 1, 1},
  {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_kp_u__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 1, 0, 0},
  {&__pyx_kp_u__19, __pyx_k__19, sizeof(__pyx_k__19), 0, 1, 0, 0},
  {&__pyx_kp_u__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 1, 0, 0},
  {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
  {&__pyx_n_s_alloc_arrays, __pyx_k_alloc_arrays, sizeof(__pyx_k_alloc_arrays), 0, 0, 1, 1},
  {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
  {&__pyx_n_s_buffer_size, __pyx_k_buffer_size, sizeof(__pyx_k_buffer_size), 0, 0, 1, 1},
  {&__pyx_kp_u_bytes, __pyx_k_bytes, sizeof(__pyx_k_bytes), 0, 1, 0, 0},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_close, __pyx_k_close, sizeof(__pyx_k_close), 0, 0, 1, 1},
  {&__pyx_kp_u_cumulative, __pyx_k_cumulative, sizeof(__pyx_k_cumulative), 0, 1, 0, 0},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_def_disasm_type, __pyx_k_def_disasm_type, sizeof(__pyx_k_def_disasm_type), 0, 0, 1, 1},
  {&__pyx_kp_u_deleting_labels_via_slices_not_y, __pyx_k_deleting_labels_via_slices_not_y, sizeof(__pyx_k_deleting_labels_via_slices_not_y), 0, 1, 0, 0},
  {&__pyx_n_s_disasm_type, __pyx_k_disasm_type, sizeof(__pyx_k_disasm_type), 0, 0, 1, 1},
  {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
  {&__pyx_kp_u_entries, __pyx_k_entries, sizeof(__pyx_k_entries), 0, 1, 0, 0},
  {&__pyx_kp_u_entry, __pyx_k_entry, sizeof(__pyx_k_entry), 0, 1, 0, 0},
  {&__pyx_kp_u_exceeded_attempted_to_save, __pyx_k_exceeded_attempted_to_save, sizeof(__pyx_k_exceeded_attempted_to_save), 0, 1, 0, 0},
  {&__pyx_kp_u_exceeded_in_LabelStorage_attemp, __pyx_k_exceeded_in_LabelStorage_attemp, sizeof(__pyx_k_exceeded_in_LabelStorage_attemp), 0, 1, 0, 0},
  {&__pyx_kp_u_exceeded_in_TextStorage_attempt, __pyx_k_exceeded_in_TextStorage_attempt, sizeof(__pyx_k_exceeded_in_TextStorage_attempt), 0, 1, 0, 0},
  {&__pyx_n_s_get_label_data_addr, __pyx_k_get_label_data_addr, sizeof(__pyx_k_get_label_data_addr), 0, 0, 1, 1},
  {&__pyx_n_s_get_parser, __pyx_k_get_parser, sizeof(__pyx_k_get_parser), 0, 0, 1, 1},
  {&__pyx_n_s_get_text_storage_addr, __pyx_k_get_text_storage_addr, sizeof(__pyx_k_get_text_storage_addr), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_n_s_hex, __pyx_k_hex, sizeof(__pyx_k_hex), 0, 0, 1, 1},
  {&__pyx_n_s_hex_lower, __pyx_k_hex_lower, sizeof(__pyx_k_hex_lower), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_kp_u_index_must_be_int_or_slice_not, __pyx_k_index_must_be_int_or_slice_not, sizeof(__pyx_k_index_must_be_int_or_slice_not), 0, 1, 0, 0},
  {&__pyx_n_s_indices, __pyx_k_indices, sizeof(__pyx_k_indices), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_iter, __pyx_k_iter, sizeof(__pyx_k_iter), 0, 0, 1, 1},
  {&__pyx_n_s_jmp_targets, __pyx_k_jmp_targets, sizeof(__pyx_k_jmp_targets), 0, 0, 1, 1},
  {&__pyx_n_s_labels, __pyx_k_labels, sizeof(__pyx_k_labels), 0, 0, 1, 1},
  {&__pyx_kp_u_latest, __pyx_k_latest, sizeof(__pyx_k_latest), 0, 1, 0, 0},
  {&__pyx_kp_u_lines, __pyx_k_lines, sizeof(__pyx_k_lines), 0, 1, 0, 0},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_max_entries, __pyx_k_max_entries, sizeof(__pyx_k_max_entries), 0, 0, 1, 1},
  {&__pyx_n_s_max_lines, __pyx_k_max_lines, sizeof(__pyx_k_max_lines), 0, 0, 1, 1},
  {&__pyx_n_s_mnemonic_lower, __pyx_k_mnemonic_lower, sizeof(__pyx_k_mnemonic_lower), 0, 0, 1, 1},
  {&__pyx_n_u_more, __pyx_k_more, sizeof(__pyx_k_more), 0, 1, 0, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_kp_u_ndarray_is_not_C_contiguous, __pyx_k_ndarray_is_not_C_contiguous, sizeof(__pyx_k_ndarray_is_not_C_contiguous), 0, 1, 0, 0},
  {&__pyx_kp_u_ndarray_is_not_Fortran_contiguou, __pyx_k_ndarray_is_not_Fortran_contiguou, sizeof(__pyx_k_ndarray_is_not_Fortran_contiguou), 0, 1, 0, 0},
  {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
  {&__pyx_n_s_num_bytes, __pyx_k_num_bytes, sizeof(__pyx_k_num_bytes), 0, 0, 1, 1},
  {&__pyx_n_s_num_entries, __pyx_k_num_entries, sizeof(__pyx_k_num_entries), 0, 0, 1, 1},
  {&__pyx_n_s_num_lines, __pyx_k_num_lines, sizeof(__pyx_k_num_lines), 0, 0, 1, 1},
  {&__pyx_n_s_num_lines_requested, __pyx_k_num_lines_requested, sizeof(__pyx_k_num_lines_requested), 0, 0, 1, 1},
  {&__pyx_kp_u_number_of_entries, __pyx_k_number_of_entries, sizeof(__pyx_k_number_of_entries), 0, 1, 0, 0},
  {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
  {&__pyx_kp_u_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 1, 0, 0},
  {&__pyx_kp_u_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 1, 0, 0},
  {&__pyx_n_s_omnivore_disassembler_dtypes, __pyx_k_omnivore_disassembler_dtypes, sizeof(__pyx_k_omnivore_disassembler_dtypes), 0, 0, 1, 1},
  {&__pyx_n_s_omnivore_disassembler_libudis, __pyx_k_omnivore_disassembler_libudis, sizeof(__pyx_k_omnivore_disassembler_libudis), 0, 0, 1, 1},
  {&__pyx_n_s_origin, __pyx_k_origin, sizeof(__pyx_k_origin), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_n_u_print_all, __pyx_k_print_all, sizeof(__pyx_k_print_all), 0, 1, 0, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_segment, __pyx_k_segment, sizeof(__pyx_k_segment), 0, 0, 1, 1},
  {&__pyx_kp_s_self_history_cannot_be_converted, __pyx_k_self_history_cannot_be_converted, sizeof(__pyx_k_self_history_cannot_be_converted), 0, 0, 1, 0},
  {&__pyx_kp_s_self_history_entries_self_index, __pyx_k_self_history_entries_self_index, sizeof(__pyx_k_self_history_entries_self_index), 0, 0, 1, 0},
  {&__pyx_kp_s_self_jmp_targets_data_cannot_be, __pyx_k_self_jmp_targets_data_cannot_be, sizeof(__pyx_k_self_jmp_targets_data_cannot_be), 0, 0, 1, 0},
  {&__pyx_kp_s_self_label_info_data_cannot_be_c, __pyx_k_self_label_info_data_cannot_be_c, sizeof(__pyx_k_self_label_info_data_cannot_be_c), 0, 0, 1, 0},
  {&__pyx_kp_s_self_segment_parsers_cannot_be_c, __pyx_k_self_segment_parsers_cannot_be_c, sizeof(__pyx_k_self_segment_parsers_cannot_be_c), 0, 0, 1, 0},
  {&__pyx_n_s_send, __pyx_k_send, sizeof(__pyx_k_send), 0, 0, 1, 1},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_kp_u_setting_labels_via_slices_not_ye, __pyx_k_setting_labels_via_slices_not_ye, sizeof(__pyx_k_setting_labels_via_slices_not_ye), 0, 1, 0, 0},
  {&__pyx_kp_u_slicing_not_yet_supported, __pyx_k_slicing_not_yet_supported, sizeof(__pyx_k_slicing_not_yet_supported), 0, 1, 0, 0},
  {&__pyx_n_s_split_comments, __pyx_k_split_comments, sizeof(__pyx_k_split_comments), 0, 0, 1, 1},
  {&__pyx_n_s_src, __pyx_k_src, sizeof(__pyx_k_src), 0, 0, 1, 1},
  {&__pyx_n_s_start_index, __pyx_k_start_index, sizeof(__pyx_k_start_index), 0, 0, 1, 1},
  {&__pyx_kp_u_start_of_ring, __pyx_k_start_of_ring, sizeof(__pyx_k_start_of_ring), 0, 1, 0, 0},
  {&__pyx_n_s_style, __pyx_k_style, sizeof(__pyx_k_style), 0, 0, 1, 1},
  {&__pyx_kp_u_summary, __pyx_k_summary, sizeof(__pyx_k_summary), 0, 1, 0, 0},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_text_buffer, __pyx_k_text_buffer, sizeof(__pyx_k_text_buffer), 0, 0, 1, 1},
  {&__pyx_n_s_throw, __pyx_k_throw, sizeof(__pyx_k_throw), 0, 0, 1, 1},
  {&__pyx_n_s_tobytes, __pyx_k_tobytes, sizeof(__pyx_k_tobytes), 0, 0, 1, 1},
  {&__pyx_n_s_tostring, __pyx_k_tostring, sizeof(__pyx_k_tostring), 0, 0, 1, 1},
  {&__pyx_kp_u_total, __pyx_k_total, sizeof(__pyx_k_total), 0, 1, 0, 0},
  {&__pyx_n_s_uint32, __pyx_k_uint32, sizeof(__pyx_k_uint32), 0, 0, 1, 1},
  {&__pyx_n_s_uint8, __pyx_k_uint8, sizeof(__pyx_k_uint8), 0, 0, 1, 1},
  {&__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_k_unknown_dtype_code_in_numpy_pxd, sizeof(__pyx_k_unknown_dtype_code_in_numpy_pxd), 0, 1, 0, 0},
  {&__pyx_kp_u_used, __pyx_k_used, sizeof(__pyx_k_used), 0, 1, 0, 0},
  {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 59, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(0, 72, __pyx_L1_error)
  __pyx_builtin_print = __Pyx_GetBuiltinName(__pyx_n_s_print); if (!__pyx_builtin_print) __PYX_ERR(0, 95, __pyx_L1_error)
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 159, __pyx_L1_error)
  __pyx_builtin_hex = __Pyx_GetBuiltinName(__pyx_n_s_hex); if (!__pyx_builtin_hex) __PYX_ERR(0, 211, __pyx_L1_error)
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) __PYX_ERR(2, 856, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(2, 1038, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_s_self_label_info_data_cannot_be_c); if (unlikely(!__pyx_tuple_)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "(tree fragment)":4
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_s_self_label_info_data_cannot_be_c); if (unlikely(!__pyx_tuple__2)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "libudis/libudis.pyx":136
 *             return (self.text_buffer[start:start + count].tostring(), info.num_bytes, info.item_count, info.type_code)
 *         elif isinstance(index, slice):
 *             raise TypeError(f"slicing not yet supported")             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_u_slicing_not_yet_supported); if (unlikely(!__pyx_tuple__3)) __PYX_ERR(0, 136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "libudis/libudis.pyx":188
 *                 start += 1
 *         elif isinstance(index, slice):
 *             raise TypeError(f"setting labels via slices not yet supported")             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_u_setting_labels_via_slices_not_ye); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "libudis/libudis.pyx":202
 *             self.num_lines -= 1
 *         elif isinstance(index, slice):
 *             raise TypeError(f"deleting labels via slices not yet supported")             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(f"index must be int or slice, not {type(index)}")
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_u_deleting_labels_via_slices_not_y); if (unlikely(!__pyx_tuple__5)) __PYX_ERR(0, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_self_label_info_data_cannot_be_c); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "(tree fragment)":4
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.label_info_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_s_self_label_info_data_cannot_be_c); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_s_self_jmp_targets_data_cannot_be); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "(tree fragment)":4
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_s_self_jmp_targets_data_cannot_be); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_s_self_history_entries_self_index); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "(tree fragment)":4
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history_entries,self.index_to_row_data,self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_s_self_history_entries_self_index); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_s_self_segment_parsers_cannot_be_c); if (unlikely(!__pyx_tuple__14)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "(tree fragment)":4
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.segment_parsers cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_s_self_segment_parsers_cannot_be_c); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_s_self_jmp_targets_data_cannot_be); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "(tree fragment)":4
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.jmp_targets_data cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_s_self_jmp_targets_data_cannot_be); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "libudis/libudis.pyx":695
 *         i = (from_index+1) % mod
 *         print(f"{i}: {self.entries[i]}")
 *         print("  ...")             # <<<<<<<<<<<<<<
 *         i = (last - 1) % mod
 *         print(f"{i}: {self.entries[i]}")
 */
  __pyx_tuple__21 = PyTuple_Pack(1, __pyx_kp_u__20); if (unlikely(!__pyx_tuple__21)) __PYX_ERR(0, 695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__21);
  __Pyx_GIVEREF(__pyx_tuple__21);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 */
  __pyx_tuple__22 = PyTuple_Pack(1, __pyx_kp_s_self_history_cannot_be_converted); if (unlikely(!__pyx_tuple__22)) __PYX_ERR(1, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__22);
  __Pyx_GIVEREF(__pyx_tuple__22);

  /* "(tree fragment)":4
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError("self.history cannot be converted to a Python object for pickling")             # <<<<<<<<<<<<<<
 */
  __pyx_tuple__23 = PyTuple_Pack(1, __pyx_kp_s_self_history_cannot_be_converted); if (unlikely(!__pyx_tuple__23)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__23);
  __Pyx_GIVEREF(__pyx_tuple__23);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":272
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
  __pyx_tuple__24 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_C_contiguous); if (unlikely(!__pyx_tuple__24)) __PYX_ERR(2, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__24);
  __Pyx_GIVEREF(__pyx_tuple__24);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":276
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_ARRAY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
  __pyx_tuple__25 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_Fortran_contiguou); if (unlikely(!__pyx_tuple__25)) __PYX_ERR(2, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__25);
  __Pyx_GIVEREF(__pyx_tuple__25);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":306
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
  __pyx_tuple__26 = PyTuple_Pack(1, __pyx_kp_u_Non_native_byte_order_not_suppor); if (unlikely(!__pyx_tuple__26)) __PYX_ERR(2, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__26);
  __Pyx_GIVEREF(__pyx_tuple__26);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":856
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
  __pyx_tuple__27 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(2, 856, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":880
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
  __pyx_tuple__28 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor_2); if (unlikely(!__pyx_tuple__28)) __PYX_ERR(2, 880, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__28);
  __Pyx_GIVEREF(__pyx_tuple__28);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1038
 *         _import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__29 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1044
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__30 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(2, 1044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_64 = PyInt_FromLong(64); if (unlikely(!__pyx_int_64)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_65536 = PyInt_FromLong(65536L); if (unlikely(!__pyx_int_65536)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_8omnivore_12disassembler_7libudis_TextStorage = &__pyx_vtable_8omnivore_12disassembler_7libudis_TextStorage;
  __pyx_vtable_8omnivore_12disassembler_7libudis_TextStorage.clear = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *))__pyx_f_8omnivore_12disassembler_7libudis_11TextStorage_clear;
  __pyx_vtable_8omnivore_12disassembler_7libudis_TextStorage.store = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *, int))__pyx_f_8omnivore_12disassembler_7libudis_11TextStorage_store;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis_TextStorage) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis_TextStorage.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis_TextStorage.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis_TextStorage.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis_TextStorage.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_8omnivore_12disassembler_7libudis_TextStorage.tp_dict, __pyx_vtabptr_8omnivore_12disassembler_7libudis_TextStorage) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_TextStorage, (PyObject *)&__pyx_type_8omnivore_12disassembler_7libudis_TextStorage) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_8omnivore_12disassembler_7libudis_TextStorage) < 0) __PYX_ERR(0, 22, __pyx_L1_error)
  __pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage = &__pyx_type_8omnivore_12disassembler_7libudis_TextStorage;
  __pyx_vtabptr_8omnivore_12disassembler_7libudis_LabelStorage = &__pyx_vtable_8omnivore_12disassembler_7libudis_LabelStorage;
  __pyx_vtable_8omnivore_12disassembler_7libudis_LabelStorage.__pyx_base = *__pyx_vtabptr_8omnivore_12disassembler_7libudis_TextStorage;
  __pyx_vtable_8omnivore_12disassembler_7libudis_LabelStorage.__pyx_base.clear = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_TextStorage *))__pyx_f_8omnivore_12disassembler_7libudis_12LabelStorage_clear;
  __pyx_type_8omnivore_12disassembler_7libudis_LabelStorage.tp_base = __pyx_ptype_8omnivore_12disassembler_7libudis_TextStorage;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis_LabelStorage) < 0) __PYX_ERR(0, 113, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis_LabelStorage.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis_LabelStorage.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis_LabelStorage.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis_LabelStorage.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_8omnivore_12disassembler_7libudis_LabelStorage.tp_dict, __pyx_vtabptr_8omnivore_12disassembler_7libudis_LabelStorage) < 0) __PYX_ERR(0, 113, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_LabelStorage, (PyObject *)&__pyx_type_8omnivore_12disassembler_7libudis_LabelStorage) < 0) __PYX_ERR(0, 113, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_8omnivore_12disassembler_7libudis_LabelStorage) < 0) __PYX_ERR(0, 113, __pyx_L1_error)
  __pyx_ptype_8omnivore_12disassembler_7libudis_LabelStorage = &__pyx_type_8omnivore_12disassembler_7libudis_LabelStorage;
  __pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedDisassembly = &__pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedDisassembly;
  __pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedDisassembly.clear = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *))__pyx_f_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_clear;
  __pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedDisassembly.parse_history_entries = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedDisassembly *, struct __pyx_t_7libudis_7libudis_history_entry_t *, int))__pyx_f_8omnivore_12disassembler_7libudis_22StringifiedDisassembly_parse_history_entries;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly) < 0) __PYX_ERR(0, 263, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly.tp_dict, __pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedDisassembly) < 0) __PYX_ERR(0, 263, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_StringifiedDisassembly, (PyObject *)&__pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly) < 0) __PYX_ERR(0, 263, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly) < 0) __PYX_ERR(0, 263, __pyx_L1_error)
  __pyx_ptype_8omnivore_12disassembler_7libudis_StringifiedDisassembly = &__pyx_type_8omnivore_12disassembler_7libudis_StringifiedDisassembly;
  __pyx_vtabptr_8omnivore_12disassembler_7libudis_ParsedDisassembly = &__pyx_vtable_8omnivore_12disassembler_7libudis_ParsedDisassembly;
  __pyx_vtable_8omnivore_12disassembler_7libudis_ParsedDisassembly.parse_next = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *, __pyx_t_7libudis_7libudis_parse_func_t, unsigned char *, int))__pyx_f_8omnivore_12disassembler_7libudis_17ParsedDisassembly_parse_next;
  __pyx_vtable_8omnivore_12disassembler_7libudis_ParsedDisassembly.fix_offset_labels = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_ParsedDisassembly *))__pyx_f_8omnivore_12disassembler_7libudis_17ParsedDisassembly_fix_offset_labels;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly) < 0) __PYX_ERR(0, 344, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly.tp_dict, __pyx_vtabptr_8omnivore_12disassembler_7libudis_ParsedDisassembly) < 0) __PYX_ERR(0, 344, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ParsedDisassembly, (PyObject *)&__pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly) < 0) __PYX_ERR(0, 344, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly) < 0) __PYX_ERR(0, 344, __pyx_L1_error)
  __pyx_ptype_8omnivore_12disassembler_7libudis_ParsedDisassembly = &__pyx_type_8omnivore_12disassembler_7libudis_ParsedDisassembly;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig) < 0) __PYX_ERR(0, 444, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_DisassemblyConfig, (PyObject *)&__pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig) < 0) __PYX_ERR(0, 444, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig) < 0) __PYX_ERR(0, 444, __pyx_L1_error)
  __pyx_ptype_8omnivore_12disassembler_7libudis_DisassemblyConfig = &__pyx_type_8omnivore_12disassembler_7libudis_DisassemblyConfig;
  __pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedHistory = &__pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedHistory;
  __pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedHistory.clear = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *))__pyx_f_8omnivore_12disassembler_7libudis_18StringifiedHistory_clear;
  __pyx_vtable_8omnivore_12disassembler_7libudis_StringifiedHistory.parse_history_entries = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_StringifiedHistory *, struct __pyx_t_7libudis_7libudis_emulator_history_t *, int, int))__pyx_f_8omnivore_12disassembler_7libudis_18StringifiedHistory_parse_history_entries;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory) < 0) __PYX_ERR(0, 525, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory.tp_dict, __pyx_vtabptr_8omnivore_12disassembler_7libudis_StringifiedHistory) < 0) __PYX_ERR(0, 525, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_StringifiedHistory, (PyObject *)&__pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory) < 0) __PYX_ERR(0, 525, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory) < 0) __PYX_ERR(0, 525, __pyx_L1_error)
  __pyx_ptype_8omnivore_12disassembler_7libudis_StringifiedHistory = &__pyx_type_8omnivore_12disassembler_7libudis_StringifiedHistory;
  __pyx_vtabptr_8omnivore_12disassembler_7libudis_HistoryStorage = &__pyx_vtable_8omnivore_12disassembler_7libudis_HistoryStorage;
  __pyx_vtable_8omnivore_12disassembler_7libudis_HistoryStorage.clear = (PyObject *(*)(struct __pyx_obj_8omnivore_12disassembler_7libudis_HistoryStorage *))__pyx_f_8omnivore_12disassembler_7libudis_14HistoryStorage_clear;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage) < 0) __PYX_ERR(0, 616, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  if (__Pyx_SetVtable(__pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage.tp_dict, __pyx_vtabptr_8omnivore_12disassembler_7libudis_HistoryStorage) < 0) __PYX_ERR(0, 616, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_HistoryStorage, (PyObject *)&__pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage) < 0) __PYX_ERR(0, 616, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage) < 0) __PYX_ERR(0, 616, __pyx_L1_error)
  __pyx_ptype_8omnivore_12disassembler_7libudis_HistoryStorage = &__pyx_type_8omnivore_12disassembler_7libudis_HistoryStorage;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__) < 0) __PYX_ERR(0, 74, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__ = &__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct____iter__;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__) < 0) __PYX_ERR(0, 140, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__ = &__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_1___iter__;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__) < 0) __PYX_ERR(0, 319, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__ = &__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_2___iter__;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__) < 0) __PYX_ERR(0, 578, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__ = &__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_3___iter__;
  if (PyType_Ready(&__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__) < 0) __PYX_ERR(0, 648, __pyx_L1_error)
  __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__.tp_print = 0;
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__.tp_dictoffset && __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
  }
  __pyx_ptype_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__ = &__pyx_type_8omnivore_12disassembler_7libudis___pyx_scope_struct_4___iter__;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(3, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 206, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(2, 206, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(2, 229, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(2, 233, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __Pyx_ImportType_CheckSize_Ignore);
   if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(2, 242, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(2, 918, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION < 3
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC void
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#else
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initlibudis(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initlibudis(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_libudis(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_libudis(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_libudis(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'libudis' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_libudis(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("libudis", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_omnivore__disassembler__libudis) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "omnivore.disassembler.libudis")) {
      if (unlikely(PyDict_SetItemString(modules, "omnivore.disassembler.libudis", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() != 0)) goto __pyx_L1_error;
  if (unlikely(__Pyx_modinit_type_import_code() != 0)) goto __pyx_L1_error;
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "libudis/libudis.pyx":4
 * from libc.stdio cimport printf
 * import cython
 * import numpy as np             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * 
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_numpy, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_1) < 0) __PYX_ERR(0, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":9
 * from libudis.libudis cimport history_entry_t, emulator_history_t, parse_func_t, string_func_t, jmp_targets_t, label_info_t
 * 
 * from omnivore.disassembler.dtypes import HISTORY_ENTRY_DTYPE             # <<<<<<<<<<<<<<
 * 
 * cdef extern:
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_HISTORY_ENTRY_DTYPE);
  __Pyx_GIVEREF(__pyx_n_s_HISTORY_ENTRY_DTYPE);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_HISTORY_ENTRY_DTYPE);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_omnivore_disassembler_dtypes, __pyx_t_1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_HISTORY_ENTRY_DTYPE); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_HISTORY_ENTRY_DTYPE, __pyx_t_1) < 0) __PYX_ERR(0, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "libudis/libudis.pyx":18
 * 
 * 
 * cdef char *hexdigits_lower = "000102030405060708090a0b0c0d0e0f101112131415161718191a1b1c1d1e1f202122232425262728292a2b2c2d2e2f303132333435363738393a3b3c3d3e3f404142434445464748494a4b4c4d4e4f505152535455565758595a5b5c5d5e5f606162636465666768696a6b6c6d6e6f707172737475767778797a7b7c7d7e7f808182838485868788898a8b8c8d8e8f909192939495969798999a9b9c9d9e9fa0a1a2a3a4a5a6a7a8a9aaabacadaeafb0b1b2b3b4b5b6b7b8b9babbbcbdbebfc0c1c2c3c4c5c6c7c8c9cacbcccdcecfd0d1d2d3d4d5d6d7d8d9dadbdcdddedfe0e1e2e3e4e5e6e7e8e9eaebecedeeeff0f1f2f3f4f5f6f7f8f9fafbfcfdfeff"             # <<<<<<<<<<<<<<
 * cdef char *hexdigits_upper = "000102030405060708090A0B0C0D0E0F101112131415161718191A1B1C1D1E1F202122232425262728292A2B2C2D2E2F303132333435363738393A3B3C3D3E3F404142434445464748494A4B4C4D4E4F505152535455565758595A5B5C5D5E5F606162636465666768696A6B6C6D6E6F707172737475767778797A7B7C7D7E7F808182838485868788898A8B8C8D8E8F909192939495969798999A9B9C9D9E9FA0A1A2A3A4A5A6A7A8A9AAABACADAEAFB0B1B2B3B4B5B6B7B8B9BABBBCBDBEBFC0C1C2C3C4C5C6C7C8C9CACBCCCDCECFD0D1D2D3D4D5D6D7D8D9DADBDCDDDEDFE0E1E2E3E4E5E6E7E8E9EAEBECEDEEEFF0F1F2F3F4F5F6F7F8F9FAFBFCFDFEFF"
 * 
 */
  __pyx_v_8omnivore_12disassembler_7libudis_hexdigits_lower = ((char *)"000102030405060708090a0b0c0d0e0f101112131415161718191a1b1c1d1e1f202122232425262728292a2b2c2d2e2f303132333435363738393a3b3c3d3e3f404142434445464748494a4b4c4d4e4f505152535455565758595a5b5c5d5e5f606162636465666768696a6b6c6d6e6f707172737475767778797a7b7c7d7e7f808182838485868788898a8b8c8d8e8f909192939495969798999a9b9c9d9e9fa0a1a2a3a4a5a6a7a8a9aaabacadaeafb0b1b2b3b4b5b6b7b8b9babbbcbdbebfc0c1c2c3c4c5c6c7c8c9cacbcccdcecfd0d1d2d3d4d5d6d7d8d9dadbdcdddedfe0e1e2e3e4e5e6e7e8e9eaebecedeeeff0f1f2f3f4f5f6f7f8f9fafbfcfdfeff");

  /* "libudis/libudis.pyx":19
 * 
 * cdef char *hexdigits_lower = "000102030405060708090a0b0c0d0e0f101112131415161718191a1b1c1d1e1f202122232425262728292a2b2c2d2e2f303132333435363738393a3b3c3d3e3f404142434445464748494a4b4c4d4e4f505152535455565758595a5b5c5d5e5f606162636465666768696a6b6c6d6e6f707172737475767778797a7b7c7d7e7f808182838485868788898a8b8c8d8e8f909192939495969798999a9b9c9d9e9fa0a1a2a3a4a5a6a7a8a9aaabacadaeafb0b1b2b3b4b5b6b7b8b9babbbcbdbebfc0c1c2c3c4c5c6c7c8c9cacbcccdcecfd0d1d2d3d4d5d6d7d8d9dadbdcdddedfe0e1e2e3e4e5e6e7e8e9eaebecedeeeff0f1f2f3f4f5f6f7f8f9fafbfcfdfeff"
 * cdef char *hexdigits_upper = "000102030405060708090A0B0C0D0E0F101112131415161718191A1B1C1D1E1F202122232425262728292A2B2C2D2E2F303132333435363738393A3B3C3D3E3F404142434445464748494A4B4C4D4E4F505152535455565758595A5B5C5D5E5F606162636465666768696A6B6C6D6E6F707172737475767778797A7B7C7D7E7F808182838485868788898A8B8C8D8E8F909192939495969798999A9B9C9D9E9FA0A1A2A3A4A5A6A7A8A9AAABACADAEAFB0B1B2B3B4B5B6B7B8B9BABBBCBDBEBFC0C1C2C3C4C5C6C7C8C9CACBCCCDCECFD0D1D2D3D4D5D6D7D8D9DADBDCDDDEDFE0E1E2E3E4E5E6E7E8E9EAEBECEDEEEFF0F1F2F3F4F5F6F7F8F9FAFBFCFDFEFF"             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_8omnivore_12disassembler_7libudis_hexdigits_upper = ((char *)"000102030405060708090A0B0C0D0E0F101112131415161718191A1B1C1D1E1F202122232425262728292A2B2C2D2E2F303132333435363738393A3B3C3D3E3F404142434445464748494A4B4C4D4E4F505152535455565758595A5B5C5D5E5F606162636465666768696A6B6C6D6E6F707172737475767778797A7B7C7D7E7F808182838485868788898A8B8C8D8E8F909192939495969798999A9B9C9D9E9FA0A1A2A3A4A5A6A7A8A9AAABACADAEAFB0B1B2B3B4B5B6B7B8B9BABBBCBDBEBFC0C1C2C3C4C5C6C7C8C9CACBCCCDCECFD0D1D2D3D4D5D6D7D8D9DADBDCDDDEDFE0E1E2E3E4E5E6E7E8E9EAEBECEDEEEFF0F1F2F3F4F5F6F7F8F9FAFBFCFDFEFF");

  /* "libudis/libudis.pyx":442
 * 
 * 
 * cdef int data_style = 0             # <<<<<<<<<<<<<<
 * 
 * cdef class DisassemblyConfig:
 */
  __pyx_v_8omnivore_12disassembler_7libudis_data_style = 0;

  /* "libudis/libudis.pyx":449
 *     cdef np.uint8_t default_disasm_type
 * 
 *     def __init__(self, def_disasm_type=0, split_comments=[data_style]):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         for i in range(256):
 */
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_8omnivore_12disassembler_7libudis_data_style); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_k__13 = __pyx_t_1;
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;

  /* "libudis/libudis.pyx":1
 * # cython: language_level=3             # <<<<<<<<<<<<<<
 * from libc.stdio cimport printf
 * import cython
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "../../../../fast/code/venv/py3d/lib64/python3.6/site-packages/Cython/Includes/numpy/__init__.pxd":1046
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init omnivore.disassembler.libudis", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init omnivore.disassembler.libudis");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, int nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned short    uint16_t;
        #else
           typedef unsigned __int16  uint16_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#if defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define GCC_DIAGNOSTIC
#endif
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            *(uint16_t*)dpos = ((const uint16_t*)DIGIT_PAIRS_8)[digit_pos];
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            *(uint16_t*)dpos = ((const uint16_t*)DIGIT_PAIRS_10)[digit_pos];
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    if (last_one_off) {
        assert(*dpos == '0');
        dpos++;
    }
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      CYTHON_UNUSED Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind;
    Py_ssize_t i, char_pos;
    void *result_udata;
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely(char_pos + ulength < 0))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + char_pos * result_ukind, udata, (size_t) (ulength * result_ukind));
        } else {
            #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    result_ulength++;
    value_count++;
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* IterFinish */
static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_FAST_THREAD_STATE
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

/* UnpackItemEndCheck */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* IsLittleEndian */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void)
{
  union {
    uint32_t u32;
    uint8_t u8[4];
  } S;
  S.u32 = 0x01020304;
  return S.u8[0] == 4;
}

/* BufferFormatCheck */
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t <= '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparseable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number;
    int ndim = ctx->head->field->type->ndim;
;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
        CYTHON_FALLTHROUGH;
      case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if (ctx->enc_type == *ts && got_Z == ctx->is_complex &&
            ctx->enc_packmode == ctx->new_packmode) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
        CYTHON_FALLTHROUGH;
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}

/* BufferGetAndValidate */
  static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (unlikely(info->buf == NULL)) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}
static void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static int __Pyx__GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  buf->buf = NULL;
  if (unlikely(__Pyx_GetBuffer(obj, buf, flags) == -1)) {
    __Pyx_ZeroBuffer(buf);
    return -1;
  }
  if (unlikely(buf->ndim != nd)) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if (unlikely((size_t)buf->itemsize != dtype->size)) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_SafeReleaseBuffer(buf);
  return -1;
}

/* None */
  static CYTHON_INLINE long __Pyx_mod_long(long a, long b) {
    long r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* PyIntBinop */
  #if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_SubtractObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a - b);
            if (likely((x^a) >= 0 || (x^~b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_subtract(op1, op2);
            }
        }
                x = a - b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla - llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("subtract", return NULL)
            result = ((double)a) - (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceSubtract : PyNumber_Subtract)(op1, op2);
}
#endif

/* None */
  static CYTHON_INLINE __pyx_t_5numpy_int32_t __Pyx_mod___pyx_t_5numpy_int32_t(__pyx_t_5numpy_int32_t a, __pyx_t_5numpy_int32_t b) {
    __pyx_t_5numpy_int32_t r = a % b;
    r += ((r != 0) & ((r ^ b) < 0)) * b;
    return r;
}

/* DictGetItem */
  #if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* RaiseNoneIterError */
  static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* PyObject_GenericGetAttrNoDict */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
  static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* SetupReduce */
  static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_cython); if (unlikely(!reduce_cython)) goto BAD;
            ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto BAD;
            ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto BAD;
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate_cython); if (unlikely(!setstate_cython)) goto BAD;
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto BAD;
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto GOOD;
BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
  #ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* Import */
  static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
  static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* CLineInTraceback */
  #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
  static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
  #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) return __pyx_pw_5numpy_7ndarray_1__getbuffer__(obj, view, flags);
    PyErr_Format(PyExc_TypeError, "'%.200s' does not have the buffer interface", Py_TYPE(obj)->tp_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
    if ((0)) {}
        else if (__Pyx_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) __pyx_pw_5numpy_7ndarray_3__releasebuffer__(obj, view);
    view->obj = NULL;
    Py_DECREF(obj);
}
#endif


  /* CIntFromPyVerify */
  #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint32(npy_uint32 value) {
    const npy_uint32 neg_one = (npy_uint32) ((npy_uint32) 0 - (npy_uint32) 1), const_zero = (npy_uint32) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_uint32) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_uint32) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint32) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_uint32) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint32) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(npy_uint32),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int8(npy_int8 value) {
    const npy_int8 neg_one = (npy_int8) ((npy_int8) 0 - (npy_int8) 1), const_zero = (npy_int8) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int8) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int8) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int8) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int8) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int8) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(npy_int8),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint8(npy_uint8 value) {
    const npy_uint8 neg_one = (npy_uint8) ((npy_uint8) 0 - (npy_uint8) 1), const_zero = (npy_uint8) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_uint8) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_uint8) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint8) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_uint8) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint8) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(npy_uint8),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value) {
    const npy_int32 neg_one = (npy_int32) ((npy_int32) 0 - (npy_int32) 1), const_zero = (npy_int32) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int32) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int32) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int32) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int32) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int32) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(npy_int32),
                                     little, !is_unsigned);
    }
}

/* Declarations */
  #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
  #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if (b.imag == 0) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value) {
    const enum NPY_TYPES neg_one = (enum NPY_TYPES) ((enum NPY_TYPES) 0 - (enum NPY_TYPES) 1), const_zero = (enum NPY_TYPES) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum NPY_TYPES) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(enum NPY_TYPES) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(enum NPY_TYPES) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum NPY_TYPES),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
  static CYTHON_INLINE npy_uint8 __Pyx_PyInt_As_npy_uint8(PyObject *x) {
    const npy_uint8 neg_one = (npy_uint8) ((npy_uint8) 0 - (npy_uint8) 1), const_zero = (npy_uint8) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(npy_uint8) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(npy_uint8, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_uint8) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_uint8) 0;
                case  1: __PYX_VERIFY_RETURN_INT(npy_uint8, digit, digits[0])
                case 2:
                    if (8 * sizeof(npy_uint8) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) >= 2 * PyLong_SHIFT) {
                            return (npy_uint8) (((((npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_uint8) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) >= 3 * PyLong_SHIFT) {
                            return (npy_uint8) (((((((npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_uint8) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) >= 4 * PyLong_SHIFT) {
                            return (npy_uint8) (((((((((npy_uint8)digits[3]) << PyLong_SHIFT) | (npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_uint8) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(npy_uint8) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_uint8) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_uint8) 0;
                case -1: __PYX_VERIFY_RETURN_INT(npy_uint8, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(npy_uint8,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(npy_uint8) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_uint8) (((npy_uint8)-1)*(((((npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(npy_uint8) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_uint8) ((((((npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(npy_uint8) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_uint8) (((npy_uint8)-1)*(((((((npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_uint8) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_uint8) ((((((((npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(npy_uint8) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_uint8) (((npy_uint8)-1)*(((((((((npy_uint8)digits[3]) << PyLong_SHIFT) | (npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_uint8) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_uint8) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_uint8) ((((((((((npy_uint8)digits[3]) << PyLong_SHIFT) | (npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(npy_uint8) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_uint8) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            npy_uint8 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (npy_uint8) -1;
        }
    } else {
        npy_uint8 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_uint8) -1;
        val = __Pyx_PyInt_As_npy_uint8(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_uint8");
    return (npy_uint8) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_uint8");
    return (npy_uint8) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_int8 __Pyx_PyInt_As_npy_int8(PyObject *x) {
    const npy_int8 neg_one = (npy_int8) ((npy_int8) 0 - (npy_int8) 1), const_zero = (npy_int8) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(npy_int8) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(npy_int8, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_int8) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_int8) 0;
                case  1: __PYX_VERIFY_RETURN_INT(npy_int8, digit, digits[0])
                case 2:
                    if (8 * sizeof(npy_int8) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) >= 2 * PyLong_SHIFT) {
                            return (npy_int8) (((((npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_int8) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) >= 3 * PyLong_SHIFT) {
                            return (npy_int8) (((((((npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_int8) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) >= 4 * PyLong_SHIFT) {
                            return (npy_int8) (((((((((npy_int8)digits[3]) << PyLong_SHIFT) | (npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_int8) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(npy_int8) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_int8) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_int8) 0;
                case -1: __PYX_VERIFY_RETURN_INT(npy_int8, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(npy_int8,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(npy_int8) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_int8) (((npy_int8)-1)*(((((npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(npy_int8) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_int8) ((((((npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(npy_int8) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_int8) (((npy_int8)-1)*(((((((npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_int8) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_int8) ((((((((npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(npy_int8) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_int8) (((npy_int8)-1)*(((((((((npy_int8)digits[3]) << PyLong_SHIFT) | (npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_int8) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int8) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_int8) ((((((((((npy_int8)digits[3]) << PyLong_SHIFT) | (npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(npy_int8) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_int8) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            npy_int8 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (npy_int8) -1;
        }
    } else {
        npy_int8 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_int8) -1;
        val = __Pyx_PyInt_As_npy_int8(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_int8");
    return (npy_int8) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_int8");
    return (npy_int8) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_int32 __Pyx_PyInt_As_npy_int32(PyObject *x) {
    const npy_int32 neg_one = (npy_int32) ((npy_int32) 0 - (npy_int32) 1), const_zero = (npy_int32) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(npy_int32) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(npy_int32, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_int32) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_int32) 0;
                case  1: __PYX_VERIFY_RETURN_INT(npy_int32, digit, digits[0])
                case 2:
                    if (8 * sizeof(npy_int32) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) >= 2 * PyLong_SHIFT) {
                            return (npy_int32) (((((npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_int32) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) >= 3 * PyLong_SHIFT) {
                            return (npy_int32) (((((((npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_int32) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) >= 4 * PyLong_SHIFT) {
                            return (npy_int32) (((((((((npy_int32)digits[3]) << PyLong_SHIFT) | (npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_int32) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(npy_int32) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_int32) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (npy_int32) 0;
                case -1: __PYX_VERIFY_RETURN_INT(npy_int32, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(npy_int32,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(npy_int32) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_int32) (((npy_int32)-1)*(((((npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(npy_int32) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) - 1 > 2 * PyLong_SHIFT) {
                            return (npy_int32) ((((((npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(npy_int32) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_int32) (((npy_int32)-1)*(((((((npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(npy_int32) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) - 1 > 3 * PyLong_SHIFT) {
                            return (npy_int32) ((((((((npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(npy_int32) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_int32) (((npy_int32)-1)*(((((((((npy_int32)digits[3]) << PyLong_SHIFT) | (npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(npy_int32) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(npy_int32) - 1 > 4 * PyLong_SHIFT) {
                            return (npy_int32) ((((((((((npy_int32)digits[3]) << PyLong_SHIFT) | (npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(npy_int32) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(npy_int32) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            npy_int32 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (npy_int32) -1;
        }
    } else {
        npy_int32 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_int32) -1;
        val = __Pyx_PyInt_As_npy_int32(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_int32");
    return (npy_int32) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_int32");
    return (npy_int32) -1;
}

/* FastTypeChecks */
  #if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* FetchCommonType */
  static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* SwapException */
  #if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
    #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* PyObjectGetMethod */
  static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
  static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* CoroutineBase */
  #include <structmember.h>
#include <frameobject.h>
#define __Pyx_Coroutine_Undelegate(gen) Py_CLEAR((gen)->yieldfrom)
static int __Pyx_PyGen__FetchStopIterationValue(CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#if PY_VERSION_HEX >= 0x030300A0
        else if (Py_TYPE(ev) == (PyTypeObject*)PyExc_StopIteration) {
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            Py_DECREF(ev);
        }
#endif
        else if (unlikely(PyTuple_Check(ev))) {
            if (PyTuple_GET_SIZE(ev) >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#else
                value = PySequence_ITEM(ev, 0);
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if PY_VERSION_HEX >= 0x030300A0
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
    Py_DECREF(ev);
#else
    {
        PyObject* args = __Pyx_PyObject_GetAttrStr(ev, __pyx_n_s_args);
        Py_DECREF(ev);
        if (likely(args)) {
            value = PySequence_GetItem(args, 0);
            Py_DECREF(args);
        }
        if (unlikely(!value)) {
            __Pyx_ErrRestore(NULL, NULL, NULL);
            Py_INCREF(Py_None);
            value = Py_None;
        }
    }
#endif
    *pvalue = value;
    return 0;
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(CYTHON_UNUSED __pyx_CoroutineObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
#define __Pyx_Coroutine_NotStartedError(gen)  (__Pyx__Coroutine_NotStartedError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_NotStartedError(CYTHON_UNUSED PyObject *gen) {
    const char *msg;
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check(gen)) {
        msg = "can't send non-None value to a just-started coroutine";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact(gen)) {
        msg = "can't send non-None value to a just-started async generator";
    #endif
    } else {
        msg = "can't send non-None value to a just-started generator";
    }
    PyErr_SetString(PyExc_TypeError, msg);
}
#define __Pyx_Coroutine_AlreadyTerminatedError(gen, value, closing)  (__Pyx__Coroutine_AlreadyTerminatedError(gen, value, closing), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyTerminatedError(CYTHON_UNUSED PyObject *gen, PyObject *value, CYTHON_UNUSED int closing) {
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(__Pyx_PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
PyObject *__Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(!self->is_running);
    if (unlikely(self->resume_label == 0)) {
        if (unlikely(value && value != Py_None)) {
            return __Pyx_Coroutine_NotStartedError((PyObject*)self);
        }
    }
    if (unlikely(self->resume_label == -1)) {
        return __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_type) {
        #if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
        #else
        if (exc_state->exc_traceback) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_state->exc_traceback;
            PyFrameObject *f = tb->tb_frame;
            Py_XINCREF(tstate->frame);
            assert(f->f_back == NULL);
            f->f_back = tstate->frame;
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    self->is_running = 1;
    retval = self->body((PyObject *) self, tstate, value);
    self->is_running = 0;
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    return retval;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
    PyObject *exc_tb = exc_state->exc_traceback;
    if (likely(exc_tb)) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_PYSTON
#else
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
#endif
    }
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_MethodReturn(CYTHON_UNUSED PyObject* gen, PyObject *retval) {
    if (unlikely(!retval)) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        if (!__Pyx_PyErr_Occurred()) {
            PyObject *exc = PyExc_StopIteration;
            #ifdef __Pyx_AsyncGen_USED
            if (__Pyx_AsyncGen_CheckExact(gen))
                exc = __Pyx_PyExc_StopAsyncIteration;
            #endif
            __Pyx_PyErr_SetNone(exc);
        }
    }
    return retval;
}
static CYTHON_INLINE
PyObject *__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen) {
    PyObject *ret;
    PyObject *val = NULL;
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    ret = __Pyx_Coroutine_SendEx(gen, val, 0);
    Py_XDECREF(val);
    return ret;
}
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03050000 && defined(PyCoro_CheckExact) && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyCoro_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
        {
            if (value == Py_None)
                ret = Py_TYPE(yf)->tp_iternext(yf);
            else
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_n_s_send, value);
        }
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        retval = __Pyx_Coroutine_FinishDelegation(gen);
    } else {
        retval = __Pyx_Coroutine_SendEx(gen, value, 0);
    }
    return __Pyx_Coroutine_MethodReturn(self, retval);
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    PyObject *retval = NULL;
    int err = 0;
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        retval = __Pyx_Coroutine_Close(yf);
        if (!retval)
            return -1;
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        retval = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf, NULL);
        if (!retval)
            return -1;
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
    } else
    #endif
    {
        PyObject *meth;
        gen->is_running = 1;
        meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_close);
        if (unlikely(!meth)) {
            if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                PyErr_WriteUnraisable(yf);
            }
            PyErr_Clear();
        } else {
            retval = PyObject_CallFunction(meth, NULL);
            Py_DECREF(meth);
            if (!retval)
                err = -1;
        }
        gen->is_running = 0;
    }
    Py_XDECREF(retval);
    return err;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        gen->is_running = 1;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03030000 && (defined(__linux__) || PY_VERSION_HEX >= 0x030600B3)
        if (PyGen_CheckExact(yf)) {
            ret = _PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
            ret = Py_TYPE(yf)->tp_iternext(yf);
        gen->is_running = 0;
        if (likely(ret)) {
            return ret;
        }
        return __Pyx_Coroutine_FinishDelegation(gen);
    }
    return __Pyx_Coroutine_SendEx(gen, Py_None, 0);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, CYTHON_UNUSED PyObject *arg) {
    return __Pyx_Coroutine_Close(self);
}
static PyObject *__Pyx_Coroutine_Close(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *retval, *raised_exception;
    PyObject *yf = gen->yieldfrom;
    int err = 0;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    retval = __Pyx_Coroutine_SendEx(gen, NULL, 1);
    if (unlikely(retval)) {
        const char *msg;
        Py_DECREF(retval);
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
#if PY_VERSION_HEX < 0x03060000
            msg = "async generator ignored GeneratorExit - might require Python 3.6+ finalisation (PEP 525)";
#else
            msg = "async generator ignored GeneratorExit";
#endif
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        return NULL;
    }
    raised_exception = PyErr_Occurred();
    if (likely(!raised_exception || __Pyx_PyErr_GivenExceptionMatches2(raised_exception, PyExc_GeneratorExit, PyExc_StopIteration))) {
        if (raised_exception) PyErr_Clear();
        Py_INCREF(Py_None);
        return Py_None;
    }
    return NULL;
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf = gen->yieldfrom;
    if (unlikely(gen->is_running))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    if (yf) {
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
            goto throw_here;
        }
        gen->is_running = 1;
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStr(yf, __pyx_n_s_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (!PyErr_ExceptionMatches(PyExc_AttributeError)) {
                    gen->is_running = 0;
                    return NULL;
                }
                PyErr_Clear();
                __Pyx_Coroutine_Undelegate(gen);
                gen->is_running = 0;
                goto throw_here;
            }
            if (likely(args)) {
                ret = PyObject_CallObject(meth, args);
            } else {
                ret = PyObject_CallFunctionObjArgs(meth, typ, val, tb, NULL);
            }
            Py_DECREF(meth);
        }
        gen->is_running = 0;
        Py_DECREF(yf);
        if (!ret) {
            ret = __Pyx_Coroutine_FinishDelegation(gen);
        }
        return __Pyx_Coroutine_MethodReturn(self, ret);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
    return __Pyx_Coroutine_MethodReturn(self, __Pyx_Coroutine_SendEx(gen, NULL, 0));
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (!PyArg_UnpackTuple(args, (char *)"throw", 1, 3, &typ, &val, &tb))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    Py_CLEAR(gen->yieldfrom);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    if (gen->gi_weakreflist != NULL)
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if PY_VERSION_HEX >= 0x030400a1 && CYTHON_USE_TP_FINALIZE
        if (PyObject_CallFinalizerFromDealloc(self))
#else
        Py_TYPE(gen)->tp_del(self);
        if (self->ob_refcnt > 0)
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    PyObject_GC_Del(gen);
}
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt == 0);
    self->ob_refcnt = 1;
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
#if PY_MAJOR_VERSION >= 3  || defined(PyErr_WarnFormat)
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
#else
        {PyObject *msg;
        char *cmsg;
        #if CYTHON_COMPILING_IN_PYPY
        msg = NULL;
        cmsg = (char*) "coroutine was never awaited";
        #else
        char *cname;
        PyObject *qualname;
        qualname = gen->gi_qualname;
        cname = PyString_AS_STRING(qualname);
        msg = PyString_FromFormat("coroutine '%.50s' was never awaited", cname);
        if (unlikely(!msg)) {
            PyErr_Clear();
            cmsg = (char*) "coroutine was never awaited";
        } else {
            cmsg = PyString_AS_STRING(msg);
        }
        #endif
        if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, cmsg, 1) < 0))
            PyErr_WriteUnraisable(self);
        Py_XDECREF(msg);}
#endif
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *res = __Pyx_Coroutine_Close(self);
        if (unlikely(!res)) {
            if (PyErr_Occurred())
                PyErr_WriteUnraisable(self);
        } else {
            Py_DECREF(res);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
#if !CYTHON_USE_TP_FINALIZE
    assert(self->ob_refcnt > 0);
    if (--self->ob_refcnt == 0) {
        return;
    }
    {
        Py_ssize_t refcnt = self->ob_refcnt;
        _Py_NewReference(self);
        self->ob_refcnt = refcnt;
    }
#if CYTHON_COMPILING_IN_CPYTHON
    assert(PyType_IS_GC(self->ob_type) &&
           _Py_AS_GC(self)->gc.gc_refs != _PyGC_REFS_UNTRACKED);
    _Py_DEC_REFTOTAL;
#endif
#ifdef COUNT_ALLOCS
    --Py_TYPE(self)->tp_frees;
    --Py_TYPE(self)->tp_allocs;
#endif
#endif
}
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_name;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_name;
    Py_INCREF(value);
    self->gi_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, CYTHON_UNUSED void *context)
{
    PyObject *name = self->gi_qualname;
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = self->gi_qualname;
    Py_INCREF(value);
    self->gi_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
    gen->gi_weakreflist = NULL;
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    PyObject_GC_Track(gen);
    return gen;
}

/* PatchModuleWithCoroutine */
  static PyObject* __Pyx_Coroutine_patch_module(PyObject* module, const char* py_code) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    int result;
    PyObject *globals, *result_obj;
    globals = PyDict_New();  if (unlikely(!globals)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_coroutine_type",
    #ifdef __Pyx_Coroutine_USED
        (PyObject*)__pyx_CoroutineType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    result = PyDict_SetItemString(globals, "_cython_generator_type",
    #ifdef __Pyx_Generator_USED
        (PyObject*)__pyx_GeneratorType);
    #else
        Py_None);
    #endif
    if (unlikely(result < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "_module", module) < 0)) goto ignore;
    if (unlikely(PyDict_SetItemString(globals, "__builtins__", __pyx_b) < 0)) goto ignore;
    result_obj = PyRun_String(py_code, Py_file_input, globals, globals);
    if (unlikely(!result_obj)) goto ignore;
    Py_DECREF(result_obj);
    Py_DECREF(globals);
    return module;
ignore:
    Py_XDECREF(globals);
    PyErr_WriteUnraisable(module);
    if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning, "Cython module failed to patch module with custom type", 1) < 0)) {
        Py_DECREF(module);
        module = NULL;
    }
#else
    py_code++;
#endif
    return module;
}

/* PatchGeneratorABC */
  #ifndef CYTHON_REGISTER_ABCS
#define CYTHON_REGISTER_ABCS 1
#endif
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
static PyObject* __Pyx_patch_abc_module(PyObject *module);
static PyObject* __Pyx_patch_abc_module(PyObject *module) {
    module = __Pyx_Coroutine_patch_module(
        module, ""
"if _cython_generator_type is not None:\n"
"    try: Generator = _module.Generator\n"
"    except AttributeError: pass\n"
"    else: Generator.register(_cython_generator_type)\n"
"if _cython_coroutine_type is not None:\n"
"    try: Coroutine = _module.Coroutine\n"
"    except AttributeError: pass\n"
"    else: Coroutine.register(_cython_coroutine_type)\n"
    );
    return module;
}
#endif
static int __Pyx_patch_abc(void) {
#if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
    static int abc_patched = 0;
    if (CYTHON_REGISTER_ABCS && !abc_patched) {
        PyObject *module;
        module = PyImport_ImportModule((PY_MAJOR_VERSION >= 3) ? "collections.abc" : "collections");
        if (!module) {
            PyErr_WriteUnraisable(NULL);
            if (unlikely(PyErr_WarnEx(PyExc_RuntimeWarning,
                    ((PY_MAJOR_VERSION >= 3) ?
                        "Cython module failed to register with collections.abc module" :
                        "Cython module failed to register with collections module"), 1) < 0)) {
                return -1;
            }
        } else {
            module = __Pyx_patch_abc_module(module);
            abc_patched = 1;
            if (unlikely(!module))
                return -1;
            Py_DECREF(module);
        }
        module = PyImport_ImportModule("backports_abc");
        if (module) {
            module = __Pyx_patch_abc_module(module);
            Py_XDECREF(module);
        }
        if (!module) {
            PyErr_Clear();
        }
    }
#else
    if ((0)) __Pyx_Coroutine_patch_module(NULL, NULL);
#endif
    return 0;
}

/* Generator */
  static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     (char*) PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     (char*) PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     (char*) PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {(char *) "gi_running", T_BOOL, offsetof(__pyx_CoroutineObject, is_running), READONLY, NULL},
    {(char*) "gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     (char*) PyDoc_STR("object being iterated by 'yield from', or None")},
    {(char*) "gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {(char *) "__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     (char*) PyDoc_STR("name of the generator"), 0},
    {(char *) "__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     (char*) PyDoc_STR("qualified name of the generator"), 0},
    {0, 0, 0, 0, 0}
};
static PyTypeObject __pyx_GeneratorType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "generator",
    sizeof(__pyx_CoroutineObject),
    0,
    (destructor) __Pyx_Coroutine_dealloc,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_HAVE_FINALIZE,
    0,
    (traverseproc) __Pyx_Coroutine_traverse,
    0,
    0,
    offsetof(__pyx_CoroutineObject, gi_weakreflist),
    0,
    (iternextfunc) __Pyx_Generator_Next,
    __pyx_Generator_methods,
    __pyx_Generator_memberlist,
    __pyx_Generator_getsets,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if CYTHON_USE_TP_FINALIZE
    0,
#else
    __Pyx_Coroutine_del,
#endif
    0,
#if CYTHON_USE_TP_FINALIZE
    __Pyx_Coroutine_del,
#elif PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_Generator_init(void) {
    __pyx_GeneratorType_type.tp_getattro = __Pyx_PyObject_GenericGetAttrNoDict;
    __pyx_GeneratorType_type.tp_iter = PyObject_SelfIter;
    __pyx_GeneratorType = __Pyx_FetchCommonType(&__pyx_GeneratorType_type);
    if (unlikely(!__pyx_GeneratorType)) {
        return -1;
    }
    return 0;
}

/* CheckBinaryVersion */
  static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
  static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
